@@ -6,7 +6,7 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Array proxy base class
+"""Array proxy base class
 
 The proxy API is - at minimum:
 
@@ -25,16 +25,18 @@ The proxy API is - at minimum:
 
 See :mod:`nibabel.tests.test_proxy_api` for proxy API conformance checks.
 """
+from __future__ import annotations
+
+import typing as ty
+import warnings
 from contextlib import contextmanager
 from threading import RLock
 
 import numpy as np
 
-from .deprecated import deprecate_with_version
-from .volumeutils import array_from_file, apply_read_scaling
-from .fileslice import fileslice, canonical_slicers
 from . import openers
-
+from .fileslice import canonical_slicers, fileslice
+from .volumeutils import apply_read_scaling, array_from_file
 
 """This flag controls whether a new file handle is created every time an image
 is accessed through an ``ArrayProxy``, or a single file handle is created and
@@ -50,16 +52,33 @@ If this flag is set to ``True``, a single file handle is created and used. If
 If this is set to any other value, attempts to create an ``ArrayProxy`` without
 specifying the ``keep_file_open`` flag will result in a ``ValueError`` being
 raised.
-
-.. warning:: Setting this flag to a value of ``'auto'`` became deprecated
-             behaviour in version 2.4.1. Support for ``'auto'`` was removed
-             in version 3.0.0.
 """
 KEEP_FILE_OPEN_DEFAULT = False
 
 
-class ArrayProxy(object):
-    """ Class to act as proxy for the array that can be read from a file
+if ty.TYPE_CHECKING:  # pragma: no cover
+    import numpy.typing as npt
+
+
+class ArrayLike(ty.Protocol):
+    """Protocol for numpy ndarray-like objects
+
+    This is more stringent than :class:`numpy.typing.ArrayLike`, but guarantees
+    access to shape, ndim and slicing.
+    """
+
+    shape: tuple[int, ...]
+    ndim: int
+
+    def __array__(self, dtype: npt.DTypeLike | None = None, /) -> npt.NDArray:
+        ...  # pragma: no cover
+
+    def __getitem__(self, key, /) -> npt.NDArray:
+        ...  # pragma: no cover
+
+
+class ArrayProxy(ArrayLike):
+    """Class to act as proxy for the array that can be read from a file
 
     The array proxy allows us to freeze the passed fileobj and header such that
     it returns the expected data array.
@@ -88,17 +107,12 @@ class ArrayProxy(object):
     See :mod:`nibabel.minc1`, :mod:`nibabel.ecat` and :mod:`nibabel.parrec` for
     examples.
     """
-    # Assume Fortran array memory layout
-    order = 'F'
-    _header = None
 
-    def __init__(self, file_like, spec, *, mmap=True, keep_file_open=None):
+    _default_order = 'F'
+
+    def __init__(self, file_like, spec, *, mmap=True, order=None, keep_file_open=None):
         """Initialize array proxy instance
 
-        .. deprecated:: 2.4.1
-            ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It raises an error as of nibabel 3.0.
-
         Parameters
         ----------
         file_like : object
@@ -126,6 +140,11 @@ class ArrayProxy(object):
             True gives the same behavior as ``mmap='c'``.  If `file_like`
             cannot be memory-mapped, ignore `mmap` value and read array from
             file.
+        order : {None, 'F', 'C'}, optional, keyword only
+            `order` controls the order of the data array layout. Fortran-style,
+            column-major order may be indicated with 'F', and C-style, row-major
+            order may be indicated with 'C'. None gives the default order, that
+            comes from the `_default_order` class variable.
         keep_file_open : { None, True, False }, optional, keyword only
             `keep_file_open` controls whether a new file handle is created
             every time the image is accessed, or a single file handle is
@@ -138,31 +157,51 @@ class ArrayProxy(object):
         """
         if mmap not in (True, False, 'c', 'r'):
             raise ValueError("mmap should be one of {True, False, 'c', 'r'}")
+        if order not in (None, 'C', 'F'):
+            raise ValueError("order should be one of {None, 'C', 'F'}")
         self.file_like = file_like
         if hasattr(spec, 'get_data_shape'):
             slope, inter = spec.get_slope_inter()
-            par = (spec.get_data_shape(),
-                   spec.get_data_dtype(),
-                   spec.get_data_offset(),
-                   1. if slope is None else slope,
-                   0. if inter is None else inter)
-            # Reference to original header; we will remove this soon
-            self._header = spec.copy()
+            par = (
+                spec.get_data_shape(),
+                spec.get_data_dtype(),
+                spec.get_data_offset(),
+                1.0 if slope is None else slope,
+                0.0 if inter is None else inter,
+            )
         elif 2 <= len(spec) <= 5:
-            optional = (0, 1., 0.)
-            par = spec + optional[len(spec) - 2:]
+            optional = (0, 1.0, 0.0)
+            par = spec + optional[len(spec) - 2 :]
         else:
             raise TypeError('spec must be tuple of length 2-5 or header object')
 
+        # Warn downstream users that the class variable order is going away
+        if hasattr(self.__class__, 'order'):
+            warnings.warn(
+                f'Class {self.__class__} has an `order` class variable. '
+                'ArrayProxy subclasses should rename this variable to `_default_order` '
+                'to avoid conflict with instance variables.\n'
+                '* deprecated in version: 5.0\n'
+                '* will raise error in version: 7.0\n',
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            # Override _default_order with order, to follow intent of subclasser
+            self._default_order = self.order
+
         # Copies of values needed to read array
         self._shape, self._dtype, self._offset, self._slope, self._inter = par
         # Permit any specifier that can be interpreted as a numpy dtype
         self._dtype = np.dtype(self._dtype)
         self._mmap = mmap
+        if order is None:
+            order = self._default_order
+        self.order = order
         # Flags to keep track of whether a single ImageOpener is created, and
         # whether a single underlying file handle is created.
-        self._keep_file_open, self._persist_opener = \
-            self._should_keep_file_open(file_like, keep_file_open)
+        self._keep_file_open, self._persist_opener = self._should_keep_file_open(
+            file_like, keep_file_open
+        )
         self._lock = RLock()
 
     def __del__(self):
@@ -174,13 +213,13 @@ class ArrayProxy(object):
             self._opener = None
 
     def __getstate__(self):
-        """Returns the state of this ``ArrayProxy`` during pickling. """
+        """Returns the state of this ``ArrayProxy`` during pickling."""
         state = self.__dict__.copy()
         state.pop('_lock', None)
         return state
 
     def __setstate__(self, state):
-        """Sets the state of this ``ArrayProxy`` during unpickling. """
+        """Sets the state of this ``ArrayProxy`` during unpickling."""
         self.__dict__.update(state)
         self._lock = RLock()
 
@@ -232,10 +271,6 @@ class ArrayProxy(object):
            In this case, file handle management is delegated to the
            ``indexed_gzip`` library.
 
-        .. deprecated:: 2.4.1
-            ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It raises an error as of nibabel 3.0.
-
         Parameters
         ----------
 
@@ -255,8 +290,10 @@ class ArrayProxy(object):
         if keep_file_open is None:
             keep_file_open = KEEP_FILE_OPEN_DEFAULT
             if keep_file_open not in (True, False):
-                raise ValueError("nibabel.arrayproxy.KEEP_FILE_OPEN_DEFAULT "
-                                 f"must be boolean. Found: {keep_file_open}")
+                raise ValueError(
+                    'nibabel.arrayproxy.KEEP_FILE_OPEN_DEFAULT '
+                    f'must be boolean. Found: {keep_file_open}'
+                )
         elif keep_file_open not in (True, False):
             raise ValueError('keep_file_open must be one of {None, True, False}')
 
@@ -269,11 +306,6 @@ class ArrayProxy(object):
         persist_opener = keep_file_open or have_igzip
         return keep_file_open, persist_opener
 
-    @property
-    @deprecate_with_version('ArrayProxy.header deprecated', '2.2', '3.0')
-    def header(self):
-        return self._header
-
     @property
     def shape(self):
         return self._shape
@@ -317,32 +349,35 @@ class ArrayProxy(object):
         """
         if self._persist_opener:
             if not hasattr(self, '_opener'):
-                self._opener = openers.ImageOpener(
-                    self.file_like, keep_open=self._keep_file_open)
+                self._opener = openers.ImageOpener(self.file_like, keep_open=self._keep_file_open)
             yield self._opener
         else:
-            with openers.ImageOpener(
-                    self.file_like, keep_open=False) as opener:
+            with openers.ImageOpener(self.file_like, keep_open=False) as opener:
                 yield opener
 
     def _get_unscaled(self, slicer):
-        if canonical_slicers(slicer, self._shape, False) == \
-                canonical_slicers((), self._shape, False):
+        if canonical_slicers(slicer, self._shape, False) == canonical_slicers(
+            (), self._shape, False
+        ):
             with self._get_fileobj() as fileobj, self._lock:
-                return array_from_file(self._shape,
-                                       self._dtype,
-                                       fileobj,
-                                       offset=self._offset,
-                                       order=self.order,
-                                       mmap=self._mmap)
+                return array_from_file(
+                    self._shape,
+                    self._dtype,
+                    fileobj,
+                    offset=self._offset,
+                    order=self.order,
+                    mmap=self._mmap,
+                )
         with self._get_fileobj() as fileobj:
-            return fileslice(fileobj,
-                             slicer,
-                             self._shape,
-                             self._dtype,
-                             self._offset,
-                             order=self.order,
-                             lock=self._lock)
+            return fileslice(
+                fileobj,
+                slicer,
+                self._shape,
+                self._dtype,
+                self._offset,
+                order=self.order,
+                lock=self._lock,
+            )
 
     def _get_scaled(self, dtype, slicer):
         # Ensure scale factors have dtypes
@@ -361,14 +396,14 @@ class ArrayProxy(object):
         return scaled
 
     def get_unscaled(self):
-        """ Read data from file
+        """Read data from file
 
         This is an optional part of the proxy API
         """
         return self._get_unscaled(slicer=())
 
     def __array__(self, dtype=None):
-        """ Read data from file and apply scaling, casting to ``dtype``
+        """Read data from file and apply scaling, casting to ``dtype``
 
         If ``dtype`` is unspecified, the dtype of the returned array is the
         narrowest dtype that can represent the data without overflow.
@@ -397,31 +432,32 @@ class ArrayProxy(object):
         return self._get_scaled(dtype=None, slicer=slicer)
 
     def reshape(self, shape):
-        """ Return an ArrayProxy with a new shape, without modifying data """
+        """Return an ArrayProxy with a new shape, without modifying data"""
         size = np.prod(self._shape)
 
         # Calculate new shape if not fully specified
-        from operator import mul
         from functools import reduce
+        from operator import mul
+
         n_unknowns = len([e for e in shape if e == -1])
         if n_unknowns > 1:
-            raise ValueError("can only specify one unknown dimension")
+            raise ValueError('can only specify one unknown dimension')
         elif n_unknowns == 1:
             known_size = reduce(mul, shape, -1)
             unknown_size = size // known_size
             shape = tuple(unknown_size if e == -1 else e for e in shape)
 
         if np.prod(shape) != size:
-            raise ValueError(f"cannot reshape array of size {size:d} into shape {shape!s}")
-        return self.__class__(file_like=self.file_like,
-                              spec=(shape, self._dtype, self._offset,
-                                    self._slope, self._inter),
-                              mmap=self._mmap)
+            raise ValueError(f'cannot reshape array of size {size:d} into shape {shape!s}')
+        return self.__class__(
+            file_like=self.file_like,
+            spec=(shape, self._dtype, self._offset, self._slope, self._inter),
+            mmap=self._mmap,
+        )
 
 
 def is_proxy(obj):
-    """ Return True if `obj` is an array proxy
-    """
+    """Return True if `obj` is an array proxy"""
     try:
         return obj.is_proxy
     except AttributeError:
@@ -429,7 +465,19 @@ def is_proxy(obj):
 
 
 def reshape_dataobj(obj, shape):
-    """ Use `obj` reshape method if possible, else numpy reshape function
-    """
-    return (obj.reshape(shape) if hasattr(obj, 'reshape')
-            else np.reshape(obj, shape))
+    """Use `obj` reshape method if possible, else numpy reshape function"""
+    return obj.reshape(shape) if hasattr(obj, 'reshape') else np.reshape(obj, shape)
+
+
+def get_obj_dtype(obj):
+    """Get the effective dtype of an array-like object"""
+    if is_proxy(obj):
+        # Read and potentially apply scaling to one value
+        idx = (0,) * len(obj.shape)
+        return obj[idx].dtype
+    elif hasattr(obj, 'dtype'):
+        # Trust the dtype (probably an ndarray)
+        return obj.dtype
+    else:
+        # Coerce; this could be expensive but we don't know what we can do with it
+        return np.asanyarray(obj).dtype
