@@ -1,4 +1,4 @@
-""" Array writer objects
+"""Array writer objects
 
 Array writers have init signature::
 
@@ -29,13 +29,18 @@ something else to make sense of conversions between float and int, or between
 larger ints and smaller.
 """
 
-import warnings
-
 import numpy as np
 
-from .casting import (int_to_float, as_int, int_abs, type_info, floor_exact,
-                      best_float, shared_range)
-from .volumeutils import finite_range, array_to_file
+from .casting import (
+    as_int,
+    best_float,
+    floor_exact,
+    int_abs,
+    int_to_float,
+    shared_range,
+    type_info,
+)
+from .volumeutils import array_to_file, finite_range
 
 
 class WriterError(Exception):
@@ -46,10 +51,9 @@ class ScalingError(WriterError):
     pass
 
 
-class ArrayWriter(object):
-
+class ArrayWriter:
     def __init__(self, array, out_dtype=None, **kwargs):
-        r""" Initialize array writer
+        r"""Initialize array writer
 
         Parameters
         ----------
@@ -94,10 +98,10 @@ class ArrayWriter(object):
         self._has_nan = None
         self._nan2zero = nan2zero
         if check_scaling and self.scaling_needed():
-            raise WriterError("Scaling needed but cannot scale")
+            raise WriterError('Scaling needed but cannot scale')
 
     def scaling_needed(self):
-        """ Checks if scaling is needed for input array
+        """Checks if scaling is needed for input array
 
         Raises WriterError if no scaling possible.
 
@@ -157,18 +161,17 @@ class ArrayWriter(object):
 
     @property
     def array(self):
-        """ Return array from arraywriter """
+        """Return array from arraywriter"""
         return self._array
 
     @property
     def out_dtype(self):
-        """ Return `out_dtype` from arraywriter """
+        """Return `out_dtype` from arraywriter"""
         return self._out_dtype
 
     @property
     def has_nan(self):
-        """ True if array has NaNs
-        """
+        """True if array has NaNs"""
         # Structured types raise an error for finite range; don't run finite
         # range unless we have to.
         if self._has_nan is None:
@@ -179,56 +182,45 @@ class ArrayWriter(object):
         return self._has_nan
 
     def finite_range(self):
-        """ Return (maybe cached) finite range of data array """
+        """Return (maybe cached) finite range of data array"""
         if self._finite_range is None:
             mn, mx, has_nan = finite_range(self._array, True)
             self._finite_range = (mn, mx)
             self._has_nan = has_nan
         return self._finite_range
 
-    def _check_nan2zero(self, nan2zero):
-        if nan2zero is None:
-            return
-        if nan2zero != self._nan2zero:
-            raise WriterError('Deprecated `nan2zero` argument to `to_fileobj` '
-                              'must be same as class value set in __init__')
-        warnings.warn('Please remove `nan2zero` from call to ' '`to_fileobj` '
-                      'and use in instance __init__ instead.\n'
-                      '* deprecated in version: 2.0\n'
-                      '* will raise error in version: 4.0\n',
-                      DeprecationWarning, stacklevel=3)
-
     def _needs_nan2zero(self):
-        """ True if nan2zero check needed for writing array """
-        return (self._nan2zero and
-                self._array.dtype.kind in 'fc' and
-                self.out_dtype.kind in 'iu' and
-                self.has_nan)
+        """True if nan2zero check needed for writing array"""
+        return (
+            self._nan2zero
+            and self._array.dtype.kind in 'fc'
+            and self.out_dtype.kind in 'iu'
+            and self.has_nan
+        )
 
-    def to_fileobj(self, fileobj, order='F', nan2zero=None):
-        """ Write array into `fileobj`
+    def to_fileobj(self, fileobj, order='F'):
+        """Write array into `fileobj`
 
         Parameters
         ----------
         fileobj : file-like object
         order : {'F', 'C'}
             order (Fortran or C) to which to write array
-        nan2zero : {None, True, False}, optional, deprecated
-            Deprecated version of argument to __init__ with same name
         """
-        self._check_nan2zero(nan2zero)
-        array_to_file(self._array,
-                      fileobj,
-                      self._out_dtype,
-                      offset=None,
-                      mn=None,
-                      mx=None,
-                      order=order,
-                      nan2zero=self._needs_nan2zero())
+        array_to_file(
+            self._array,
+            fileobj,
+            self._out_dtype,
+            offset=None,
+            mn=None,
+            mx=None,
+            order=order,
+            nan2zero=self._needs_nan2zero(),
+        )
 
 
 class SlopeArrayWriter(ArrayWriter):
-    """ ArrayWriter that can use scalefactor for writing arrays
+    """ArrayWriter that can use scalefactor for writing arrays
 
     The scalefactor allows the array writer to write floats to int output
     types, and rescale larger ints to smaller.  It can therefore lose
@@ -244,9 +236,8 @@ class SlopeArrayWriter(ArrayWriter):
     * calc_scale() - calculate slope to best write self.array
     """
 
-    def __init__(self, array, out_dtype=None, calc_scale=True,
-                 scaler_dtype=np.float32, **kwargs):
-        r""" Initialize array writer
+    def __init__(self, array, out_dtype=None, calc_scale=True, scaler_dtype=np.float32, **kwargs):
+        r"""Initialize array writer
 
         Parameters
         ----------
@@ -303,7 +294,7 @@ class SlopeArrayWriter(ArrayWriter):
             self.calc_scale()
 
     def scaling_needed(self):
-        """ Checks if scaling is needed for input array
+        """Checks if scaling is needed for input array
 
         Raises WriterError if no scaling possible.
 
@@ -322,14 +313,14 @@ class SlopeArrayWriter(ArrayWriter):
           data are within range of the output type, return False
         * Otherwise return True
         """
-        if not super(SlopeArrayWriter, self).scaling_needed():
+        if not super().scaling_needed():
             return False
         mn, mx = self.finite_range()  # this is cached
         # No finite data - no scaling needed
         return (mn, mx) != (np.inf, -np.inf)
 
     def reset(self):
-        """ Set object to values before any scaling calculation """
+        """Set object to values before any scaling calculation"""
         self.slope = 1.0
         self._finite_range = None
         self._scale_calced = False
@@ -339,11 +330,11 @@ class SlopeArrayWriter(ArrayWriter):
 
     def _set_slope(self, val):
         self._slope = np.squeeze(self.scaler_dtype.type(val))
+
     slope = property(_get_slope, _set_slope, None, 'get/set slope')
 
     def calc_scale(self, force=False):
-        """ Calculate / set scaling for floats/(u)ints to (u)ints
-        """
+        """Calculate / set scaling for floats/(u)ints to (u)ints"""
         # If we've run already, return unless told otherwise
         if not force and self._scale_calced:
             return
@@ -354,7 +345,7 @@ class SlopeArrayWriter(ArrayWriter):
         self._scale_calced = True
 
     def _writing_range(self):
-        """ Finite range for thresholding on write """
+        """Finite range for thresholding on write"""
         if self._out_dtype.kind in 'iu' and self._array.dtype.kind == 'f':
             mn, mx = self.finite_range()
             if (mn, mx) == (np.inf, -np.inf):  # no finite data
@@ -362,28 +353,27 @@ class SlopeArrayWriter(ArrayWriter):
             return mn, mx
         return None, None
 
-    def to_fileobj(self, fileobj, order='F', nan2zero=None):
-        """ Write array into `fileobj`
+    def to_fileobj(self, fileobj, order='F'):
+        """Write array into `fileobj`
 
         Parameters
         ----------
         fileobj : file-like object
         order : {'F', 'C'}
             order (Fortran or C) to which to write array
-        nan2zero : {None, True, False}, optional, deprecated
-            Deprecated version of argument to __init__ with same name
         """
-        self._check_nan2zero(nan2zero)
         mn, mx = self._writing_range()
-        array_to_file(self._array,
-                      fileobj,
-                      self._out_dtype,
-                      offset=None,
-                      divslope=self.slope,
-                      mn=mn,
-                      mx=mx,
-                      order=order,
-                      nan2zero=self._needs_nan2zero())
+        array_to_file(
+            self._array,
+            fileobj,
+            self._out_dtype,
+            offset=None,
+            divslope=self.slope,
+            mn=mn,
+            mx=mx,
+            order=order,
+            nan2zero=self._needs_nan2zero(),
+        )
 
     def _do_scaling(self):
         arr = self._array
@@ -403,7 +393,7 @@ class SlopeArrayWriter(ArrayWriter):
         out_max, out_min = info.max, info.min
         # If left as int64, uint64, comparisons will default to floats, and
         # these are inexact for > 2**53 - so convert to int
-        if (as_int(mx) <= as_int(out_max) and as_int(mn) >= as_int(out_min)):
+        if as_int(mx) <= as_int(out_max) and as_int(mn) >= as_int(out_min):
             # already in range
             return
         # (u)int to (u)int scaling
@@ -428,7 +418,7 @@ class SlopeArrayWriter(ArrayWriter):
         self._range_scale(mn, mx)
 
     def _range_scale(self, in_min, in_max):
-        """ Calculate scaling based on data range and output type """
+        """Calculate scaling based on data range and output type"""
         out_dtype = self._out_dtype
         info = type_info(out_dtype)
         out_min, out_max = info['min'], info['max']
@@ -438,12 +428,12 @@ class SlopeArrayWriter(ArrayWriter):
             # not lose precision because min/max are of fp type.
             out_min, out_max = np.array((out_min, out_max), dtype=big_float)
         else:  # (u)int
-            out_min, out_max = [int_to_float(v, big_float)
-                                for v in (out_min, out_max)]
+            out_min, out_max = (int_to_float(v, big_float) for v in (out_min, out_max))
         if self._out_dtype.kind == 'u':
             if in_min < 0 and in_max > 0:
-                raise WriterError('Cannot scale negative and positive '
-                                  'numbers to uint without intercept')
+                raise WriterError(
+                    'Cannot scale negative and positive numbers to uint without intercept'
+                )
             if in_max <= 0:  # All input numbers <= 0
                 self.slope = in_min / out_max
             else:  # All input numbers > 0
@@ -458,7 +448,7 @@ class SlopeArrayWriter(ArrayWriter):
 
 
 class SlopeInterArrayWriter(SlopeArrayWriter):
-    """ Array writer that can use slope and intercept to scale array
+    """Array writer that can use slope and intercept to scale array
 
     The writer can subtract an intercept, and divided by a slope, in order to
     be able to convert floating point values into a (u)int range, or to convert
@@ -475,9 +465,8 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
     * calc_scale() - calculate inter, slope to best write self.array
     """
 
-    def __init__(self, array, out_dtype=None, calc_scale=True,
-                 scaler_dtype=np.float32, **kwargs):
-        r""" Initialize array writer
+    def __init__(self, array, out_dtype=None, calc_scale=True, scaler_dtype=np.float32, **kwargs):
+        r"""Initialize array writer
 
         Parameters
         ----------
@@ -518,15 +507,11 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
         >>> (aw.slope, aw.inter) == (1.0, 128)
         True
         """
-        super(SlopeInterArrayWriter, self).__init__(array,
-                                                    out_dtype,
-                                                    calc_scale,
-                                                    scaler_dtype,
-                                                    **kwargs)
+        super().__init__(array, out_dtype, calc_scale, scaler_dtype, **kwargs)
 
     def reset(self):
-        """ Set object to values before any scaling calculation """
-        super(SlopeInterArrayWriter, self).reset()
+        """Set object to values before any scaling calculation"""
+        super().reset()
         self.inter = 0.0
 
     def _get_inter(self):
@@ -534,43 +519,42 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
 
     def _set_inter(self, val):
         self._inter = np.squeeze(self.scaler_dtype.type(val))
+
     inter = property(_get_inter, _set_inter, None, 'get/set inter')
 
-    def to_fileobj(self, fileobj, order='F', nan2zero=None):
-        """ Write array into `fileobj`
+    def to_fileobj(self, fileobj, order='F'):
+        """Write array into `fileobj`
 
         Parameters
         ----------
         fileobj : file-like object
         order : {'F', 'C'}
             order (Fortran or C) to which to write array
-        nan2zero : {None, True, False}, optional, deprecated
-            Deprecated version of argument to __init__ with same name
         """
-        self._check_nan2zero(nan2zero)
         mn, mx = self._writing_range()
-        array_to_file(self._array,
-                      fileobj,
-                      self._out_dtype,
-                      offset=None,
-                      intercept=self.inter,
-                      divslope=self.slope,
-                      mn=mn,
-                      mx=mx,
-                      order=order,
-                      nan2zero=self._needs_nan2zero())
+        array_to_file(
+            self._array,
+            fileobj,
+            self._out_dtype,
+            offset=None,
+            intercept=self.inter,
+            divslope=self.slope,
+            mn=mn,
+            mx=mx,
+            order=order,
+            nan2zero=self._needs_nan2zero(),
+        )
 
     def _iu2iu(self):
         # (u)int to (u)int
-        mn, mx = [as_int(v) for v in self.finite_range()]
+        mn, mx = (as_int(v) for v in self.finite_range())
         # range may be greater than the largest integer for this type.
         # as_int needed to work round numpy 1.4.1 int casting bug
         out_dtype = self._out_dtype
         # Options in this method are scaling using intercept only.  These will
         # have to pass through ``self.scaler_dtype`` (because the intercept is
         # in this type).
-        o_min, o_max = [as_int(v)
-                        for v in shared_range(self.scaler_dtype, out_dtype)]
+        o_min, o_max = (as_int(v) for v in shared_range(self.scaler_dtype, out_dtype))
         type_range = o_max - o_min
         mn2mx = mx - mn
         if mn2mx <= type_range:  # might offset be enough?
@@ -593,13 +577,12 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
                 self.inter = inter
                 return
         # Try slope options (sign flip) and then range scaling
-        super(SlopeInterArrayWriter, self)._iu2iu()
+        super()._iu2iu()
 
     def _range_scale(self, in_min, in_max):
-        """ Calculate scaling, intercept based on data range and output type
-        """
+        """Calculate scaling, intercept based on data range and output type"""
         if in_max == in_min:  # Only one number in array
-            self.slope = 1.
+            self.slope = 1.0
             self.inter = in_min
             return
         big_float = best_float()
@@ -619,8 +602,7 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
             in_min, in_max = as_int(in_min), as_int(in_max)
             in_range = int_to_float(in_max - in_min, big_float)
             # Cast to float for later processing.
-            in_min, in_max = [int_to_float(v, big_float)
-                              for v in (in_min, in_max)]
+            in_min, in_max = (int_to_float(v, big_float) for v in (in_min, in_max))
         if out_dtype.kind == 'f':
             # Type range, these are also floats
             info = type_info(out_dtype)
@@ -699,7 +681,7 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
         self.inter = inter
         self.slope = slope
         if not np.all(np.isfinite([self.slope, self.inter])):
-            raise ScalingError("Slope / inter not both finite")
+            raise ScalingError('Slope / inter not both finite')
         # Check nan fill value
         if not (0 in (in_min, in_max) and self._nan2zero and self.has_nan):
             return
@@ -714,7 +696,7 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
 
 
 def get_slope_inter(writer):
-    """ Return slope, intercept from array writer object
+    """Return slope, intercept from array writer object
 
     Parameters
     ----------
@@ -748,9 +730,8 @@ def get_slope_inter(writer):
     return slope, inter
 
 
-def make_array_writer(data, out_type, has_slope=True, has_intercept=True,
-                      **kwargs):
-    r""" Make array writer instance for array `data` and output type `out_type`
+def make_array_writer(data, out_type, has_slope=True, has_intercept=True, **kwargs):
+    r"""Make array writer instance for array `data` and output type `out_type`
 
     Parameters
     ----------
