@@ -6,7 +6,7 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Battery runner classes and Report classes
+"""Battery runner classes and Report classes
 
 These classes / objects are for generic checking / fixing batteries
 
@@ -20,6 +20,7 @@ different object, if ``fix==True``.
 
 To run checks only, and return problem report objects:
 
+>>> from nibabel.batteryrunners import BatteryRunner, Report
 >>> def chk(obj, fix=False): # minimal check
 ...     return obj, Report()
 >>> btrun = BatteryRunner((chk,))
@@ -37,7 +38,7 @@ is an integer, giving the level of problem, from 0 (no problem) to 50
 (very bad problem).  The levels follow the log levels from the logging
 module (e.g 40 equivalent to "error" level, 50 to "critical").  The
 ``error`` can be one of ``None`` if no error to suggest, or an Exception
-class that the user might consider raising for this sitation.  The
+class that the user might consider raising for this situation.  The
 ``problem_msg`` and ``fix_msg`` are human readable strings that should
 explain what happened.
 
@@ -104,15 +105,14 @@ or the pixdims::
             hdr['pixdim'][1:4] = np.abs(hdr['pixdim'][1:4])
             rep.fix_msg = 'setting to abs of pixdim values'
         return hdr, rep
-
 """
 
 
-class BatteryRunner(object):
-    """ Class to run set of checks """
+class BatteryRunner:
+    """Class to run set of checks"""
 
     def __init__(self, checks):
-        """ Initialize instance from sequence of `checks`
+        """Initialize instance from sequence of `checks`
 
         Parameters
         ----------
@@ -130,7 +130,7 @@ class BatteryRunner(object):
         self._checks = checks
 
     def check_only(self, obj):
-        """ Run checks on `obj` returning reports
+        """Run checks on `obj` returning reports
 
         Parameters
         ----------
@@ -150,7 +150,7 @@ class BatteryRunner(object):
         return reports
 
     def check_fix(self, obj):
-        """ Run checks, with fixes, on `obj` returning `obj`, reports
+        """Run checks, with fixes, on `obj` returning `obj`, reports
 
         Parameters
         ----------
@@ -174,14 +174,9 @@ class BatteryRunner(object):
         return len(self._checks)
 
 
-class Report(object):
-
-    def __init__(self,
-                 error=Exception,
-                 problem_level=0,
-                 problem_msg='',
-                 fix_msg=''):
-        """ Initialize report with values
+class Report:
+    def __init__(self, error=Exception, problem_level=0, problem_msg='', fix_msg=''):
+        """Initialize report with values
 
         Parameters
         ----------
@@ -214,7 +209,7 @@ class Report(object):
         self.fix_msg = fix_msg
 
     def __getstate__(self):
-        """ State that defines object
+        """State that defines object
 
         Returns
         -------
@@ -223,7 +218,7 @@ class Report(object):
         return self.error, self.problem_level, self.problem_msg, self.fix_msg
 
     def __eq__(self, other):
-        """ are two BatteryRunner-like objects equal?
+        """are two BatteryRunner-like objects equal?
 
         Parameters
         ----------
@@ -243,26 +238,25 @@ class Report(object):
         return self.__getstate__() == other.__getstate__()
 
     def __ne__(self, other):
-        """ are two BatteryRunner-like objects not equal?
+        """are two BatteryRunner-like objects not equal?
 
         See docstring for __eq__
         """
         return not self == other
 
     def __str__(self):
-        """ Printable string for object """
+        """Printable string for object"""
         return self.__dict__.__str__()
 
     @property
     def message(self):
-        """ formatted message string, including fix message if present
-        """
+        """formatted message string, including fix message if present"""
         if self.fix_msg:
             return '; '.join((self.problem_msg, self.fix_msg))
         return self.problem_msg
 
     def log_raise(self, logger, error_level=40):
-        """ Log problem, raise error if problem >= `error_level`
+        """Log problem, raise error if problem >= `error_level`
 
         Parameters
         ----------
@@ -277,7 +271,7 @@ class Report(object):
                 raise self.error(self.problem_msg)
 
     def write_raise(self, stream, error_level=40, log_level=30):
-        """ Write report to `stream`
+        """Write report to `stream`
 
         Parameters
         ----------
