@@ -1,12 +1,13 @@
-""" Utilties for casting numpy values in various ways
+"""Utilities for casting numpy values in various ways
 
 Most routines work round some numpy oddities in floating point precision and
 casting.  Others work round numpy casting to and from python ints
 """
+from __future__ import annotations
 
 import warnings
 from numbers import Integral
-from platform import processor, machine
+from platform import machine, processor
 
 import numpy as np
 
@@ -24,7 +25,7 @@ TRUNC_UINT64 = np.float64(_test_val).astype(np.uint64) != _test_val
 
 
 def float_to_int(arr, int_type, nan2zero=True, infmax=False):
-    """ Convert floating point array `arr` to type `int_type`
+    """Convert floating point array `arr` to type `int_type`
 
     * Rounds numbers to nearest integer
     * Clips values to prevent overflows when casting
@@ -110,11 +111,11 @@ def float_to_int(arr, int_type, nan2zero=True, infmax=False):
 
 
 # Cache range values
-_SHARED_RANGES = {}
+_SHARED_RANGES: dict[tuple[type, type], tuple[np.number, np.number]] = {}
 
 
 def shared_range(flt_type, int_type):
-    """ Min and max in float type that are >=min, <=max in integer type
+    """Min and max in float type that are >=min, <=max in integer type
 
     This is not as easy as it sounds, because the float type may not be able to
     exactly represent the max or min integer values, so we have to find the
@@ -132,7 +133,7 @@ def shared_range(flt_type, int_type):
     Returns
     -------
     mn : object
-        Number of type `flt_type` that is the minumum value in the range of
+        Number of type `flt_type` that is the minimum value in the range of
         `int_type`, such that ``mn.astype(int_type)`` >= min of `int_type`
     mx : object
         Number of type `flt_type` that is the maximum value in the range of
@@ -172,12 +173,13 @@ def shared_range(flt_type, int_type):
 # types.
 # ----------------------------------------------------------------------------
 
+
 class FloatingError(Exception):
     pass
 
 
 def on_powerpc():
-    """ True if we are running on a Power PC platform
+    """True if we are running on a Power PC platform
 
     Has to deal with older Macs and IBM POWER7 series among others
     """
@@ -185,7 +187,7 @@ def on_powerpc():
 
 
 def type_info(np_type):
-    """ Return dict with min, max, nexp, nmant, width for numpy type `np_type`
+    """Return dict with min, max, nexp, nmant, width for numpy type `np_type`
 
     Type can be integer in which case nexp and nmant are None.
 
@@ -225,20 +227,28 @@ def type_info(np_type):
     except ValueError:
         pass
     else:
-        return dict(min=np_type(info.min), max=np_type(info.max), minexp=None,
-                    maxexp=None, nmant=None, nexp=None, width=width)
+        return dict(
+            min=np_type(info.min),
+            max=np_type(info.max),
+            minexp=None,
+            maxexp=None,
+            nmant=None,
+            nexp=None,
+            width=width,
+        )
     info = np.finfo(dt)
     # Trust the standard IEEE types
     nmant, nexp = info.nmant, info.nexp
-    ret = dict(min=np_type(info.min),
-               max=np_type(info.max),
-               nmant=nmant,
-               nexp=nexp,
-               minexp=info.minexp,
-               maxexp=info.maxexp,
-               width=width)
-    if np_type in (np.float16, np.float32, np.float64,
-                   np.complex64, np.complex128):
+    ret = dict(
+        min=np_type(info.min),
+        max=np_type(info.max),
+        nmant=nmant,
+        nexp=nexp,
+        minexp=info.minexp,
+        maxexp=info.maxexp,
+        width=width,
+    )
+    if np_type in (np.float16, np.float32, np.float64, np.complex64, np.complex128):
         return ret
     info_64 = np.finfo(np.float64)
     if dt.kind == 'c':
@@ -247,16 +257,18 @@ def type_info(np_type):
     else:
         assert np_type is np.longdouble
         vals = (nmant, nexp, width)
-    if vals in ((112, 15, 16),  # binary128
-                (info_64.nmant, info_64.nexp, 8),  # float64
-                (63, 15, 12), (63, 15, 16)):  # Intel extended 80
+    if vals in (
+        (112, 15, 16),  # binary128
+        (info_64.nmant, info_64.nexp, 8),  # float64
+        (63, 15, 12),  # Intel extended 80
+        (63, 15, 16),  # Intel extended 80
+    ):
         return ret  # these are OK without modification
     # The remaining types are longdoubles with bad finfo values.  Some we
     # correct, others we wait to hear of errors.
     # We start with float64 as basis
     ret = type_info(np.float64)
-    if vals in ((52, 15, 12),  # windows float96
-                (52, 15, 16)):  # windows float128?
+    if vals in ((52, 15, 12), (52, 15, 16)):  # windows float96 / windows float128?
         # On windows 32 bit at least, float96 is Intel 80 storage but operating
         # at float64 precision. The finfo values give nexp == 15 (as for intel
         # 80) but in calculations nexp in fact appears to be 11 as for float64
@@ -270,39 +282,38 @@ def type_info(np_type):
     # their complex equivalent.
     if np_type not in (np.longdouble, np.longcomplex) or width not in (16, 32):
         raise FloatingError(f'We had not expected type {np_type}')
-    if (vals == (1, 1, 16) and on_powerpc() and
-            _check_maxexp(np.longdouble, 1024)):
+    if vals == (1, 1, 16) and on_powerpc() and _check_maxexp(np.longdouble, 1024):
         # double pair on PPC.  The _check_nmant routine does not work for this
         # type, hence the powerpc platform check instead
         ret.update(dict(nmant=106, width=width))
-    elif (_check_nmant(np.longdouble, 52) and
-          _check_maxexp(np.longdouble, 11)):
+    elif _check_nmant(np.longdouble, 52) and _check_maxexp(np.longdouble, 11):
         # Got float64 despite everything
         pass
-    elif (_check_nmant(np.longdouble, 112) and
-          _check_maxexp(np.longdouble, 16384)):
+    elif _check_nmant(np.longdouble, 112) and _check_maxexp(np.longdouble, 16384):
         # binary 128, but with some busted type information. np.longcomplex
         # seems to break here too, so we need to use np.longdouble and
         # complexify
         two = np.longdouble(2)
         # See: https://matthew-brett.github.io/pydagogue/floating_point.html
-        max_val = (two ** 113 - 1) / (two ** 112) * two ** 16383
+        max_val = (two**113 - 1) / (two**112) * two**16383
         if np_type is np.longcomplex:
             max_val += 0j
-        ret = dict(min=-max_val,
-                   max=max_val,
-                   nmant=112,
-                   nexp=15,
-                   minexp=-16382,
-                   maxexp=16384,
-                   width=width)
+        ret = dict(
+            min=-max_val,
+            max=max_val,
+            nmant=112,
+            nexp=15,
+            minexp=-16382,
+            maxexp=16384,
+            width=width,
+        )
     else:  # don't recognize the type
         raise FloatingError(f'We had not expected long double type {np_type} with info {info}')
     return ret
 
 
 def _check_nmant(np_type, nmant):
-    """ True if fp type `np_type` seems to have `nmant` significand digits
+    """True if fp type `np_type` seems to have `nmant` significand digits
 
     Note 'digits' does not include implicit digits.  And in fact if there are
     no implicit digits, the `nmant` number is one less than the actual digits.
@@ -328,7 +339,7 @@ def _check_nmant(np_type, nmant):
 
 
 def _check_maxexp(np_type, maxexp):
-    """ True if fp type `np_type` seems to have `maxexp` maximum exponent
+    """True if fp type `np_type` seems to have `maxexp` maximum exponent
 
     We're testing "maxexp" as returned by numpy. This value is set to one
     greater than the maximum power of 2 that `np_type` can represent.
@@ -351,12 +362,12 @@ def _check_maxexp(np_type, maxexp):
     np_type = dt.type
     two = np_type(2).reshape((1,))  # to avoid upcasting
     with warnings.catch_warnings():
-        warnings.simplefilter("ignore", RuntimeWarning)  # Expected overflow warning
-        return np.isfinite(two ** (maxexp - 1)) and not np.isfinite(two ** maxexp)
+        warnings.simplefilter('ignore', RuntimeWarning)  # Expected overflow warning
+        return np.isfinite(two ** (maxexp - 1)) and not np.isfinite(two**maxexp)
 
 
 def as_int(x, check=True):
-    """ Return python integer representation of number
+    """Return python integer representation of number
 
     This is useful because the numpy int(val) mechanism is broken for large
     values in np.longdouble.
@@ -417,7 +428,7 @@ def as_int(x, check=True):
 
 
 def int_to_float(val, flt_type):
-    """ Convert integer `val` to floating point type `flt_type`
+    """Convert integer `val` to floating point type `flt_type`
 
     Why is this so complicated?
 
@@ -454,7 +465,7 @@ def int_to_float(val, flt_type):
 
 
 def floor_exact(val, flt_type):
-    """ Return nearest exact integer <= `val` in float type `flt_type`
+    """Return nearest exact integer <= `val` in float type `flt_type`
 
     Parameters
     ----------
@@ -508,14 +519,14 @@ def floor_exact(val, flt_type):
     if diff >= 0:  # floating point value <= val
         return fval
     # Float casting made the value go up
-    biggest_gap = 2**(floor_log2(val) - info['nmant'])
+    biggest_gap = 2 ** (floor_log2(val) - info['nmant'])
     assert biggest_gap > 1
     fval -= flt_type(biggest_gap)
     return fval
 
 
 def ceil_exact(val, flt_type):
-    """ Return nearest exact integer >= `val` in float type `flt_type`
+    """Return nearest exact integer >= `val` in float type `flt_type`
 
     Parameters
     ----------
@@ -559,7 +570,7 @@ def ceil_exact(val, flt_type):
 
 
 def int_abs(arr):
-    """ Absolute values of array taking care of max negative int values
+    """Absolute values of array taking care of max negative int values
 
     Parameters
     ----------
@@ -599,7 +610,7 @@ def int_abs(arr):
 
 
 def floor_log2(x):
-    """ floor of log2 of abs(`x`)
+    """floor of log2 of abs(`x`)
 
     Embarrassingly, from https://en.wikipedia.org/wiki/Binary_logarithm
 
@@ -639,7 +650,7 @@ def floor_log2(x):
 
 
 def best_float():
-    """ Floating point type with best precision
+    """Floating point type with best precision
 
     This is nearly always np.longdouble, except on Windows, where np.longdouble
     is Intel80 storage, but with float64 precision for calculations.  In that
@@ -662,15 +673,15 @@ def best_float():
         long_info = type_info(np.longdouble)
     except FloatingError:
         return np.float64
-    if (long_info['nmant'] > type_info(np.float64)['nmant'] and
-            machine() != 'sparc64'):  # sparc has crazy-slow float128
+    if (
+        long_info['nmant'] > type_info(np.float64)['nmant'] and machine() != 'sparc64'
+    ):  # sparc has crazy-slow float128
         return np.longdouble
     return np.float64
 
 
 def longdouble_lte_float64():
-    """ Return True if longdouble appears to have the same precision as float64
-    """
+    """Return True if longdouble appears to have the same precision as float64"""
     return np.longdouble(2**53) == np.longdouble(2**53) + 1
 
 
@@ -679,7 +690,7 @@ _LD_LTE_FLOAT64 = longdouble_lte_float64()
 
 
 def longdouble_precision_improved():
-    """ True if longdouble precision increased since initial import
+    """True if longdouble precision increased since initial import
 
     This can happen on Windows compiled with MSVC.  It may be because libraries
     compiled with mingw (longdouble is Intel80) get linked to numpy compiled
@@ -689,8 +700,7 @@ def longdouble_precision_improved():
 
 
 def have_binary128():
-    """ True if we have a binary128 IEEE longdouble
-    """
+    """True if we have a binary128 IEEE longdouble"""
     try:
         ti = type_info(np.longdouble)
     except FloatingError:
@@ -699,7 +709,7 @@ def have_binary128():
 
 
 def ok_floats():
-    """ Return floating point types sorted by precision
+    """Return floating point types sorted by precision
 
     Remove longdouble if it has no higher precision than float64
     """
@@ -714,7 +724,7 @@ OK_FLOATS = ok_floats()
 
 
 def able_int_type(values):
-    """ Find the smallest integer numpy type to contain sequence `values`
+    """Find the smallest integer numpy type to contain sequence `values`
 
     Prefers uint to int if minimum is >= 0
 
@@ -751,7 +761,7 @@ def able_int_type(values):
 
 
 def ulp(val=np.float64(1.0)):
-    """ Return gap between `val` and nearest representable number of same type
+    """Return gap between `val` and nearest representable number of same type
 
     This is the value of a unit in the last place (ULP), and is similar in
     meaning to the MATLAB eps function.
@@ -785,4 +795,4 @@ def ulp(val=np.float64(1.0)):
     if fl2 is None or fl2 < info['minexp']:  # subnormal
         fl2 = info['minexp']
     # 'nmant' value does not include implicit first bit
-    return 2**(fl2 - info['nmant'])
+    return 2 ** (fl2 - info['nmant'])
