@@ -1,136 +1,233 @@
 """Code for PAR/REC to NIfTI converter command
 """
 
-from optparse import OptionParser, Option
+import csv
+import os
+import sys
+from optparse import Option, OptionParser
+
 import numpy as np
 import numpy.linalg as npl
-import sys
-import os
-import csv
+
 import nibabel
-import nibabel.parrec as pr
-from nibabel.parrec import one_line
-from nibabel.mriutils import calculate_dwell_time, MRIError
 import nibabel.nifti1 as nifti1
-from nibabel.filename_parser import splitext_addext
-from nibabel.volumeutils import fname_ext_ul_case
-from nibabel.orientations import (io_orientation, inv_ornt_aff,
-                                  apply_orientation)
+import nibabel.parrec as pr
 from nibabel.affines import apply_affine, from_matvec, to_matvec
+from nibabel.filename_parser import splitext_addext
+from nibabel.mriutils import MRIError, calculate_dwell_time
+from nibabel.orientations import apply_orientation, inv_ornt_aff, io_orientation
+from nibabel.parrec import one_line
+from nibabel.volumeutils import fname_ext_ul_case
 
 
 def get_opt_parser():
     # use module docstring for help output
     p = OptionParser(
-        usage=f"{sys.argv[0]} [OPTIONS] <PAR files>\n\n" + __doc__,
-        version="%prog " + nibabel.__version__)
+        usage=f'{sys.argv[0]} [OPTIONS] <PAR files>\n\n' + __doc__,
+        version='%prog ' + nibabel.__version__,
+    )
     p.add_option(
-        Option("-v", "--verbose", action="store_true", dest="verbose",
-               default=False,
-               help="""Make some noise."""))
+        Option(
+            '-v',
+            '--verbose',
+            action='store_true',
+            dest='verbose',
+            default=False,
+            help="""Make some noise.""",
+        )
+    )
     p.add_option(
-        Option("-o", "--output-dir", action="store", type="string",
-               dest="outdir", default=None,
-               help=one_line("""Destination directory for NIfTI files.
-                             Default: current directory.""")))
+        Option(
+            '-o',
+            '--output-dir',
+            action='store',
+            type='string',
+            dest='outdir',
+            default=None,
+            help='Destination directory for NIfTI files. Default: current directory.',
+        )
+    )
     p.add_option(
-        Option("-c", "--compressed", action="store_true",
-               dest="compressed", default=False,
-               help="Whether to write compressed NIfTI files or not."))
+        Option(
+            '-c',
+            '--compressed',
+            action='store_true',
+            dest='compressed',
+            default=False,
+            help='Whether to write compressed NIfTI files or not.',
+        )
+    )
     p.add_option(
-        Option("-p", "--permit-truncated", action="store_true",
-               dest="permit_truncated", default=False,
-               help=one_line(
-                   """Permit conversion of truncated recordings. Support for
+        Option(
+            '-p',
+            '--permit-truncated',
+            action='store_true',
+            dest='permit_truncated',
+            default=False,
+            help=one_line(
+                """Permit conversion of truncated recordings. Support for
                    this is experimental, and results *must* be checked
-                   afterward for validity.""")))
+                   afterward for validity."""
+            ),
+        )
+    )
     p.add_option(
-        Option("-b", "--bvs", action="store_true", dest="bvs", default=False,
-               help=one_line(
-                   """Output bvals/bvecs files in addition to NIFTI
-                   image.""")))
+        Option(
+            '-b',
+            '--bvs',
+            action='store_true',
+            dest='bvs',
+            default=False,
+            help='Output bvals/bvecs files in addition to NIFTI image.',
+        )
+    )
     p.add_option(
-        Option("-d", "--dwell-time", action="store_true", default=False,
-               dest="dwell_time",
-               help=one_line(
-                   """Calculate the scan dwell time. If supplied, the magnetic
+        Option(
+            '-d',
+            '--dwell-time',
+            action='store_true',
+            default=False,
+            dest='dwell_time',
+            help=one_line(
+                """Calculate the scan dwell time. If supplied, the magnetic
                    field strength should also be supplied using
                    --field-strength (default 3). The field strength must be
                    supplied because it is not encoded in the PAR/REC
-                   format.""")))
+                   format."""
+            ),
+        )
+    )
     p.add_option(
-        Option("--field-strength", action="store", type="float",
-               dest="field_strength",
-               help=one_line(
-                   """The magnetic field strength of the recording, only needed
+        Option(
+            '--field-strength',
+            action='store',
+            type='float',
+            dest='field_strength',
+            help=one_line(
+                """The magnetic field strength of the recording, only needed
                    for --dwell-time. The field strength must be supplied
-                   because it is not encoded in the PAR/REC format.""")))
+                   because it is not encoded in the PAR/REC format."""
+            ),
+        )
+    )
     p.add_option(
-        Option("-i", "--volume-info", action="store_true", dest="vol_info",
-               default=False,
-               help=one_line(
-                   """Export .PAR volume labels corresponding to the fourth
+        Option(
+            '-i',
+            '--volume-info',
+            action='store_true',
+            dest='vol_info',
+            default=False,
+            help=one_line(
+                """Export .PAR volume labels corresponding to the fourth
                    dimension of the data.  The dimension info will be stored in
                    CSV format with the first row containing dimension labels
                    and the subsequent rows (one per volume), the corresponding
                    indices.  Only labels that vary along the 4th dimension are
                    exported (e.g. for a single volume structural scan there
                    are no dynamic labels and no output file will be created).
-                   """)))
+                   """
+            ),
+        )
+    )
     p.add_option(
-        Option("--origin", action="store", dest="origin", default="scanner",
-               help=one_line(
-                   """Reference point of the q-form transformation of the NIfTI
+        Option(
+            '--origin',
+            action='store',
+            dest='origin',
+            default='scanner',
+            help=one_line(
+                """Reference point of the q-form transformation of the NIfTI
                    image. If 'scanner' the (0,0,0) coordinates will refer to
                    the scanner's iso center. If 'fov', this coordinate will be
                    the center of the recorded volume (field of view). Default:
-                   'scanner'.""")))
+                   'scanner'."""
+            ),
+        )
+    )
     p.add_option(
-        Option("--minmax", action="store", nargs=2, dest="minmax",
-               help=one_line(
-                   """Minimum and maximum settings to be stored in the NIfTI
+        Option(
+            '--minmax',
+            action='store',
+            nargs=2,
+            dest='minmax',
+            help=one_line(
+                """Minimum and maximum settings to be stored in the NIfTI
                    header. If any of them is set to 'parse', the scaled data is
                    scanned for the actual minimum and maximum.  To bypass this
                    potentially slow and memory intensive step (the data has to
                    be scaled and fully loaded into memory), fixed values can be
                    provided as space-separated pair, e.g. '5.4 120.4'. It is
                    possible to set a fixed minimum as scan for the actual
-                   maximum (and vice versa). Default: 'parse parse'.""")))
+                   maximum (and vice versa). Default: 'parse parse'."""
+            ),
+        )
+    )
     p.set_defaults(minmax=('parse', 'parse'))
     p.add_option(
-        Option("--store-header", action="store_true", dest="store_header",
-               default=False,
-               help=one_line(
-                   """If set, all information from the PAR header is stored in
-                   an extension of the NIfTI file header.  Default: off""")))
+        Option(
+            '--store-header',
+            action='store_true',
+            dest='store_header',
+            default=False,
+            help=one_line(
+                """If set, all information from the PAR header is stored in
+                   an extension of the NIfTI file header.  Default: off"""
+            ),
+        )
+    )
     p.add_option(
-        Option("--scaling", action="store", dest="scaling", default='dv',
-               help=one_line(
-                   """Choose data scaling setting. The PAR header defines two
+        Option(
+            '--scaling',
+            action='store',
+            dest='scaling',
+            default='dv',
+            help=one_line(
+                """Choose data scaling setting. The PAR header defines two
                    different data scaling settings: 'dv' (values displayed on
                    console) and 'fp' (floating point values). Either one can be
                    chosen, or scaling can be disabled completely ('off').  Note
                    that neither method will actually scale the data, but just
                    store the corresponding settings in the NIfTI header, unless
                    non-uniform scaling is used, in which case the data is
-                   stored in the file in scaled form. Default: 'dv'""")))
+                   stored in the file in scaled form. Default: 'dv'"""
+            ),
+        )
+    )
     p.add_option(
-        Option('--keep-trace', action="store_true", dest='keep_trace',
-               default=False,
-               help=one_line("""Do not discard the diagnostic Philips DTI
-                             trace volume, if it exists in the data.""")))
+        Option(
+            '--keep-trace',
+            action='store_true',
+            dest='keep_trace',
+            default=False,
+            help=one_line(
+                """Do not discard the diagnostic Philips DTI
+                   trace volume, if it exists in the data."""
+            ),
+        )
+    )
     p.add_option(
-        Option("--overwrite", action="store_true", dest="overwrite",
-               default=False,
-               help=one_line("""Overwrite file if it exists. Default:
-                             False""")))
+        Option(
+            '--overwrite',
+            action='store_true',
+            dest='overwrite',
+            default=False,
+            help='Overwrite file if it exists. Default: False',
+        )
+    )
     p.add_option(
-        Option("--strict-sort", action="store_true", dest="strict_sort",
-               default=False,
-               help=one_line("""Use additional keys in determining the order
+        Option(
+            '--strict-sort',
+            action='store_true',
+            dest='strict_sort',
+            default=False,
+            help=one_line(
+                """Use additional keys in determining the order
                 to sort the slices within the .REC file.  This may be necessary
                 for more complicated scans with multiple echos,
-                cardiac phases, ASL label states, etc.""")))
+                cardiac phases, ASL label states, etc."""
+            ),
+        )
+    )
     return p
 
 
@@ -158,15 +255,17 @@ def proc_file(infile, opts):
     else:
         outfilename = basefilename + '.nii'
     if os.path.isfile(outfilename) and not opts.overwrite:
-        raise IOError(f'Output file "{outfilename}" exists, use --overwrite to overwrite it')
+        raise OSError(f'Output file "{outfilename}" exists, use --overwrite to overwrite it')
 
     # load the PAR header and data
     scaling = 'dv' if opts.scaling == 'off' else opts.scaling
     infile = fname_ext_ul_case(infile)
-    pr_img = pr.load(infile,
-                     permit_truncated=opts.permit_truncated,
-                     scaling=scaling,
-                     strict_sort=opts.strict_sort)
+    pr_img = pr.load(
+        infile,
+        permit_truncated=opts.permit_truncated,
+        scaling=scaling,
+        strict_sort=opts.strict_sort,
+    )
     pr_hdr = pr_img.header
     affine = pr_hdr.get_affine(origin=opts.origin)
     slope, intercept = pr_hdr.get_data_scaling(scaling)
@@ -174,8 +273,8 @@ def proc_file(infile, opts):
         verbose(f'Using data scaling "{opts.scaling}"')
     # get original scaling, and decide if we scale in-place or not
     if opts.scaling == 'off':
-        slope = np.array([1.])
-        intercept = np.array([0.])
+        slope = np.array([1.0])
+        intercept = np.array([0.0])
         in_data = pr_img.dataobj.get_unscaled()
         out_dtype = pr_hdr.get_data_dtype()
     elif not np.any(np.diff(slope)) and not np.any(np.diff(intercept)):
@@ -186,15 +285,20 @@ def proc_file(infile, opts):
         out_dtype = pr_hdr.get_data_dtype()
     else:
         # Multi scalefactor case
-        slope = np.array([1.])
-        intercept = np.array([0.])
+        slope = np.array([1.0])
+        intercept = np.array([0.0])
         in_data = np.array(pr_img.dataobj)
         out_dtype = np.float64
     # Reorient data block to LAS+ if necessary
     ornt = io_orientation(np.diag([-1, 1, 1, 1]).dot(affine))
-    if np.all(ornt == [[0, 1],
-                       [1, 1],
-                       [2, 1]]):  # already in LAS+
+    if np.array_equal(
+        ornt,
+        [
+            [0, 1],
+            [1, 1],
+            [2, 1],
+        ],
+    ):  # already in LAS+
         t_aff = np.eye(4)
     else:  # Not in LAS+
         t_aff = inv_ornt_aff(ornt, pr_img.shape)
@@ -249,8 +353,10 @@ def proc_file(infile, opts):
         if bvals is None and bvecs is None:
             verbose('No DTI volumes detected, bvals and bvecs not written')
         elif bvecs is None:
-            verbose('DTI volumes detected, but no diffusion direction info was'
-                    'found.  Writing .bvals file only.')
+            verbose(
+                'DTI volumes detected, but no diffusion direction info was'
+                'found.  Writing .bvals file only.'
+            )
             with open(basefilename + '.bvals', 'w') as fid:
                 # np.savetxt could do this, but it's just a loop anyway
                 for val in bvals:
@@ -288,14 +394,15 @@ def proc_file(infile, opts):
     if opts.dwell_time:
         try:
             dwell_time = calculate_dwell_time(
-                pr_hdr.get_water_fat_shift(),
-                pr_hdr.get_echo_train_length(),
-                opts.field_strength)
+                pr_hdr.get_water_fat_shift(), pr_hdr.get_echo_train_length(), opts.field_strength
+            )
         except MRIError:
             verbose('No EPI factors, dwell time not written')
         else:
-            verbose(f'Writing dwell time ({dwell_time!r} sec) '
-                    f'calculated assuming {opts.field_strength}T magnet')
+            verbose(
+                f'Writing dwell time ({dwell_time!r} sec) '
+                f'calculated assuming {opts.field_strength}T magnet'
+            )
             with open(basefilename + '.dwell_time', 'w') as fid:
                 fid.write(f'{dwell_time!r}\n')
     # done
@@ -322,7 +429,6 @@ def main():
             errs.append(f'{infile}: {e}')
 
     if len(errs):
-        error('Caught %i exceptions. Dump follows:\n\n %s'
-              % (len(errs), '\n'.join(errs)), 1)
+        error(f'Caught {len(errs)} exceptions. Dump follows:\n\n' + '\n'.join(errs), 1)
     else:
         verbose('Done')
