@@ -1,24 +1,24 @@
 """
 Convert tractograms (TCK -> TRK).
 """
-import os
 import argparse
+import os
 
 import nibabel as nib
-
-from nibabel.streamlines import Field
 from nibabel.orientations import aff2axcodes
+from nibabel.streamlines import Field
 
 
 def parse_args():
-    DESCRIPTION = "Convert tractograms (TCK -> TRK)."
+    DESCRIPTION = 'Convert tractograms (TCK -> TRK).'
     parser = argparse.ArgumentParser(description=DESCRIPTION)
-    parser.add_argument("anatomy",
-                        help="reference anatomical image (.nii|.nii.gz.")
-    parser.add_argument("tractograms", metavar="tractogram", nargs="+",
-                        help="list of tractograms (.tck).")
-    parser.add_argument("-f", "--force", action="store_true",
-                        help="overwrite existing output files.")
+    parser.add_argument('anatomy', help='reference anatomical image (.nii|.nii.gz.')
+    parser.add_argument(
+        'tractograms', metavar='tractogram', nargs='+', help='list of tractograms (.tck).'
+    )
+    parser.add_argument(
+        '-f', '--force', action='store_true', help='overwrite existing output files.'
+    )
 
     args = parser.parse_args()
     return args, parser
@@ -30,7 +30,7 @@ def main():
     try:
         nii = nib.load(args.anatomy)
     except Exception:
-        parser.error("Expecting anatomical image as first agument.")
+        parser.error('Expecting anatomical image as first argument.')
 
     for tractogram in args.tractograms:
         tractogram_format = nib.streamlines.detect_format(tractogram)
@@ -49,7 +49,7 @@ def main():
         header[Field.VOXEL_TO_RASMM] = nii.affine.copy()
         header[Field.VOXEL_SIZES] = nii.header.get_zooms()[:3]
         header[Field.DIMENSIONS] = nii.shape[:3]
-        header[Field.VOXEL_ORDER] = "".join(aff2axcodes(nii.affine))
+        header[Field.VOXEL_ORDER] = ''.join(aff2axcodes(nii.affine))
 
         tck = nib.streamlines.load(tractogram)
         nib.streamlines.save(tck.tractogram, output_filename, header=header)
