@@ -13,9 +13,9 @@ import unittest
 import pytest
 
 import nibabel as nib
-from nibabel.testing import test_data
 from nibabel.cmdline.conform import main
 from nibabel.optpkg import optional_package
+from nibabel.testing import test_data
 
 _, have_scipy, _ = optional_package('scipy.ndimage')
 needs_scipy = unittest.skipUnless(have_scipy, 'These tests need scipy')
@@ -23,8 +23,8 @@ needs_scipy = unittest.skipUnless(have_scipy, 'These tests need scipy')
 
 @needs_scipy
 def test_default(tmpdir):
-    infile = test_data(fname="anatomical.nii")
-    outfile = tmpdir / "output.nii.gz"
+    infile = test_data(fname='anatomical.nii')
+    outfile = tmpdir / 'output.nii.gz'
     main([str(infile), str(outfile)])
     assert outfile.isfile()
     c = nib.load(outfile)
@@ -35,19 +35,21 @@ def test_default(tmpdir):
     with pytest.raises(FileExistsError):
         main([str(infile), str(outfile)])
 
-    main([str(infile), str(outfile), "--force"])
+    main([str(infile), str(outfile), '--force'])
     assert outfile.isfile()
 
 
 @needs_scipy
 def test_nondefault(tmpdir):
-    infile = test_data(fname="anatomical.nii")
-    outfile = tmpdir / "output.nii.gz"
+    infile = test_data(fname='anatomical.nii')
+    outfile = tmpdir / 'output.nii.gz'
     out_shape = (100, 100, 150)
     voxel_size = (1, 2, 4)
-    orientation = "LAS"
-    args = (f"{infile} {outfile} --out-shape {' '.join(map(str, out_shape))} "
-            f"--voxel-size {' '.join(map(str, voxel_size))} --orientation {orientation}")
+    orientation = 'LAS'
+    args = (
+        f"{infile} {outfile} --out-shape {' '.join(map(str, out_shape))} "
+        f"--voxel-size {' '.join(map(str, voxel_size))} --orientation {orientation}"
+    )
     main(args.split())
     assert outfile.isfile()
     c = nib.load(outfile)
