@@ -1,4 +1,4 @@
-""" File-based images that have data arrays
+"""File-based images that have data arrays
 
 The class:`DataObjImage` class defines an image that extends the
 :class:`FileBasedImage` by adding an array-like object, named ``dataobj``.
@@ -7,18 +7,34 @@ This can either be an actual numpy array, or an object that:
 * returns an array from ``numpy.asanyarray(obj)``;
 * has an attribute or property ``shape``.
 """
+from __future__ import annotations
+
+import typing as ty
 
 import numpy as np
 
-from .filebasedimages import FileBasedImage
+from .arrayproxy import ArrayLike
 from .deprecated import deprecate_with_version
+from .filebasedimages import FileBasedHeader, FileBasedImage, FileMap, FileSpec
+
+if ty.TYPE_CHECKING:  # pragma: no cover
+    import numpy.typing as npt
 
 
 class DataobjImage(FileBasedImage):
-    """ Template class for images that have dataobj data stores"""
+    """Template class for images that have dataobj data stores"""
 
-    def __init__(self, dataobj, header=None, extra=None, file_map=None):
-        """ Initialize dataobj image
+    _data_cache: np.ndarray | None
+    _fdata_cache: np.ndarray | None
+
+    def __init__(
+        self,
+        dataobj: ArrayLike,
+        header: FileBasedHeader | ty.Mapping | None = None,
+        extra: ty.Mapping | None = None,
+        file_map: FileMap | None = None,
+    ):
+        """Initialize dataobj image
 
         The datobj image is a combination of (dataobj, header), with optional
         metadata in `extra`, and filename / file-like objects contained in the
@@ -27,9 +43,9 @@ class DataobjImage(FileBasedImage):
         Parameters
         ----------
         dataobj : object
-           Object containg image data.  It should be some object that retuns an
-           array from ``np.asanyarray``.  It should have ``shape`` and ``ndim``
-           attributes or properties
+           Object containing image data.  It should be some object that returns
+           an array from ``np.asanyarray``.  It should have ``shape`` and
+           ``ndim`` attributes or properties
         header : None or mapping or header instance, optional
            metadata for this image format
         extra : None or mapping, optional
@@ -38,30 +54,23 @@ class DataobjImage(FileBasedImage):
         file_map : mapping, optional
            mapping giving file information for this image format
         """
-        super(DataobjImage, self).__init__(header=header, extra=extra,
-                                           file_map=file_map)
+        super().__init__(header=header, extra=extra, file_map=file_map)
         self._dataobj = dataobj
-        self._fdata_cache = None
         self._data_cache = None
+        self._fdata_cache = None
 
     @property
-    def dataobj(self):
+    def dataobj(self) -> ArrayLike:
         return self._dataobj
 
-    @property
-    @deprecate_with_version('_data attribute not part of public API. '
-                            'please use "dataobj" property instead.',
-                            '2.0', '4.0')
-    def _data(self):
-        return self._dataobj
-
-    @deprecate_with_version('get_data() is deprecated in favor of get_fdata(),'
-                            ' which has a more predictable return type. To '
-                            'obtain get_data() behavior going forward, use '
-                            'numpy.asanyarray(img.dataobj).',
-                            '3.0', '5.0')
+    @deprecate_with_version(
+        'get_data() is deprecated in favor of get_fdata(), which has a more predictable return '
+        'type. To obtain get_data() behavior going forward, use numpy.asanyarray(img.dataobj).',
+        '3.0',
+        '5.0',
+    )
     def get_data(self, caching='fill'):
-        """ Return image data from image with any necessary scaling applied
+        """Return image data from image with any necessary scaling applied
 
         .. WARNING::
 
@@ -209,8 +218,12 @@ class DataobjImage(FileBasedImage):
             self._data_cache = data
         return data
 
-    def get_fdata(self, caching='fill', dtype=np.float64):
-        """ Return floating point image data with necessary scaling applied
+    def get_fdata(
+        self,
+        caching: ty.Literal['fill', 'unchanged'] = 'fill',
+        dtype: npt.DTypeLike = np.float64,
+    ) -> np.ndarray:
+        """Return floating point image data with necessary scaling applied
 
         The image ``dataobj`` property can be an array proxy or an array.  An
         array proxy is an object that knows how to load the image data from
@@ -358,18 +371,20 @@ class DataobjImage(FileBasedImage):
         return data
 
     @property
-    def in_memory(self):
-        """ True when any array data is in memory cache
+    def in_memory(self) -> bool:
+        """True when any array data is in memory cache
 
         There are separate caches for `get_data` reads and `get_fdata` reads.
         This property is True if either of those caches are set.
         """
-        return (isinstance(self._dataobj, np.ndarray) or
-                self._fdata_cache is not None or
-                self._data_cache is not None)
+        return (
+            isinstance(self._dataobj, np.ndarray)
+            or self._fdata_cache is not None
+            or self._data_cache is not None
+        )
 
-    def uncache(self):
-        """ Delete any cached read of data from proxied data
+    def uncache(self) -> None:
+        """Delete any cached read of data from proxied data
 
         Remember there are two types of images:
 
@@ -397,29 +412,22 @@ class DataobjImage(FileBasedImage):
         self._data_cache = None
 
     @property
-    def shape(self):
+    def shape(self) -> tuple[int, ...]:
         return self._dataobj.shape
 
     @property
-    def ndim(self):
+    def ndim(self) -> int:
         return self._dataobj.ndim
 
-    @deprecate_with_version('get_shape method is deprecated.\n'
-                            'Please use the ``img.shape`` property '
-                            'instead.',
-                            '1.2', '3.0')
-    def get_shape(self):
-        """ Return shape for image
-        """
-        return self.shape
-
     @classmethod
-    def from_file_map(klass, file_map, *, mmap=True, keep_file_open=None):
-        """ Class method to create image from mapping in ``file_map``
-
-        .. deprecated:: 2.4.1
-            ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It raises an error as of nibabel 3.0.
+    def from_file_map(
+        klass,
+        file_map: FileMap,
+        *,
+        mmap: bool | ty.Literal['c', 'r'] = True,
+        keep_file_open: bool | None = None,
+    ):
+        """Class method to create image from mapping in ``file_map``
 
         Parameters
         ----------
@@ -451,13 +459,15 @@ class DataobjImage(FileBasedImage):
         raise NotImplementedError
 
     @classmethod
-    def from_filename(klass, filename, *, mmap=True, keep_file_open=None):
+    def from_filename(
+        klass,
+        filename: FileSpec,
+        *,
+        mmap: bool | ty.Literal['c', 'r'] = True,
+        keep_file_open: bool | None = None,
+    ):
         """Class method to create image from filename `filename`
 
-        .. deprecated:: 2.4.1
-            ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It raises an error as of nibabel 3.0.
-
         Parameters
         ----------
         filename : str
@@ -485,7 +495,6 @@ class DataobjImage(FileBasedImage):
         if mmap not in (True, False, 'c', 'r'):
             raise ValueError("mmap should be one of {True, False, 'c', 'r'}")
         file_map = klass.filespec_to_file_map(filename)
-        return klass.from_file_map(file_map, mmap=mmap,
-                                   keep_file_open=keep_file_open)
+        return klass.from_file_map(file_map, mmap=mmap, keep_file_open=keep_file_open)
 
     load = from_filename
