@@ -1,9 +1,9 @@
-""" Class for recording and reporting deprecations
+"""Class for recording and reporting deprecations
 """
 
 import functools
-import warnings
 import re
+import warnings
 
 _LEADING_WHITE = re.compile(r'^(\s*)')
 
@@ -29,16 +29,17 @@ TESTCLEANUP = """
 
 
 class ExpiredDeprecationError(RuntimeError):
-    """ Error for expired deprecation
+    """Error for expired deprecation
 
     Error raised when a called function or method has passed out of its
     deprecation period.
     """
+
     pass
 
 
 def _ensure_cr(text):
-    """ Remove trailing whitespace and add carriage return
+    """Remove trailing whitespace and add carriage return
 
     Ensures that `text` always ends with a carriage return
     """
@@ -46,7 +47,7 @@ def _ensure_cr(text):
 
 
 def _add_dep_doc(old_doc, dep_doc, setup='', cleanup=''):
-    """ Add deprecation message `dep_doc` to docstring in `old_doc`
+    """Add deprecation message `dep_doc` to docstring in `old_doc`
 
     Parameters
     ----------
@@ -79,12 +80,13 @@ def _add_dep_doc(old_doc, dep_doc, setup='', cleanup=''):
     setup_lines = [indent + L for L in setup.splitlines()]
     dep_lines = [indent + L for L in [''] + dep_doc.splitlines() + ['']]
     cleanup_lines = [indent + L for L in cleanup.splitlines()]
-    return '\n'.join(new_lines + dep_lines + setup_lines +
-                     old_lines[next_line:] + cleanup_lines + [''])
+    return '\n'.join(
+        new_lines + dep_lines + setup_lines + old_lines[next_line:] + cleanup_lines + ['']
+    )
 
 
-class Deprecator(object):
-    """ Class to make decorator marking function or method as deprecated
+class Deprecator:
+    """Class to make decorator marking function or method as deprecated
 
     The decorated function / method will:
 
@@ -109,16 +111,18 @@ class Deprecator(object):
         given argument of ``until`` in the ``__call__`` method (see below).
     """
 
-    def __init__(self,
-                 version_comparator,
-                 warn_class=DeprecationWarning,
-                 error_class=ExpiredDeprecationError):
+    def __init__(
+        self,
+        version_comparator,
+        warn_class=DeprecationWarning,
+        error_class=ExpiredDeprecationError,
+    ):
         self.version_comparator = version_comparator
         self.warn_class = warn_class
         self.error_class = error_class
 
     def is_bad_version(self, version_str):
-        """ Return True if `version_str` is too high
+        """Return True if `version_str` is too high
 
         Tests `version_str` with ``self.version_comparator``
 
@@ -135,9 +139,8 @@ class Deprecator(object):
         """
         return self.version_comparator(version_str) == -1
 
-    def __call__(self, message, since='', until='',
-                 warn_class=None, error_class=None):
-        """ Return decorator function function for deprecation warning / error
+    def __call__(self, message, since='', until='', warn_class=None, error_class=None):
+        """Return decorator function function for deprecation warning / error
 
         Parameters
         ----------
@@ -161,20 +164,21 @@ class Deprecator(object):
         deprecator : func
             Function returning a decorator.
         """
-        warn_class = warn_class if warn_class else self.warn_class
-        error_class = error_class if error_class else self.error_class
+        warn_class = warn_class or self.warn_class
+        error_class = error_class or self.error_class
         messages = [message]
         if (since, until) != ('', ''):
             messages.append('')
         if since:
             messages.append('* deprecated from version: ' + since)
         if until:
-            messages.append(f"* {'Raises' if self.is_bad_version(until) else 'Will raise'} "
-                            f"{error_class} as of version: {until}")
+            messages.append(
+                f"* {'Raises' if self.is_bad_version(until) else 'Will raise'} "
+                f'{error_class} as of version: {until}'
+            )
         message = '\n'.join(messages)
 
         def deprecator(func):
-
             @functools.wraps(func)
             def deprecated_func(*args, **kwargs):
                 if until and self.is_bad_version(until):
@@ -182,8 +186,18 @@ class Deprecator(object):
                 warnings.warn(message, warn_class, stacklevel=2)
                 return func(*args, **kwargs)
 
-            deprecated_func.__doc__ = _add_dep_doc(deprecated_func.__doc__,
-                                                   message, TESTSETUP, TESTCLEANUP)
+            keep_doc = deprecated_func.__doc__
+            setup = TESTSETUP
+            cleanup = TESTCLEANUP
+            # After expiration, remove all but the first paragraph.
+            # The details are no longer relevant, but any code will likely
+            # raise exceptions we don't need.
+            if keep_doc and until and self.is_bad_version(until):
+                lines = '\n'.join(line.rstrip() for line in keep_doc.splitlines())
+                keep_doc = lines.split('\n\n', 1)[0]
+                setup = ''
+                cleanup = ''
+            deprecated_func.__doc__ = _add_dep_doc(keep_doc, message, setup, cleanup)
             return deprecated_func
 
         return deprecator
