@@ -7,59 +7,58 @@
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 # Copyright (C) 2011 Christian Haselgrove
-""" DICOM filesystem tools
+"""DICOM filesystem tools
 """
 
 
-import os
-from os.path import join as pjoin
-import tempfile
+import contextlib
 import getpass
 import logging
-import warnings
+import os
 import sqlite3
+import tempfile
+import warnings
+from io import BytesIO
+from os.path import join as pjoin
 
 import numpy
 
-from io import BytesIO
-
-from .nifti1 import Nifti1Header
 from nibabel.optpkg import optional_package
 
-pydicom = optional_package("pydicom")[0]
+from .nifti1 import Nifti1Header
+
+pydicom = optional_package('pydicom')[0]
 
 logger = logging.getLogger('nibabel.dft')
 
 
 class DFTError(Exception):
-    "base class for DFT exceptions"
+    """base class for DFT exceptions"""
 
 
 class CachingError(DFTError):
-    "error while caching"
+    """error while caching"""
 
 
 class VolumeError(DFTError):
-    "unsupported volume parameter"
+    """unsupported volume parameter"""
 
 
 class InstanceStackError(DFTError):
 
-    "bad series of instance numbers"
+    """bad series of instance numbers"""
 
     def __init__(self, series, i, si):
         self.series = series
         self.i = i
         self.si = si
-        return
 
     def __str__(self):
         fmt = 'expecting instance number %d, got %d'
         return fmt % (self.i + 1, self.si.instance_number)
 
 
-class _Study(object):
-
+class _Study:
     def __init__(self, d):
         self.uid = d['uid']
         self.date = d['date']
@@ -70,14 +69,13 @@ class _Study(object):
         self.patient_birth_date = d['patient_birth_date']
         self.patient_sex = d['patient_sex']
         self.series = None
-        return
 
     def __getattribute__(self, name):
         val = object.__getattribute__(self, name)
         if name == 'series' and val is None:
             val = []
-            with _db_nochange() as c:
-                c.execute("SELECT * FROM series WHERE study = ?", (self.uid, ))
+            with DB.readonly_cursor() as c:
+                c.execute('SELECT * FROM series WHERE study = ?', (self.uid,))
                 cols = [el[0] for el in c.description]
                 for row in c:
                     d = dict(zip(cols, row))
@@ -91,8 +89,7 @@ class _Study(object):
         return self.patient_name
 
 
-class _Series(object):
-
+class _Series:
     def __init__(self, d):
         self.uid = d['uid']
         self.study = d['study']
@@ -103,18 +100,17 @@ class _Series(object):
         self.bits_allocated = d['bits_allocated']
         self.bits_stored = d['bits_stored']
         self.storage_instances = None
-        return
 
     def __getattribute__(self, name):
         val = object.__getattribute__(self, name)
         if name == 'storage_instances' and val is None:
             val = []
-            with _db_nochange() as c:
+            with DB.readonly_cursor() as c:
                 query = """SELECT *
                              FROM storage_instance
                             WHERE series = ?
                             ORDER BY instance_number"""
-                c.execute(query, (self.uid, ))
+                c.execute(query, (self.uid,))
                 cols = [el[0] for el in c.description]
                 for row in c:
                     d = dict(zip(cols, row))
@@ -124,6 +120,7 @@ class _Series(object):
 
     def as_png(self, index=None, scale_to_slice=True):
         import PIL.Image
+
         # For compatibility with older versions of PIL that did not
         # have `frombytes`:
         if hasattr(PIL.Image, 'frombytes'):
@@ -162,8 +159,9 @@ class _Series(object):
             raise VolumeError('unsupported bits allocated')
         if self.bits_stored != 12:
             raise VolumeError('unsupported bits stored')
-        data = numpy.ndarray((len(self.storage_instances), self.rows,
-                              self.columns), dtype=numpy.int16)
+        data = numpy.ndarray(
+            (len(self.storage_instances), self.rows, self.columns), dtype=numpy.int16
+        )
         for (i, si) in enumerate(self.storage_instances):
             if i + 1 != si.instance_number:
                 raise InstanceStackError(self, i, si)
@@ -194,10 +192,12 @@ class _Series(object):
         cosk = pos_n - pos_1
         cosk = cosk / numpy.linalg.norm(cosk)
 
-        m = ((pdi * cosi[0], pdj * cosj[0], pdk * cosk[0], pos_1[0]),
-             (pdi * cosi[1], pdj * cosj[1], pdk * cosk[1], pos_1[1]),
-             (pdi * cosi[2], pdj * cosj[2], pdk * cosk[2], pos_1[2]),
-             (0, 0, 0, 1))
+        m = (
+            (pdi * cosi[0], pdj * cosj[0], pdk * cosk[0], pos_1[0]),
+            (pdi * cosi[1], pdj * cosj[1], pdk * cosk[1], pos_1[1]),
+            (pdi * cosi[2], pdj * cosj[2], pdk * cosk[2], pos_1[2]),
+            (0, 0, 0, 1),
+        )
 
         # Values are python Decimals in pydicom 0.9.7
         m = numpy.array(m, dtype=float)
@@ -207,8 +207,7 @@ class _Series(object):
         hdr.set_qform(m, 1)
         hdr.set_xyzt_units(2, 8)
         hdr.set_data_dtype(numpy.int16)
-        hdr.set_data_shape((self.columns, self.rows,
-                            len(self.storage_instances)))
+        hdr.set_data_shape((self.columns, self.rows, len(self.storage_instances)))
 
         s = BytesIO()
         hdr.write_to(s)
@@ -219,24 +218,22 @@ class _Series(object):
         return 352 + 2 * len(self.storage_instances) * self.columns * self.rows
 
 
-class _StorageInstance(object):
-
+class _StorageInstance:
     def __init__(self, d):
         self.uid = d['uid']
         self.instance_number = d['instance_number']
         self.series = d['series']
         self.files = None
-        return
 
     def __getattribute__(self, name):
         val = object.__getattribute__(self, name)
         if name == 'files' and val is None:
-            with _db_nochange() as c:
+            with DB.readonly_cursor() as c:
                 query = """SELECT directory, name
                              FROM file
                             WHERE storage_instance = ?
                             ORDER BY directory, name"""
-                c.execute(query, (self.uid, ))
+                c.execute(query, (self.uid,))
                 val = ['%s/%s' % tuple(row) for row in c]
             self.files = val
         return val
@@ -245,36 +242,6 @@ class _StorageInstance(object):
         return pydicom.read_file(self.files[0])
 
 
-class _db_nochange:
-    """context guard for read-only database access"""
-
-    def __enter__(self):
-        self.c = DB.cursor()
-        return self.c
-
-    def __exit__(self, type, value, traceback):
-        if type is None:
-            self.c.close()
-        DB.rollback()
-        return
-
-
-class _db_change:
-    """context guard for database access requiring a commit"""
-
-    def __enter__(self):
-        self.c = DB.cursor()
-        return self.c
-
-    def __exit__(self, type, value, traceback):
-        if type is None:
-            self.c.close()
-            DB.commit()
-        else:
-            DB.rollback()
-        return
-
-
 def _get_subdirs(base_dir, files_dict=None, followlinks=False):
     dirs = []
     for (dirpath, dirnames, filenames) in os.walk(base_dir, followlinks=followlinks):
@@ -294,37 +261,34 @@ def update_cache(base_dir, followlinks=False):
     for d in dirs:
         os.stat(d)
         mtimes[d] = os.stat(d).st_mtime
-    with _db_nochange() as c:
-        c.execute("SELECT path, mtime FROM directory")
+    with DB.readwrite_cursor() as c:
+        c.execute('SELECT path, mtime FROM directory')
         db_mtimes = dict(c)
-        c.execute("SELECT uid FROM study")
+        c.execute('SELECT uid FROM study')
         studies = [row[0] for row in c]
-        c.execute("SELECT uid FROM series")
+        c.execute('SELECT uid FROM series')
         series = [row[0] for row in c]
-        c.execute("SELECT uid FROM storage_instance")
+        c.execute('SELECT uid FROM storage_instance')
         storage_instances = [row[0] for row in c]
-    with _db_change() as c:
         for dir in sorted(mtimes.keys()):
             if dir in db_mtimes and mtimes[dir] <= db_mtimes[dir]:
                 continue
             logger.debug(f'updating {dir}')
-            _update_dir(c, dir, files_by_dir[dir], studies, series,
-                        storage_instances)
+            _update_dir(c, dir, files_by_dir[dir], studies, series, storage_instances)
             if dir in db_mtimes:
-                query = "UPDATE directory SET mtime = ? WHERE path = ?"
+                query = 'UPDATE directory SET mtime = ? WHERE path = ?'
                 c.execute(query, (mtimes[dir], dir))
             else:
-                query = "INSERT INTO directory (path, mtime) VALUES (?, ?)"
+                query = 'INSERT INTO directory (path, mtime) VALUES (?, ?)'
                 c.execute(query, (dir, mtimes[dir]))
-    return
 
 
 def get_studies(base_dir=None, followlinks=False):
     if base_dir is not None:
         update_cache(base_dir, followlinks)
     if base_dir is None:
-        with _db_nochange() as c:
-            c.execute("SELECT * FROM study")
+        with DB.readonly_cursor() as c:
+            c.execute('SELECT * FROM study')
             studies = []
             cols = [el[0] for el in c.description]
             for row in c:
@@ -338,15 +302,15 @@ def get_studies(base_dir=None, followlinks=False):
                                WHERE uid IN (SELECT storage_instance
                                                FROM file
                                               WHERE directory = ?))"""
-    with _db_nochange() as c:
+    with DB.readonly_cursor() as c:
         study_uids = {}
         for dir in _get_subdirs(base_dir, followlinks=followlinks):
-            c.execute(query, (dir, ))
+            c.execute(query, (dir,))
             for row in c:
                 study_uids[row[0]] = None
         studies = []
         for uid in study_uids:
-            c.execute("SELECT * FROM study WHERE uid = ?", (uid, ))
+            c.execute('SELECT * FROM study WHERE uid = ?', (uid,))
             cols = [el[0] for el in c.description]
             d = dict(zip(cols, c.fetchone()))
             studies.append(_Study(d))
@@ -355,21 +319,19 @@ def get_studies(base_dir=None, followlinks=False):
 
 def _update_dir(c, dir, files, studies, series, storage_instances):
     logger.debug(f'Updating directory {dir}')
-    c.execute("SELECT name, mtime FROM file WHERE directory = ?", (dir, ))
+    c.execute('SELECT name, mtime FROM file WHERE directory = ?', (dir,))
     db_mtimes = dict(c)
     for fname in db_mtimes:
         if fname not in files:
             logger.debug(f'    remove {fname}')
-            c.execute("DELETE FROM file WHERE directory = ? AND name = ?",
-                      (dir, fname))
+            c.execute('DELETE FROM file WHERE directory = ? AND name = ?', (dir, fname))
     for fname in files:
         mtime = os.lstat(f'{dir}/{fname}').st_mtime
         if fname in db_mtimes and mtime <= db_mtimes[fname]:
             logger.debug(f'    okay {fname}')
         else:
             logger.debug(f'    update {fname}')
-            si_uid = _update_file(c, dir, fname, studies, series,
-                                  storage_instances)
+            si_uid = _update_file(c, dir, fname, studies, series, storage_instances)
             if fname not in db_mtimes:
                 query = """INSERT INTO file (directory,
                                              name,
@@ -382,7 +344,6 @@ def _update_dir(c, dir, files, studies, series, storage_instances):
                               SET mtime = ?, storage_instance = ?
                             WHERE directory = ? AND name = ?"""
                 c.execute(query, (mtime, si_uid, dir, fname))
-    return
 
 
 def _update_file(c, path, fname, studies, series, storage_instances):
@@ -407,14 +368,16 @@ def _update_file(c, path, fname, studies, series, storage_instances):
                                           patient_birth_date,
                                           patient_sex)
                        VALUES (?, ?, ?, ?, ?, ?, ?, ?)"""
-            params = (str(do.StudyInstanceUID),
-                      do.StudyDate,
-                      do.StudyTime,
-                      study_comments,
-                      str(do.PatientName),
-                      do.PatientID,
-                      do.PatientBirthDate,
-                      do.PatientSex)
+            params = (
+                str(do.StudyInstanceUID),
+                do.StudyDate,
+                do.StudyTime,
+                study_comments,
+                str(do.PatientName),
+                do.PatientID,
+                do.PatientBirthDate,
+                do.PatientSex,
+            )
             c.execute(query, params)
             studies.append(str(do.StudyInstanceUID))
         if str(do.SeriesInstanceUID) not in series:
@@ -427,21 +390,22 @@ def _update_file(c, path, fname, studies, series, storage_instances):
                                            bits_allocated,
                                            bits_stored)
                        VALUES (?, ?, ?, ?, ?, ?, ?, ?)"""
-            params = (str(do.SeriesInstanceUID),
-                      str(do.StudyInstanceUID),
-                      do.SeriesNumber,
-                      do.SeriesDescription,
-                      do.Rows,
-                      do.Columns,
-                      do.BitsAllocated,
-                      do.BitsStored)
+            params = (
+                str(do.SeriesInstanceUID),
+                str(do.StudyInstanceUID),
+                do.SeriesNumber,
+                do.SeriesDescription,
+                do.Rows,
+                do.Columns,
+                do.BitsAllocated,
+                do.BitsStored,
+            )
             c.execute(query, params)
             series.append(str(do.SeriesInstanceUID))
         if str(do.SOPInstanceUID) not in storage_instances:
             query = """INSERT INTO storage_instance (uid, instance_number, series)
                        VALUES (?, ?, ?)"""
-            params = (str(do.SOPInstanceUID), do.InstanceNumber,
-                      str(do.SeriesInstanceUID))
+            params = (str(do.SOPInstanceUID), do.InstanceNumber, str(do.SeriesInstanceUID))
             c.execute(query, params)
             storage_instances.append(str(do.SOPInstanceUID))
     except AttributeError as data:
@@ -451,13 +415,12 @@ def _update_file(c, path, fname, studies, series, storage_instances):
 
 
 def clear_cache():
-    with _db_change() as c:
-        c.execute("DELETE FROM file")
-        c.execute("DELETE FROM directory")
-        c.execute("DELETE FROM storage_instance")
-        c.execute("DELETE FROM series")
-        c.execute("DELETE FROM study")
-    return
+    with DB.readwrite_cursor() as c:
+        c.execute('DELETE FROM file')
+        c.execute('DELETE FROM directory')
+        c.execute('DELETE FROM storage_instance')
+        c.execute('DELETE FROM series')
+        c.execute('DELETE FROM study')
 
 
 CREATE_QUERIES = (
@@ -486,27 +449,66 @@ CREATE_QUERIES = (
                           name TEXT NOT NULL,
                           mtime INTEGER NOT NULL,
                           storage_instance TEXT DEFAULT NULL REFERENCES storage_instance,
-                          PRIMARY KEY (directory, name))""")
-DB_FNAME = pjoin(tempfile.gettempdir(), f'dft.{getpass.getuser()}.sqlite')
+                          PRIMARY KEY (directory, name))""",
+)
+
+
+class _DB:
+    def __init__(self, fname=None, verbose=True):
+        self.fname = fname or pjoin(tempfile.gettempdir(), f'dft.{getpass.getuser()}.sqlite')
+        self.verbose = verbose
+
+    @property
+    def session(self):
+        """Get sqlite3 Connection
+
+        The connection is created on the first call of this property
+        """
+        try:
+            return self._session
+        except AttributeError:
+            self._init_db()
+            return self._session
+
+    def _init_db(self):
+        if self.verbose:
+            logger.info('db filename: ' + self.fname)
+
+        self._session = sqlite3.connect(self.fname, isolation_level='EXCLUSIVE')
+        with self.readwrite_cursor() as c:
+            c.execute("SELECT COUNT(*) FROM sqlite_master WHERE type = 'table'")
+            if c.fetchone()[0] == 0:
+                logger.debug('create')
+                for q in CREATE_QUERIES:
+                    c.execute(q)
+
+    def __repr__(self):
+        return f'<DFT {self.fname!r}>'
+
+    @contextlib.contextmanager
+    def readonly_cursor(self):
+        cursor = self.session.cursor()
+        try:
+            yield cursor
+        finally:
+            cursor.close()
+            self.session.rollback()
+
+    @contextlib.contextmanager
+    def readwrite_cursor(self):
+        cursor = self.session.cursor()
+        try:
+            yield cursor
+        except Exception:
+            self.session.rollback()
+            raise
+        finally:
+            cursor.close()
+        self.session.commit()
+
+
 DB = None
-
-
-def _init_db(verbose=True):
-    """ Initialize database """
-    if verbose:
-        logger.info('db filename: ' + DB_FNAME)
-    global DB
-    DB = sqlite3.connect(DB_FNAME, check_same_thread=False)
-    with _db_change() as c:
-        c.execute("SELECT COUNT(*) FROM sqlite_master WHERE type = 'table'")
-        if c.fetchone()[0] == 0:
-            logger.debug('create')
-            for q in CREATE_QUERIES:
-                c.execute(q)
-
-
 if os.name == 'nt':
     warnings.warn('dft needs FUSE which is not available for windows')
 else:
-    _init_db()
-# eof
+    DB = _DB()
