@@ -6,85 +6,195 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Classes defining Gifti objects
+"""Classes defining Gifti objects
 
 The Gifti specification was (at time of writing) available as a PDF download
 from http://www.nitrc.org/projects/gifti/
 """
+from __future__ import annotations
 
-import sys
-import numpy as np
 import base64
+import sys
+import warnings
+from typing import Type
+
+import numpy as np
 
 from .. import xmlutils as xml
-from ..filebasedimages import SerializableImage
-from ..nifti1 import data_type_codes, xform_codes, intent_codes
-from .util import (array_index_order_codes, gifti_encoding_codes,
-                   gifti_endian_codes, KIND2FMT)
+from ..caret import CaretMetaData
 from ..deprecated import deprecate_with_version
+from ..filebasedimages import SerializableImage
+from ..nifti1 import data_type_codes, intent_codes, xform_codes
+from .util import KIND2FMT, array_index_order_codes, gifti_encoding_codes, gifti_endian_codes
 
 
-class GiftiMetaData(xml.XmlSerializable):
-    """ A sequence of GiftiNVPairs containing metadata for a gifti data array
-    """
+class _GiftiMDList(list):
+    """List view of GiftiMetaData object that will translate most operations"""
 
-    def __init__(self, nvpair=None):
-        self.data = []
-        if nvpair is not None:
-            self.data.append(nvpair)
+    def __init__(self, metadata):
+        self._md = metadata
+        super().__init__(GiftiNVPairs._private_init(k, v, metadata) for k, v in metadata.items())
 
-    @classmethod
-    def from_dict(klass, data_dict):
-        meda = klass()
-        for k, v in data_dict.items():
-            nv = GiftiNVPairs(k, v)
-            meda.data.append(nv)
-        return meda
+    def append(self, nvpair):
+        self._md[nvpair.name] = nvpair.value
+        super().append(nvpair)
 
-    @deprecate_with_version(
-        'get_metadata method deprecated. '
-        "Use the metadata property instead.",
-        '2.1', '4.0')
-    def get_metadata(self):
-        return self.metadata
+    def clear(self):
+        super().clear()
+        self._md.clear()
+
+    def extend(self, iterable):
+        for nvpair in iterable:
+            self.append(nvpair)
+
+    def insert(self, index, nvpair):
+        self._md[nvpair.name] = nvpair.value
+        super().insert(index, nvpair)
+
+    def pop(self, index=-1):
+        nvpair = super().pop(index)
+        nvpair._container = None
+        del self._md[nvpair.name]
+        return nvpair
+
+    def remove(self, nvpair):
+        super().remove(nvpair)
+        del self._md[nvpair.name]
+
+
+class GiftiMetaData(CaretMetaData):
+    """A sequence of GiftiNVPairs containing metadata for a gifti data array"""
+
+    @staticmethod
+    def _sanitize(args, kwargs):
+        """Sanitize and warn on deprecated arguments
+
+        Accept nvpair positional/keyword argument that is a single
+        ``GiftiNVPairs`` object.
+
+        >>> import pytest
+        >>> GiftiMetaData()
+        <GiftiMetaData {}>
+        >>> GiftiMetaData([("key", "val")])
+        <GiftiMetaData {'key': 'val'}>
+        >>> GiftiMetaData(key="val")
+        <GiftiMetaData {'key': 'val'}>
+        >>> GiftiMetaData({"key": "val"})
+        <GiftiMetaData {'key': 'val'}>
+        >>> nvpairs = GiftiNVPairs(name='key', value='val')
+        >>> with pytest.warns(FutureWarning):
+        ...     GiftiMetaData(nvpairs)
+        <GiftiMetaData {'key': 'val'}>
+        >>> with pytest.warns(FutureWarning):
+        ...     GiftiMetaData(nvpair=nvpairs)
+        <GiftiMetaData {'key': 'val'}>
+        """
+        dep_init = False
+        # Positional arg
+        dep_init |= not kwargs and len(args) == 1 and isinstance(args[0], GiftiNVPairs)
+        # Keyword arg
+        dep_init |= not args and list(kwargs) == ['nvpair']
+        if not dep_init:
+            return args, kwargs
+
+        warnings.warn(
+            'GiftiMetaData now has a dict-like interface. '
+            'See ``pydoc dict`` for initialization options. '
+            'Passing ``GiftiNVPairs()`` or using the ``nvpair`` '
+            'keyword will fail or behave unexpectedly in NiBabel 6.0.',
+            FutureWarning,
+            stacklevel=3,
+        )
+        pair = args[0] if args else kwargs.get('nvpair')
+        return (), {pair.name: pair.value}
 
     @property
-    def metadata(self):
-        """ Returns metadata as dictionary """
-        self.data_as_dict = {}
-        for ele in self.data:
-            self.data_as_dict[ele.name] = ele.value
-        return self.data_as_dict
+    @deprecate_with_version(
+        'The data attribute is deprecated. Use GiftiMetaData object directly as a dict.',
+        '4.0',
+        '6.0',
+    )
+    def data(self):
+        return _GiftiMDList(self)
 
-    def _to_xml_element(self):
-        metadata = xml.Element('MetaData')
-        for ele in self.data:
-            md = xml.SubElement(metadata, 'MD')
-            name = xml.SubElement(md, 'Name')
-            value = xml.SubElement(md, 'Value')
-            name.text = ele.name
-            value.text = ele.value
-        return metadata
+    @classmethod
+    @deprecate_with_version(
+        'from_dict class method deprecated. Use GiftiMetaData directly.', '4.0', '6.0'
+    )
+    def from_dict(klass, data_dict):
+        return klass(data_dict)
+
+    @property
+    @deprecate_with_version(
+        'metadata property deprecated. Use GiftiMetaData object '
+        'as dict or pass to dict() for a standard dictionary.',
+        '4.0',
+        '6.0',
+    )
+    def metadata(self):
+        """Returns metadata as dictionary"""
+        return dict(self)
 
     def print_summary(self):
-        print(self.metadata)
+        print(dict(self))
 
 
-class GiftiNVPairs(object):
-    """ Gifti name / value pairs
+class GiftiNVPairs:
+    """Gifti name / value pairs
 
     Attributes
     ----------
     name : str
     value : str
     """
-    def __init__(self, name=u'', value=u''):
-        self.name = name
-        self.value = value
+
+    @deprecate_with_version(
+        'GiftiNVPairs objects are deprecated. Use the GiftiMetaData object as a dict, instead.',
+        '4.0',
+        '6.0',
+    )
+    def __init__(self, name='', value=''):
+        self._name = name
+        self._value = value
+        self._container = None
+
+    @classmethod
+    def _private_init(cls, name, value, md):
+        """Private init method to provide warning-free experience"""
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', DeprecationWarning)
+            self = cls(name, value)
+        self._container = md
+        return self
+
+    def __eq__(self, other):
+        if not isinstance(other, GiftiNVPairs):
+            return NotImplemented
+        return self.name == other.name and self.value == other.value
+
+    @property
+    def name(self):
+        return self._name
+
+    @name.setter
+    def name(self, key):
+        if self._container:
+            self._container[key] = self._container.pop(self._name)
+        self._name = key
+
+    @property
+    def value(self):
+        return self._value
+
+    @value.setter
+    def value(self, val):
+        if self._container:
+            self._container[self._name] = val
+        self._value = val
 
 
 class GiftiLabelTable(xml.XmlSerializable):
-    """ Gifti label table: a sequence of key, label pairs
+    """Gifti label table: a sequence of key, label pairs
 
     From the gifti spec dated 2011-01-14:
         The label table is used by DataArrays whose values are an key into the
@@ -95,6 +205,9 @@ class GiftiLabelTable(xml.XmlSerializable):
     def __init__(self):
         self.labels = []
 
+    def __repr__(self):
+        return f'<GiftiLabelTable {self.labels!r}>'
+
     def get_labels_as_dict(self):
         self.labels_as_dict = {}
         for ele in self.labels:
@@ -117,7 +230,7 @@ class GiftiLabelTable(xml.XmlSerializable):
 
 
 class GiftiLabel(xml.XmlSerializable):
-    """ Gifti label: association of integer key with optional RGBA values
+    """Gifti label: association of integer key with optional RGBA values
 
     Quotes are from the gifti spec dated 2011-01-14.
 
@@ -153,21 +266,19 @@ class GiftiLabel(xml.XmlSerializable):
         self.blue = blue
         self.alpha = alpha
 
-    @deprecate_with_version(
-        'get_rgba method deprecated. '
-        "Use the rgba property instead.",
-        '2.1', '4.0')
-    def get_rgba(self):
-        return self.rgba
+    def __repr__(self):
+        chars = 255 * np.array([self.red or 0, self.green or 0, self.blue or 0, self.alpha or 0])
+        r, g, b, a = chars.astype('u1')
+        return f'<GiftiLabel {self.key}="#{r:02x}{g:02x}{b:02x}{a:02x}">'
 
     @property
     def rgba(self):
-        """ Returns RGBA as tuple """
+        """Returns RGBA as tuple"""
         return (self.red, self.green, self.blue, self.alpha)
 
     @rgba.setter
     def rgba(self, rgba):
-        """ Set RGBA via sequence
+        """Set RGBA via sequence
 
         Parameters
         ----------
@@ -189,7 +300,7 @@ def _arr2txt(arr, elem_fmt):
 
 
 class GiftiCoordSystem(xml.XmlSerializable):
-    """ Gifti coordinate system transform matrix
+    """Gifti coordinate system transform matrix
 
     Quotes are from the gifti spec dated 2011-01-14.
 
@@ -235,6 +346,11 @@ class GiftiCoordSystem(xml.XmlSerializable):
         else:
             self.xform = xform
 
+    def __repr__(self):
+        src = xform_codes.label[self.dataspace]
+        dst = xform_codes.label[self.xformspace]
+        return f'<GiftiCoordSystem {src}-to-{dst}>'
+
     def _to_xml_element(self):
         coord_xform = xml.Element('CoordinateSystemTransformMatrix')
         if self.xform is not None:
@@ -252,41 +368,21 @@ class GiftiCoordSystem(xml.XmlSerializable):
         print('Affine Transformation Matrix: \n', self.xform)
 
 
-@deprecate_with_version(
-    "data_tag is an internal API that will be discontinued.",
-    '2.1', '4.0')
-def data_tag(dataarray, encoding, datatype, ordering):
-    class DataTag(xml.XmlSerializable):
-
-        def __init__(self, *args):
-            self.args = args
-
-        def _to_xml_element(self):
-            return _data_tag_element(*self.args)
-
-    return DataTag(dataarray, encoding, datatype, ordering).to_xml()
-
-
 def _data_tag_element(dataarray, encoding, dtype, ordering):
-    """ Creates data tag with given `encoding`, returns as XML element
-    """
+    """Creates data tag with given `encoding`, returns as XML element"""
     import zlib
+
     order = array_index_order_codes.npcode[ordering]
     enclabel = gifti_encoding_codes.label[encoding]
     if enclabel == 'ASCII':
-        # XXX Accommodating data_tag API
-        # On removal (nibabel 4.0) drop str case
-        da = _arr2txt(dataarray, dtype if isinstance(dtype, str) else KIND2FMT[dtype.kind])
+        da = _arr2txt(dataarray, KIND2FMT[dtype.kind])
     elif enclabel in ('B64BIN', 'B64GZ'):
-        # XXX Accommodating data_tag API - don't try to fix dtype
-        if isinstance(dtype, str):
-            dtype = dataarray.dtype
         out = np.asanyarray(dataarray, dtype).tobytes(order)
         if enclabel == 'B64GZ':
             out = zlib.compress(out)
         da = base64.b64encode(out).decode()
     elif enclabel == 'External':
-        raise NotImplementedError("In what format are the external files?")
+        raise NotImplementedError('In what format are the external files?')
     else:
         da = ''
 
@@ -296,7 +392,7 @@ def _data_tag_element(dataarray, encoding, dtype, ordering):
 
 
 class GiftiDataArray(xml.XmlSerializable):
-    """ Container for Gifti numerical data array and associated metadata
+    """Container for Gifti numerical data array and associated metadata
 
     Quotes are from the gifti spec dated 2011-01-14.
 
@@ -331,7 +427,7 @@ class GiftiDataArray(xml.XmlSerializable):
         The Endianness to store the data array.  Should correspond to the
         machine endianness.  Default is system byteorder.
     coordsys : :class:`GiftiCoordSystem` instance
-        Input and output coordinate system with tranformation matrix between
+        Input and output coordinate system with transformation matrix between
         the two.
     ind_ord : int
         The ordering of the array. see util.array_index_order_codes.  Default
@@ -345,17 +441,19 @@ class GiftiDataArray(xml.XmlSerializable):
         Position in bytes within `ext_fname` at which to start reading data.
     """
 
-    def __init__(self,
-                 data=None,
-                 intent='NIFTI_INTENT_NONE',
-                 datatype=None,
-                 encoding="GIFTI_ENCODING_B64GZ",
-                 endian=sys.byteorder,
-                 coordsys=None,
-                 ordering="C",
-                 meta=None,
-                 ext_fname=u'',
-                 ext_offset=0):
+    def __init__(
+        self,
+        data=None,
+        intent='NIFTI_INTENT_NONE',
+        datatype=None,
+        encoding='GIFTI_ENCODING_B64GZ',
+        endian=sys.byteorder,
+        coordsys=None,
+        ordering='C',
+        meta=None,
+        ext_fname='',
+        ext_offset=0,
+    ):
         """
         Returns a shell object that cannot be saved.
         """
@@ -368,93 +466,42 @@ class GiftiDataArray(xml.XmlSerializable):
         self.endian = gifti_endian_codes.code[endian]
         self.coordsys = coordsys or GiftiCoordSystem()
         self.ind_ord = array_index_order_codes.code[ordering]
-        self.meta = (GiftiMetaData() if meta is None else
-                     meta if isinstance(meta, GiftiMetaData) else
-                     GiftiMetaData.from_dict(meta))
+        self.meta = (
+            GiftiMetaData()
+            if meta is None
+            else meta
+            if isinstance(meta, GiftiMetaData)
+            else GiftiMetaData(meta)
+        )
         self.ext_fname = ext_fname
         self.ext_offset = ext_offset
         self.dims = [] if self.data is None else list(self.data.shape)
 
+    def __repr__(self):
+        return f'<GiftiDataArray {intent_codes.label[self.intent]}{self.dims}>'
+
     @property
     def num_dim(self):
         return len(self.dims)
 
-    # Setter for backwards compatibility with pymvpa
-    @num_dim.setter
-    @deprecate_with_version(
-        "num_dim will be read-only in future versions of nibabel",
-        '2.1', '4.0')
-    def num_dim(self, value):
-        if value != len(self.dims):
-            raise ValueError(f'num_dim value {value} != number of '
-                             f'dimensions len(self.dims) {len(self.dims)}')
-
-    @classmethod
-    @deprecate_with_version(
-        'from_array method is deprecated. '
-        'Please use GiftiDataArray constructor instead.',
-        '2.1', '4.0')
-    def from_array(klass,
-                   darray,
-                   intent="NIFTI_INTENT_NONE",
-                   datatype=None,
-                   encoding="GIFTI_ENCODING_B64GZ",
-                   endian=sys.byteorder,
-                   coordsys=None,
-                   ordering="C",
-                   meta=None):
-        """ Creates a new Gifti data array
-
-        Parameters
-        ----------
-        darray : ndarray
-            NumPy data array
-        intent : string
-            NIFTI intent code, see nifti1.intent_codes
-        datatype : None or string, optional
-            NIFTI data type codes, see nifti1.data_type_codes
-            If None, the datatype of the NumPy array is taken.
-        encoding : string, optionaal
-            Encoding of the data, see util.gifti_encoding_codes;
-            default: GIFTI_ENCODING_B64GZ
-        endian : string, optional
-            The Endianness to store the data array.  Should correspond to the
-            machine endianness.  default: system byteorder
-        coordsys : GiftiCoordSystem, optional
-            If None, a identity transformation is taken.
-        ordering : string, optional
-            The ordering of the array. see util.array_index_order_codes;
-            default: RowMajorOrder - C ordering
-        meta : None or dict, optional
-            A dictionary for metadata information.  If None, gives empty dict.
-
-        Returns
-        -------
-        da : instance of our own class
-        """
-        return klass(data=darray,
-                     intent=intent,
-                     datatype=datatype,
-                     encoding=encoding,
-                     endian=endian,
-                     coordsys=coordsys,
-                     ordering=ordering,
-                     meta=meta)
-
     def _to_xml_element(self):
         # fix endianness to machine endianness
         self.endian = gifti_endian_codes.code[sys.byteorder]
 
         # All attribute values must be strings
-        data_array = xml.Element('DataArray', attrib={
-            'Intent': intent_codes.niistring[self.intent],
-            'DataType': data_type_codes.niistring[self.datatype],
-            'ArrayIndexingOrder': array_index_order_codes.label[self.ind_ord],
-            'Dimensionality': str(self.num_dim),
-            'Encoding': gifti_encoding_codes.specs[self.encoding],
-            'Endian': gifti_endian_codes.specs[self.endian],
-            'ExternalFileName': self.ext_fname,
-            'ExternalFileOffset': str(self.ext_offset)})
+        data_array = xml.Element(
+            'DataArray',
+            attrib={
+                'Intent': intent_codes.niistring[self.intent],
+                'DataType': data_type_codes.niistring[self.datatype],
+                'ArrayIndexingOrder': array_index_order_codes.label[self.ind_ord],
+                'Dimensionality': str(self.num_dim),
+                'Encoding': gifti_encoding_codes.specs[self.encoding],
+                'Endian': gifti_endian_codes.specs[self.endian],
+                'ExternalFileName': self.ext_fname,
+                'ExternalFileOffset': str(self.ext_offset),
+            },
+        )
         for di, dn in enumerate(self.dims):
             data_array.attrib['Dim%d' % di] = str(dn)
 
@@ -464,52 +511,20 @@ class GiftiDataArray(xml.XmlSerializable):
             data_array.append(self.coordsys._to_xml_element())
         # write data array depending on the encoding
         data_array.append(
-            _data_tag_element(self.data,
-                              gifti_encoding_codes.specs[self.encoding],
-                              data_type_codes.dtype[self.datatype],
-                              self.ind_ord))
+            _data_tag_element(
+                self.data,
+                gifti_encoding_codes.specs[self.encoding],
+                data_type_codes.dtype[self.datatype],
+                self.ind_ord,
+            )
+        )
 
         return data_array
 
-    @deprecate_with_version(
-        'to_xml_open method deprecated. '
-        'Use the to_xml() function instead.',
-        '2.1', '4.0')
-    def to_xml_open(self):
-        out = """<DataArray Intent="%s"
-\tDataType="%s"
-\tArrayIndexingOrder="%s"
-\tDimensionality="%s"
-%s\tEncoding="%s"
-\tEndian="%s"
-\tExternalFileName="%s"
-\tExternalFileOffset="%d">\n"""
-        di = ""
-        for i, n in enumerate(self.dims):
-            di = di + f'\tDim{i}="{n}\"\n'
-        return out % (intent_codes.niistring[self.intent],
-                      data_type_codes.niistring[self.datatype],
-                      array_index_order_codes.label[self.ind_ord],
-                      str(self.num_dim),
-                      str(di),
-                      gifti_encoding_codes.specs[self.encoding],
-                      gifti_endian_codes.specs[self.endian],
-                      self.ext_fname,
-                      self.ext_offset,
-                      )
-
-    @deprecate_with_version(
-        'to_xml_close method deprecated. '
-        'Use the to_xml() function instead.',
-        '2.1', '4.0')
-    def to_xml_close(self):
-        return "</DataArray>\n"
-
     def print_summary(self):
         print('Intent: ', intent_codes.niistring[self.intent])
         print('DataType: ', data_type_codes.niistring[self.datatype])
-        print('ArrayIndexingOrder: ',
-              array_index_order_codes.label[self.ind_ord])
+        print('ArrayIndexingOrder: ', array_index_order_codes.label[self.ind_ord])
         print('Dimensionality: ', self.num_dim)
         print('Dimensions: ', self.dims)
         print('Encoding: ', gifti_encoding_codes.specs[self.encoding])
@@ -521,21 +536,14 @@ class GiftiDataArray(xml.XmlSerializable):
             print('Coordinate System:')
             print(self.coordsys.print_summary())
 
-    @deprecate_with_version(
-        'get_metadata method deprecated. '
-        "Use the metadata property instead.",
-        '2.1', '4.0')
-    def get_metadata(self):
-        return self.meta.metadata
-
     @property
     def metadata(self):
-        """ Returns metadata as dictionary """
-        return self.meta.metadata
+        """Returns metadata as dictionary"""
+        return dict(self.meta)
 
 
 class GiftiImage(xml.XmlSerializable, SerializableImage):
-    """ GIFTI image object
+    """GIFTI image object
 
     The Gifti spec suggests using the following suffixes to your
     filename when saving each specific type of data:
@@ -563,18 +571,27 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
 
     The Gifti file is stored in endian convention of the current machine.
     """
+
     valid_exts = ('.gii',)
     files_types = (('image', '.gii'),)
+    _compressed_suffixes = ('.gz', '.bz2')
 
     # The parser will in due course be a GiftiImageParser, but we can't set
     # that now, because it would result in a circular import.  We set it after
     # the class has been defined, at the end of the class definition.
-    parser = None
+    parser: Type[xml.XmlParser]
 
-    def __init__(self, header=None, extra=None, file_map=None, meta=None,
-                 labeltable=None, darrays=None, version=u"1.0"):
-        super(GiftiImage, self).__init__(header=header, extra=extra,
-                                         file_map=file_map)
+    def __init__(
+        self,
+        header=None,
+        extra=None,
+        file_map=None,
+        meta=None,
+        labeltable=None,
+        darrays=None,
+        version='1.0',
+    ):
+        super().__init__(header=header, extra=extra, file_map=file_map)
         if darrays is None:
             darrays = []
         if meta is None:
@@ -598,85 +615,56 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
 
     @labeltable.setter
     def labeltable(self, labeltable):
-        """ Set the labeltable for this GiftiImage
+        """Set the labeltable for this GiftiImage
 
         Parameters
         ----------
         labeltable : :class:`GiftiLabelTable` instance
         """
         if not isinstance(labeltable, GiftiLabelTable):
-            raise TypeError("Not a valid GiftiLabelTable instance")
+            raise TypeError('Not a valid GiftiLabelTable instance')
         self._labeltable = labeltable
 
-    @deprecate_with_version(
-        'set_labeltable method deprecated. '
-        "Use the gifti_img.labeltable property instead.",
-        '2.1', '4.0')
-    def set_labeltable(self, labeltable):
-        self.labeltable = labeltable
-
-    @deprecate_with_version(
-        'get_labeltable method deprecated. '
-        "Use the gifti_img.labeltable property instead.",
-        '2.1', '4.0')
-    def get_labeltable(self):
-        return self.labeltable
-
     @property
     def meta(self):
         return self._meta
 
     @meta.setter
     def meta(self, meta):
-        """ Set the metadata for this GiftiImage
+        """Set the metadata for this GiftiImage
 
         Parameters
         ----------
         meta : :class:`GiftiMetaData` instance
         """
         if not isinstance(meta, GiftiMetaData):
-            raise TypeError("Not a valid GiftiMetaData instance")
+            raise TypeError('Not a valid GiftiMetaData instance')
         self._meta = meta
 
-    @deprecate_with_version(
-        'set_meta method deprecated. '
-        "Use the gifti_img.meta property instead.",
-        '2.1', '4.0')
-    def set_metadata(self, meta):
-        self.meta = meta
-
-    @deprecate_with_version(
-        'get_meta method deprecated. '
-        "Use the gifti_img.meta property instead.",
-        '2.1', '4.0')
-    def get_meta(self):
-        return self.meta
-
     def add_gifti_data_array(self, dataarr):
-        """ Adds a data array to the GiftiImage
+        """Adds a data array to the GiftiImage
 
         Parameters
         ----------
         dataarr : :class:`GiftiDataArray` instance
         """
         if not isinstance(dataarr, GiftiDataArray):
-            raise TypeError("Not a valid GiftiDataArray instance")
+            raise TypeError('Not a valid GiftiDataArray instance')
         self.darrays.append(dataarr)
 
     def remove_gifti_data_array(self, ith):
-        """ Removes the ith data array element from the GiftiImage """
+        """Removes the ith data array element from the GiftiImage"""
         self.darrays.pop(ith)
 
     def remove_gifti_data_array_by_intent(self, intent):
-        """ Removes all the data arrays with the given intent type """
+        """Removes all the data arrays with the given intent type"""
         intent2remove = intent_codes.code[intent]
         for dele in self.darrays:
             if dele.intent == intent2remove:
                 self.darrays.remove(dele)
 
     def get_arrays_from_intent(self, intent):
-        """ Return list of GiftiDataArray elements matching given intent
-        """
+        """Return list of GiftiDataArray elements matching given intent"""
         it = intent_codes.code[intent]
         return [x for x in self.darrays if x.intent == it]
 
@@ -815,13 +803,6 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
 
         return all_data
 
-    @deprecate_with_version(
-        'getArraysFromIntent method deprecated. '
-        "Use get_arrays_from_intent instead.",
-        '2.1', '4.0')
-    def getArraysFromIntent(self, intent):
-        return self.get_arrays_from_intent(intent)
-
     def print_summary(self):
         print('----start----')
         print('Source filename: ', self.get_filename())
@@ -842,9 +823,9 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
         print('----end----')
 
     def _to_xml_element(self):
-        GIFTI = xml.Element('GIFTI', attrib={
-            'Version': self.version,
-            'NumberOfDataArrays': str(self.numDA)})
+        GIFTI = xml.Element(
+            'GIFTI', attrib={'Version': self.version, 'NumberOfDataArrays': str(self.numDA)}
+        )
         if self.meta is not None:
             GIFTI.append(self.meta._to_xml_element())
         if self.labeltable is not None:
@@ -853,17 +834,21 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
             GIFTI.append(dar._to_xml_element())
         return GIFTI
 
-    def to_xml(self, enc='utf-8'):
-        """ Return XML corresponding to image content """
-        return b"""<?xml version="1.0" encoding="UTF-8"?>
+    def to_xml(self, enc='utf-8') -> bytes:
+        """Return XML corresponding to image content"""
+        header = b"""<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE GIFTI SYSTEM "http://www.nitrc.org/frs/download.php/115/gifti.dtd">
-""" + xml.XmlSerializable.to_xml(self, enc)
+"""
+        return header + super().to_xml(enc)
 
     # Avoid the indirection of going through to_file_map
-    to_bytes = to_xml
+    def to_bytes(self, enc='utf-8'):
+        return self.to_xml(enc=enc)
 
-    def to_file_map(self, file_map=None):
-        """ Save the current image to the specified file_map
+    to_bytes.__doc__ = SerializableImage.to_bytes.__doc__
+
+    def to_file_map(self, file_map=None, enc='utf-8'):
+        """Save the current image to the specified file_map
 
         Parameters
         ----------
@@ -878,11 +863,11 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
         if file_map is None:
             file_map = self.file_map
         with file_map['image'].get_prepare_fileobj('wb') as f:
-            f.write(self.to_xml())
+            f.write(self.to_xml(enc=enc))
 
     @classmethod
-    def from_file_map(klass, file_map, buffer_size=35000000):
-        """ Load a Gifti image from a file_map
+    def from_file_map(klass, file_map, buffer_size=35000000, mmap=True):
+        """Load a Gifti image from a file_map
 
         Parameters
         ----------
@@ -890,21 +875,37 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
             Dictionary with single key ``image`` with associated value which is
             a :class:`FileHolder` instance pointing to the image file.
 
+        buffer_size: None or int, optional
+            size of read buffer. None uses default buffer_size
+            from xml.parsers.expat.
+
+        mmap : {True, False, 'c', 'r', 'r+'}
+            Controls the use of numpy memory mapping for reading data.  Only
+            has an effect when loading GIFTI images with data stored in
+            external files (``DataArray`` elements with an ``Encoding`` equal
+            to ``ExternalFileBinary``).  If ``False``, do not try numpy
+            ``memmap`` for data array.  If one of ``{'c', 'r', 'r+'}``, try
+            numpy ``memmap`` with ``mode=mmap``.  A `mmap` value of ``True``
+            gives the same behavior as ``mmap='c'``.  If the file cannot be
+            memory-mapped, ignore `mmap` value and read array from file.
+
         Returns
         -------
         img : GiftiImage
         """
-        parser = klass.parser(buffer_size=buffer_size)
-        parser.parse(fptr=file_map['image'].get_prepare_fileobj('rb'))
+        parser = klass.parser(buffer_size=buffer_size, mmap=mmap)
+        with file_map['image'].get_prepare_fileobj('rb') as fptr:
+            parser.parse(fptr=fptr)
         return parser.img
 
     @classmethod
-    def from_filename(klass, filename, buffer_size=35000000):
+    def from_filename(klass, filename, buffer_size=35000000, mmap=True):
         file_map = klass.filespec_to_file_map(filename)
-        img = klass.from_file_map(file_map, buffer_size=buffer_size)
+        img = klass.from_file_map(file_map, buffer_size=buffer_size, mmap=mmap)
         return img
 
 
 # Now GiftiImage is defined, we can import the parser module and set the parser
 from .parse_gifti_fast import GiftiImageParser
+
 GiftiImage.parser = GiftiImageParser
