@@ -1,27 +1,37 @@
-""" Testing gifti objects
+"""Testing gifti objects
 """
-import warnings
+import itertools
 import sys
+import warnings
 from io import BytesIO
 
 import numpy as np
+import pytest
+from numpy.testing import assert_array_almost_equal, assert_array_equal
 
 from nibabel.tmpdirs import InTemporaryDirectory
 
 from ... import load
-from .. import (GiftiImage, GiftiDataArray, GiftiLabel,
-                GiftiLabelTable, GiftiMetaData, GiftiNVPairs,
-                GiftiCoordSystem)
-from ..gifti import data_tag
-from ...nifti1 import data_type_codes
 from ...fileholders import FileHolder
-
-from numpy.testing import assert_array_almost_equal, assert_array_equal
-import pytest
-from ...testing import clear_and_catch_warnings, test_data
-from .test_parse_gifti_fast import (DATA_FILE1, DATA_FILE2, DATA_FILE3,
-                                    DATA_FILE4, DATA_FILE5, DATA_FILE6)
-import itertools
+from ...nifti1 import data_type_codes
+from ...testing import test_data
+from .. import (
+    GiftiCoordSystem,
+    GiftiDataArray,
+    GiftiImage,
+    GiftiLabel,
+    GiftiLabelTable,
+    GiftiMetaData,
+    GiftiNVPairs,
+)
+from .test_parse_gifti_fast import (
+    DATA_FILE1,
+    DATA_FILE2,
+    DATA_FILE3,
+    DATA_FILE4,
+    DATA_FILE5,
+    DATA_FILE6,
+)
 
 
 def test_agg_data():
@@ -52,12 +62,13 @@ def test_agg_data():
     assert surf_gii_img.agg_data(('pointset', 'triangle')) == (point_data, triangle_data)
     assert surf_gii_img.agg_data(('triangle', 'pointset')) == (triangle_data, point_data)
 
+
 def test_gifti_image():
     # Check that we're not modifying the default empty list in the default
     # arguments.
     gi = GiftiImage()
     assert gi.darrays == []
-    assert gi.meta.metadata == {}
+    assert gi.meta == {}
     assert gi.labeltable.labels == []
     arr = np.zeros((2, 3))
     gi.darrays.append(arr)
@@ -105,11 +116,13 @@ def test_gifti_image_bad_inputs():
     # Try to set to non-table
     def assign_labeltable(val):
         img.labeltable = val
+
     pytest.raises(TypeError, assign_labeltable, 'not-a-table')
 
     # Try to set to non-table
     def assign_metadata(val):
         img.meta = val
+
     pytest.raises(TypeError, assign_metadata, 'not-a-meta')
 
 
@@ -125,7 +138,7 @@ def test_dataarray_empty():
     assert null_da.coordsys.xformspace == 0
     assert_array_equal(null_da.coordsys.xform, np.eye(4))
     assert null_da.ind_ord == 1
-    assert null_da.meta.metadata == {}
+    assert null_da.meta == {}
     assert null_da.ext_fname == ''
     assert null_da.ext_offset == 0
 
@@ -148,7 +161,7 @@ def test_dataarray_init():
     pytest.raises(KeyError, gda, datatype='not_datatype')
     # Float32 datatype comes from array if datatype not set
     assert gda(arr).datatype == 16
-    # Can be overriden by init
+    # Can be overridden by init
     assert gda(arr, datatype='uint8').datatype == 2
     # Encoding
     assert gda(encoding=1).encoding == 1
@@ -173,58 +186,15 @@ def test_dataarray_init():
     assert gda(ordering='ColumnMajorOrder').ind_ord == 2
     pytest.raises(KeyError, gda, ordering='not an ordering')
     # metadata
-    meta_dict=dict(one=1, two=2)
-    assert gda(meta=GiftiMetaData.from_dict(meta_dict)).meta.metadata == meta_dict
-    assert gda(meta=meta_dict).meta.metadata == meta_dict
-    assert gda(meta=None).meta.metadata == {}
+    meta_dict = dict(one=1, two=2)
+    assert gda(meta=GiftiMetaData(meta_dict)).meta == meta_dict
+    assert gda(meta=meta_dict).meta == meta_dict
+    assert gda(meta=None).meta == {}
     # ext_fname and ext_offset
     assert gda(ext_fname='foo').ext_fname == 'foo'
     assert gda(ext_offset=12).ext_offset == 12
 
 
-def test_dataarray_from_array():
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('always', category=DeprecationWarning)
-        da = GiftiDataArray.from_array(np.ones((3, 4)))
-        assert len(w) == 1
-        for dt_code in data_type_codes.value_set():
-            data_type = data_type_codes.type[dt_code]
-            if data_type is np.void:  # not supported
-                continue
-            arr = np.zeros((10, 3), dtype=data_type)
-            da = GiftiDataArray.from_array(arr, 'triangle')
-            assert da.datatype == data_type_codes[arr.dtype]
-            bs_arr = arr.byteswap().newbyteorder()
-            da = GiftiDataArray.from_array(bs_arr, 'triangle')
-            assert da.datatype == data_type_codes[arr.dtype]
-
-
-def test_to_xml_open_close_deprecations():
-    # Smoke test on deprecated functions
-    da = GiftiDataArray(np.ones((1,)), 'triangle')
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('always', category=DeprecationWarning)
-        assert isinstance(da.to_xml_open(), str)
-        assert len(w) == 1
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('once', category=DeprecationWarning)
-        assert isinstance(da.to_xml_close(), str)
-        assert len(w) == 1
-
-
-def test_num_dim_deprecation():
-    da = GiftiDataArray(np.ones((2, 3, 4)))
-    # num_dim is property, set automatically from len(da.dims)
-    assert da.num_dim == 3
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('always', category=DeprecationWarning)
-        # OK setting num_dim to correct value, but raises DeprecationWarning
-        da.num_dim = 3
-        assert len(w) == 1
-        # Any other value gives a ValueError
-        pytest.raises(ValueError, setattr, da, 'num_dim', 4)
-
-
 def test_labeltable():
     img = GiftiImage()
     assert len(img.labeltable.labels) == 0
@@ -234,29 +204,102 @@ def test_labeltable():
     img.labeltable = new_table
     assert len(img.labeltable.labels) == 2
 
-    # Test deprecations
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('always', category=DeprecationWarning)
-        newer_table = GiftiLabelTable()
-        newer_table.labels += ['test', 'me', 'again']
-        img.set_labeltable(newer_table)
-        assert len(w) == 1
-        assert len(img.get_labeltable().labels) == 3
-        assert len(w) == 2
-
 
 def test_metadata():
-    nvpair = GiftiNVPairs('key', 'value')
-    md = GiftiMetaData(nvpair=nvpair)
-    assert md.data[0].name == 'key'
-    assert md.data[0].value == 'value'
-    # Test deprecation
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('always', category=DeprecationWarning)
-        assert md.get_metadata() == dict(key='value')
-        assert len(w) == 1
-        assert len(GiftiDataArray().get_metadata()) == 0
-        assert len(w) == 2
+    md = GiftiMetaData(key='value')
+    # Old initialization methods
+    with pytest.warns(DeprecationWarning) as w:
+        nvpair = GiftiNVPairs('key', 'value')
+    with pytest.warns(FutureWarning) as w:
+        md2 = GiftiMetaData(nvpair=nvpair)
+    assert len(w) == 1
+    with pytest.warns(DeprecationWarning) as w:
+        md3 = GiftiMetaData.from_dict({'key': 'value'})
+    assert md == md2 == md3 == {'key': 'value'}
+    # .data as a list of NVPairs is going away
+    with pytest.warns(DeprecationWarning) as w:
+        assert md.data[0].name == 'key'
+        assert md.data[0].value == 'value'
+    assert len(w) == 2
+
+
+def test_metadata_list_interface():
+    md = GiftiMetaData(key='value')
+    with pytest.warns(DeprecationWarning):
+        mdlist = md.data
+    assert len(mdlist) == 1
+    assert mdlist[0].name == 'key'
+    assert mdlist[0].value == 'value'
+
+    # Modify elements in-place
+    mdlist[0].name = 'foo'
+    assert mdlist[0].name == 'foo'
+    assert 'foo' in md
+    assert 'key' not in md
+    assert md['foo'] == 'value'
+    mdlist[0].value = 'bar'
+    assert mdlist[0].value == 'bar'
+    assert md['foo'] == 'bar'
+
+    # Append new NVPair
+    with pytest.warns(DeprecationWarning) as w:
+        nvpair = GiftiNVPairs('key', 'value')
+    mdlist.append(nvpair)
+    assert len(mdlist) == 2
+    assert mdlist[1].name == 'key'
+    assert mdlist[1].value == 'value'
+    assert len(md) == 2
+    assert md == {'foo': 'bar', 'key': 'value'}
+
+    # Clearing empties both
+    mdlist.clear()
+    assert len(mdlist) == 0
+    assert len(md) == 0
+
+    # Extension adds multiple keys
+    with pytest.warns(DeprecationWarning) as w:
+        foobar = GiftiNVPairs('foo', 'bar')
+    mdlist.extend([nvpair, foobar])
+    assert len(mdlist) == 2
+    assert len(md) == 2
+    assert md == {'key': 'value', 'foo': 'bar'}
+
+    # Insertion updates list order, though we don't attempt to preserve it in the dict
+    with pytest.warns(DeprecationWarning) as w:
+        lastone = GiftiNVPairs('last', 'one')
+    mdlist.insert(1, lastone)
+    assert len(mdlist) == 3
+    assert len(md) == 3
+    assert mdlist[1].name == 'last'
+    assert mdlist[1].value == 'one'
+    assert md == {'key': 'value', 'foo': 'bar', 'last': 'one'}
+
+    # Popping returns a pair
+    mypair = mdlist.pop(0)
+    assert isinstance(mypair, GiftiNVPairs)
+    assert mypair.name == 'key'
+    assert mypair.value == 'value'
+    assert len(mdlist) == 2
+    assert len(md) == 2
+    assert 'key' not in md
+    assert md == {'foo': 'bar', 'last': 'one'}
+    # Modifying the pair now does not affect md
+    mypair.name = 'completelynew'
+    mypair.value = 'strings'
+    assert 'completelynew' not in md
+    assert md == {'foo': 'bar', 'last': 'one'}
+    # Check popping from the end (lastone inserted before foobar)
+    lastpair = mdlist.pop()
+    assert len(mdlist) == 1
+    assert len(md) == 1
+    assert md == {'last': 'one'}
+
+    # And let's remove an old pair with a new object
+    with pytest.warns(DeprecationWarning) as w:
+        lastoneagain = GiftiNVPairs('last', 'one')
+    mdlist.remove(lastoneagain)
+    assert len(mdlist) == 0
+    assert len(md) == 0
 
 
 def test_gifti_label_rgba():
@@ -278,16 +321,11 @@ def test_gifti_label_rgba():
 
     def assign_rgba(gl, val):
         gl.rgba = val
+
     gl3 = GiftiLabel(**kwargs)
     pytest.raises(ValueError, assign_rgba, gl3, rgba[:2])
     pytest.raises(ValueError, assign_rgba, gl3, rgba.tolist() + rgba.tolist())
 
-    # Test deprecation
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('once', category=DeprecationWarning)
-        assert kwargs['red'] == gl3.get_rgba()[0]
-        assert len(w) == 1
-
     # Test default value
     gl4 = GiftiLabel()
     assert len(gl4.rgba) == 4
@@ -295,14 +333,14 @@ def test_gifti_label_rgba():
 
 
 def test_print_summary():
-    for fil in [DATA_FILE1, DATA_FILE2, DATA_FILE3, DATA_FILE4,
-                DATA_FILE5, DATA_FILE6]:
+    for fil in [DATA_FILE1, DATA_FILE2, DATA_FILE3, DATA_FILE4, DATA_FILE5, DATA_FILE6]:
         gimg = load(fil)
         gimg.print_summary()
 
 
 def test_gifti_coord():
     from ..gifti import GiftiCoordSystem
+
     gcs = GiftiCoordSystem()
     assert gcs.xform is not None
 
@@ -312,18 +350,11 @@ def test_gifti_coord():
     gcs.to_xml()
 
 
-def test_data_tag_deprecated():
-    with clear_and_catch_warnings() as w:
-        warnings.filterwarnings('once', category=DeprecationWarning)
-        data_tag(np.array([]), 'ASCII', '%i', 1)
-        assert len(w) == 1
-
-
 def test_gifti_round_trip():
     # From section 14.4 in GIFTI Surface Data Format Version 1.0
     # (with some adaptations)
 
-    test_data = b'''<?xml version="1.0" encoding="UTF-8"?>
+    test_data = b"""<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE GIFTI SYSTEM "http://www.nitrc.org/frs/download.php/1594/gifti.dtd">
 <GIFTI
 xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
@@ -380,14 +411,13 @@ ExternalFileName="" ExternalFileOffset="">
 0 2 3
 </Data>
 </DataArray>
-</GIFTI>'''
+</GIFTI>"""
 
     exp_verts = np.zeros((4, 3))
     exp_verts[0, 0] = 10.5
     exp_verts[1, 1] = 20.5
     exp_verts[2, 2] = 30.5
-    exp_faces = np.asarray([[0, 1, 2], [1, 2, 3], [0, 1, 3], [0, 2, 3]],
-                           dtype=np.int32)
+    exp_faces = np.asarray([[0, 1, 2], [1, 2, 3], [0, 1, 3], [0, 2, 3]], dtype=np.int32)
 
     def _check_gifti(gio):
         vertices = gio.get_arrays_from_intent('NIFTI_INTENT_POINTSET')[0].data
@@ -433,13 +463,13 @@ def test_data_array_round_trip():
 def test_darray_dtype_coercion_failures():
     dtypes = (np.uint8, np.int32, np.int64, np.float32, np.float64)
     encodings = ('ASCII', 'B64BIN', 'B64GZ')
-    for data_dtype, darray_dtype, encoding in itertools.product(dtypes,
-                                                                dtypes,
-                                                                encodings):
-        da = GiftiDataArray(np.arange(10).astype(data_dtype),
-                            encoding=encoding,
-                            intent='NIFTI_INTENT_NODE_INDEX',
-                            datatype=darray_dtype)
+    for data_dtype, darray_dtype, encoding in itertools.product(dtypes, dtypes, encodings):
+        da = GiftiDataArray(
+            np.arange(10, dtype=data_dtype),
+            encoding=encoding,
+            intent='NIFTI_INTENT_NODE_INDEX',
+            datatype=darray_dtype,
+        )
         gii = GiftiImage(darrays=[da])
         gii_copy = GiftiImage.from_bytes(gii.to_bytes())
         da_copy = gii_copy.darrays[0]
@@ -447,9 +477,8 @@ def test_darray_dtype_coercion_failures():
         assert_array_equal(da_copy.data, da.data)
 
 
-def test_gifti_file_close():
+def test_gifti_file_close(recwarn):
     gii = load(test_data('gifti', 'ascii.gii'))
-    with pytest.WarningsRecorder() as record:
-        with InTemporaryDirectory():
-            gii.to_filename('test.gii')
-    assert not any(isinstance(r.message, ResourceWarning) for r in record.list)
+    with InTemporaryDirectory():
+        gii.to_filename('test.gii')
+    assert not any(isinstance(r.message, ResourceWarning) for r in recwarn)
