@@ -1,19 +1,18 @@
-""" Testing reading DICOM files
-
+"""Testing reading DICOM files
 """
 
 from os.path import join as pjoin
 
 import numpy as np
+import pytest
+from numpy.testing import assert_array_almost_equal, assert_array_equal
 
 from nibabel.optpkg import optional_package
+
 from .. import dicomreaders as didr
-from .test_dicomwrappers import EXPECTED_AFFINE, EXPECTED_PARAMS, IO_DATA_PATH, DATA
+from .test_dicomwrappers import DATA, EXPECTED_AFFINE, EXPECTED_PARAMS, IO_DATA_PATH
 
-import pytest
-from numpy.testing import assert_array_equal, assert_array_almost_equal
-
-pydicom, _, setup_module = optional_package("pydicom")
+pydicom, _, setup_module = optional_package('pydicom')
 
 
 def test_read_dwi():
@@ -24,13 +23,12 @@ def test_read_dwi():
 
 
 def test_read_dwis():
-    data, aff, bs, gs = didr.read_mosaic_dwi_dir(IO_DATA_PATH,
-                                                 'siemens_dwi_*.dcm.gz')
+    data, aff, bs, gs = didr.read_mosaic_dwi_dir(IO_DATA_PATH, 'siemens_dwi_*.dcm.gz')
     assert data.ndim == 4
     assert_array_almost_equal(aff, EXPECTED_AFFINE)
     assert_array_almost_equal(bs, (0, EXPECTED_PARAMS[0]))
     assert_array_almost_equal(gs, (np.zeros((3,)), EXPECTED_PARAMS[1]))
-    with pytest.raises(IOError):
+    with pytest.raises(OSError):
         didr.read_mosaic_dwi_dir('improbable')
 
 
@@ -41,10 +39,7 @@ def test_passing_kwds():
     for func in (didr.read_mosaic_dwi_dir, didr.read_mosaic_dir):
         data, aff, bs, gs = func(IO_DATA_PATH, dwi_glob)
         # This should not raise an error
-        data2, aff2, bs2, gs2 = func(
-            IO_DATA_PATH,
-            dwi_glob,
-            dicom_kwargs=dict(force=True))
+        data2, aff2, bs2, gs2 = func(IO_DATA_PATH, dwi_glob, dicom_kwargs=dict(force=True))
         assert_array_equal(data, data2)
         # This should raise an error in pydicom.dicomio.read_file
         with pytest.raises(TypeError):
@@ -59,9 +54,8 @@ def test_passing_kwds():
 
 
 def test_slices_to_series():
-    dicom_files = (pjoin(IO_DATA_PATH, "%d.dcm" % i) for i in range(2))
+    dicom_files = (pjoin(IO_DATA_PATH, f'{i}.dcm') for i in range(2))
     wrappers = [didr.wrapper_from_file(f) for f in dicom_files]
     series = didr.slices_to_series(wrappers)
     assert len(series) == 1
     assert len(series[0]) == 2
-
