@@ -6,7 +6,7 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" A simple spatial image class
+"""A simple spatial image class
 
 The image class maintains the association between a 3D (or greater)
 array, and an affine transform that maps voxel coordinates to some world space.
@@ -21,14 +21,10 @@ It has attributes:
 methods:
 
    * .get_fdata()
-   * .get_data() (deprecated, use get_fdata() instead)
-   * .get_affine() (deprecated, use affine property instead)
-   * .get_header() (deprecated, use header property instead)
    * .to_filename(fname) - writes data to filename(s) derived from
      ``fname``, where the derivation may differ between formats.
    * to_file_map() - save image to files with which the image is already
      associated.
-   * .get_shape() (deprecated)
 
 properties:
 
@@ -95,6 +91,7 @@ corresponding to the file types that an image needs for storage.  For
 example, the Analyze data format needs an ``image`` and a ``header``
 file type for storage:
 
+   >>> import numpy as np
    >>> import nibabel as nib
    >>> data = np.arange(24, dtype='f4').reshape((2,3,4))
    >>> img = nib.AnalyzeImage(data, np.eye(4))
@@ -109,7 +106,7 @@ contain enough information so that an existing image instance can save
 itself back to the files pointed to in ``file_map``.  When a file holder
 holds active file-like objects, then these may be affected by the
 initial file read; in this case, the contains file-like objects need to
-carry the position at which a write (with ``to_files``) should place the
+carry the position at which a write (with ``to_file_map``) should place the
 data.  The ``file_map`` contents should therefore be such, that this will
 work:
 
@@ -131,38 +128,37 @@ work:
     >>> img3 = nib.AnalyzeImage.from_file_map(file_map)
     >>> np.all(img3.get_fdata(dtype=np.float32) == data)
     True
-
 """
+from __future__ import annotations
+
+from typing import Type
 
 import numpy as np
 
-from .filebasedimages import FileBasedHeader
 from .dataobj_images import DataobjImage
 from .filebasedimages import ImageFileError  # noqa
+from .filebasedimages import FileBasedHeader
+from .fileslice import canonical_slicers
+from .orientations import apply_orientation, inv_ornt_aff
 from .viewers import OrthoSlicer3D
 from .volumeutils import shape_zoom_affine
-from .fileslice import canonical_slicers
-from .deprecated import deprecate_with_version
-from .orientations import apply_orientation, inv_ornt_aff
 
 
 class HeaderDataError(Exception):
-    """ Class to indicate error in getting or setting header data """
+    """Class to indicate error in getting or setting header data"""
 
 
 class HeaderTypeError(Exception):
-    """ Class to indicate error in parameters into header functions """
+    """Class to indicate error in parameters into header functions"""
 
 
 class SpatialHeader(FileBasedHeader):
-    """ Template class to implement header protocol """
+    """Template class to implement header protocol"""
+
     default_x_flip = True
     data_layout = 'F'
 
-    def __init__(self,
-                 data_dtype=np.float32,
-                 shape=(0,),
-                 zooms=None):
+    def __init__(self, data_dtype=np.float32, shape=(0,), zooms=None):
         self.set_data_dtype(data_dtype)
         self._zooms = ()
         self.set_data_shape(shape)
@@ -179,9 +175,7 @@ class SpatialHeader(FileBasedHeader):
         # different field names
         if type(header) == klass:
             return header.copy()
-        return klass(header.get_data_dtype(),
-                     header.get_data_shape(),
-                     header.get_zooms())
+        return klass(header.get_data_dtype(), header.get_data_shape(), header.get_zooms())
 
     @classmethod
     def from_fileobj(klass, fileobj):
@@ -191,18 +185,17 @@ class SpatialHeader(FileBasedHeader):
         raise NotImplementedError
 
     def __eq__(self, other):
-        return ((self.get_data_dtype(),
-                 self.get_data_shape(),
-                 self.get_zooms()) ==
-                (other.get_data_dtype(),
-                 other.get_data_shape(),
-                 other.get_zooms()))
+        return (self.get_data_dtype(), self.get_data_shape(), self.get_zooms()) == (
+            other.get_data_dtype(),
+            other.get_data_shape(),
+            other.get_zooms(),
+        )
 
     def __ne__(self, other):
         return not self == other
 
     def copy(self):
-        """ Copy object to independent representation
+        """Copy object to independent representation
 
         The copy should not be affected by any changes to the original
         object.
@@ -237,8 +230,7 @@ class SpatialHeader(FileBasedHeader):
         shape = self.get_data_shape()
         ndim = len(shape)
         if len(zooms) != ndim:
-            raise HeaderDataError('Expecting %d zoom values for ndim %d'
-                                  % (ndim, ndim))
+            raise HeaderDataError('Expecting %d zoom values for ndim %d' % (ndim, ndim))
         if len([z for z in zooms if z < 0]):
             raise HeaderDataError('zooms must be positive')
         self._zooms = zooms
@@ -246,13 +238,12 @@ class SpatialHeader(FileBasedHeader):
     def get_base_affine(self):
         shape = self.get_data_shape()
         zooms = self.get_zooms()
-        return shape_zoom_affine(shape, zooms,
-                                 self.default_x_flip)
+        return shape_zoom_affine(shape, zooms, self.default_x_flip)
 
     get_best_affine = get_base_affine
 
     def data_to_fileobj(self, data, fileobj, rescale=True):
-        """ Write array data `data` as binary to `fileobj`
+        """Write array data `data` as binary to `fileobj`
 
         Parameters
         ----------
@@ -269,7 +260,7 @@ class SpatialHeader(FileBasedHeader):
         fileobj.write(data.astype(dtype).tobytes(order=self.data_layout))
 
     def data_from_fileobj(self, fileobj):
-        """ Read binary image data from `fileobj` """
+        """Read binary image data from `fileobj`"""
         dtype = self.get_data_dtype()
         shape = self.get_data_shape()
         data_size = int(np.prod(shape) * dtype.itemsize)
@@ -278,7 +269,7 @@ class SpatialHeader(FileBasedHeader):
 
 
 def supported_np_types(obj):
-    """ Numpy data types that instance `obj` supports
+    """Numpy data types that instance `obj` supports
 
     Parameters
     ----------
@@ -308,32 +299,24 @@ def supported_np_types(obj):
     return set(supported)
 
 
-class Header(SpatialHeader):
-    """Alias for SpatialHeader; kept for backwards compatibility."""
-
-    @deprecate_with_version('Header class is deprecated.\n'
-                            'Please use SpatialHeader instead.'
-                            'instead.',
-                            '2.1', '4.0')
-    def __init__(self, *args, **kwargs):
-        super(Header, self).__init__(*args, **kwargs)
-
-
 class ImageDataError(Exception):
     pass
 
 
-class SpatialFirstSlicer(object):
-    """ Slicing interface that returns a new image with an updated affine
+class SpatialFirstSlicer:
+    """Slicing interface that returns a new image with an updated affine
 
     Checks that an image's first three axes are spatial
     """
+
     def __init__(self, img):
         # Local import to avoid circular import on module load
         from .imageclasses import spatial_axes_first
+
         if not spatial_axes_first(img):
-            raise ValueError("Cannot predict position of spatial axes for "
-                             "Image type " + img.__class__.__name__)
+            raise ValueError(
+                'Cannot predict position of spatial axes for image type {img.__class__.__name__}'
+            )
         self.img = img
 
     def __getitem__(self, slicer):
@@ -344,13 +327,13 @@ class SpatialFirstSlicer(object):
 
         dataobj = self.img.dataobj[slicer]
         if any(dim == 0 for dim in dataobj.shape):
-            raise IndexError("Empty slice requested")
+            raise IndexError('Empty slice requested')
 
         affine = self.slice_affine(slicer)
         return self.img.__class__(dataobj.copy(), affine, self.img.header)
 
     def check_slicing(self, slicer, return_spatial=False):
-        """ Canonicalize slicers and check for scalar indices in spatial dims
+        """Canonicalize slicers and check for scalar indices in spatial dims
 
         Parameters
         ----------
@@ -373,14 +356,15 @@ class SpatialFirstSlicer(object):
         spatial_slices = slicer[:3]
         for subslicer in spatial_slices:
             if subslicer is None:
-                raise IndexError("New axis not permitted in spatial dimensions")
+                raise IndexError('New axis not permitted in spatial dimensions')
             elif isinstance(subslicer, int):
-                raise IndexError("Scalar indices disallowed in spatial dimensions; "
-                                 "Use `[x]` or `x:x+1`.")
+                raise IndexError(
+                    'Scalar indices disallowed in spatial dimensions; Use `[x]` or `x:x+1`.'
+                )
         return spatial_slices if return_spatial else slicer
 
     def slice_affine(self, slicer):
-        """ Retrieve affine for current image, if sliced by a given index
+        """Retrieve affine for current image, if sliced by a given index
 
         Applies scaling if down-sampling is applied, and adjusts the intercept
         to account for any cropping.
@@ -408,7 +392,7 @@ class SpatialFirstSlicer(object):
         for i, subslicer in enumerate(slicer):
             if isinstance(subslicer, slice):
                 if subslicer.step == 0:
-                    raise ValueError("slice step cannot be 0")
+                    raise ValueError('slice step cannot be 0')
                 transform[i, i] = subslicer.step if subslicer.step is not None else 1
                 transform[i, 3] = subslicer.start or 0
             # If slicer is None, nothing to do
@@ -417,13 +401,13 @@ class SpatialFirstSlicer(object):
 
 
 class SpatialImage(DataobjImage):
-    """ Template class for volumetric (3D/4D) images """
-    header_class = SpatialHeader
+    """Template class for volumetric (3D/4D) images"""
+
+    header_class: Type[SpatialHeader] = SpatialHeader
     ImageSlicer = SpatialFirstSlicer
 
-    def __init__(self, dataobj, affine, header=None,
-                 extra=None, file_map=None):
-        """ Initialize image
+    def __init__(self, dataobj, affine, header=None, extra=None, file_map=None):
+        """Initialize image
 
         The image is a combination of (array-like, affine matrix, header), with
         optional metadata in `extra`, and filename / file-like objects
@@ -432,11 +416,11 @@ class SpatialImage(DataobjImage):
         Parameters
         ----------
         dataobj : object
-           Object containg image data.  It should be some object that retuns an
+           Object containing image data.  It should be some object that returns an
            array from ``np.asanyarray``.  It should have a ``shape`` attribute
            or property
         affine : None or (4,4) array-like
-           homogenous affine giving relationship between voxel coordinates and
+           homogeneous affine giving relationship between voxel coordinates and
            world coordinates.  Affine can also be None.  In this case,
            ``obj.affine`` also returns None, and the affine as written to disk
            will depend on the file format.
@@ -448,8 +432,7 @@ class SpatialImage(DataobjImage):
         file_map : mapping, optional
            mapping giving file information for this image format
         """
-        super(SpatialImage, self).__init__(dataobj, header=header, extra=extra,
-                                           file_map=file_map)
+        super().__init__(dataobj, header=header, extra=extra, file_map=file_map)
         if affine is not None:
             # Check that affine is array-like 4,4.  Maybe this is too strict at
             # this abstract level, but so far I think all image formats we know
@@ -474,7 +457,7 @@ class SpatialImage(DataobjImage):
         return self._affine
 
     def update_header(self):
-        """ Harmonize header with image data and affine
+        """Harmonize header with image data and affine
 
         >>> data = np.zeros((2,3,4))
         >>> affine = np.diag([1.0,2.0,3.0,1.0])
@@ -503,7 +486,7 @@ class SpatialImage(DataobjImage):
         self._affine2header()
 
     def _affine2header(self):
-        """ Unconditionally set affine into the header """
+        """Unconditionally set affine into the header"""
         RZS = self._affine[:3, :3]
         vox = np.sqrt(np.sum(RZS * RZS, axis=0))
         hdr = self._header
@@ -515,12 +498,14 @@ class SpatialImage(DataobjImage):
     def __str__(self):
         shape = self.shape
         affine = self.affine
-        return '\n'.join((str(self.__class__),
-                          f'data shape {shape}',
-                          'affine: ',
-                          str(affine),
-                          'metadata:',
-                          str(self._header)))
+        return f"""
+{self.__class__}
+data shape {shape}
+affine:
+{affine}
+metadata:
+{self._header}
+"""
 
     def get_data_dtype(self):
         return self._header.get_data_dtype()
@@ -528,18 +513,9 @@ class SpatialImage(DataobjImage):
     def set_data_dtype(self, dtype):
         self._header.set_data_dtype(dtype)
 
-    @deprecate_with_version('get_affine method is deprecated.\n'
-                            'Please use the ``img.affine`` property '
-                            'instead.',
-                            '2.1', '4.0')
-    def get_affine(self):
-        """ Get affine from image
-        """
-        return self.affine
-
     @classmethod
     def from_image(klass, img):
-        """ Class method to create new instance of own class from `img`
+        """Class method to create new instance of own class from `img`
 
         Parameters
         ----------
@@ -552,14 +528,16 @@ class SpatialImage(DataobjImage):
         cimg : ``spatialimage`` instance
            Image, of our own class
         """
-        return klass(img.dataobj,
-                     img.affine,
-                     klass.header_class.from_header(img.header),
-                     extra=img.extra.copy())
+        return klass(
+            img.dataobj,
+            img.affine,
+            klass.header_class.from_header(img.header),
+            extra=img.extra.copy(),
+        )
 
     @property
     def slicer(self):
-        """ Slicer object that returns cropped and subsampled images
+        """Slicer object that returns cropped and subsampled images
 
         The image is resliced in the current orientation; no rotation or
         resampling is performed, and no attempt is made to filter the image
@@ -578,16 +556,17 @@ class SpatialImage(DataobjImage):
         return self.ImageSlicer(self)
 
     def __getitem__(self, idx):
-        """ No slicing or dictionary interface for images
+        """No slicing or dictionary interface for images
 
         Use the slicer attribute to perform cropping and subsampling at your
         own risk.
         """
         raise TypeError(
-            "Cannot slice image objects; consider using `img.slicer[slice]` "
-            "to generate a sliced image (see documentation for caveats) or "
-            "slicing image array data with `img.dataobj[slice]` or "
-            "`img.get_fdata()[slice]`")
+            'Cannot slice image objects; consider using `img.slicer[slice]` '
+            'to generate a sliced image (see documentation for caveats) or '
+            'slicing image array data with `img.dataobj[slice]` or '
+            '`img.get_fdata()[slice]`'
+        )
 
     def orthoview(self):
         """Plot the image using OrthoSlicer3D
@@ -603,8 +582,7 @@ class SpatialImage(DataobjImage):
         consider using viewer.show() (equivalently plt.show()) to show
         the figure.
         """
-        return OrthoSlicer3D(self.dataobj, self.affine,
-                             title=self.get_filename())
+        return OrthoSlicer3D(self.dataobj, self.affine, title=self.get_filename())
 
     def as_reoriented(self, ornt):
         """Apply an orientation change and return a new image
