@@ -6,35 +6,33 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Tests for arrayproxy module
+"""Tests for arrayproxy module
 """
 
-import warnings
-import gzip
 import contextlib
-
+import gzip
 import pickle
+import warnings
 from io import BytesIO
-from ..tmpdirs import InTemporaryDirectory
-
-import numpy as np
-
-from ..arrayproxy import (ArrayProxy, is_proxy, reshape_dataobj)
-from ..openers import ImageOpener
-from ..nifti1 import Nifti1Header
-
 from unittest import mock
 
-from numpy.testing import assert_array_equal, assert_array_almost_equal
+import numpy as np
 import pytest
-from ..testing import memmap_after_ufunc
+from numpy.testing import assert_array_almost_equal, assert_array_equal
+from packaging.version import Version
 
+from .. import __version__
+from ..arrayproxy import ArrayProxy, get_obj_dtype, is_proxy, reshape_dataobj
+from ..deprecator import ExpiredDeprecationError
+from ..nifti1 import Nifti1Header
+from ..openers import ImageOpener
+from ..testing import memmap_after_ufunc
+from ..tmpdirs import InTemporaryDirectory
 from .test_fileslice import slicer_samples
 from .test_openers import patch_indexed_gzip
 
 
-class FunkyHeader(object):
-
+class FunkyHeader:
     def __init__(self, shape):
         self.shape = shape
 
@@ -57,6 +55,11 @@ class FunkyHeader(object):
 
 class CArrayProxy(ArrayProxy):
     # C array memory layout
+    _default_order = 'C'
+
+
+class DeprecatedCArrayProxy(ArrayProxy):
+    # Used in test_deprecated_order_classvar. Remove when that test is removed (8.0)
     order = 'C'
 
 
@@ -81,6 +84,9 @@ def test_init():
     assert ap.shape != shape
     # Data stays the same, also
     assert_array_equal(np.asarray(ap), arr)
+    # You wouldn't do this, but order=None explicitly requests the default order
+    ap2 = ArrayProxy(bio, FunkyHeader(arr.shape), order=None)
+    assert_array_equal(np.asarray(ap2), arr)
     # C order also possible
     bio = BytesIO()
     bio.seek(16)
@@ -90,6 +96,8 @@ def test_init():
     # Illegal init
     with pytest.raises(TypeError):
         ArrayProxy(bio, object())
+    with pytest.raises(ValueError):
+        ArrayProxy(bio, hdr, order='badval')
 
 
 def test_tuplespec():
@@ -101,18 +109,14 @@ def test_tuplespec():
     bio.write(arr.tobytes(order='F'))
     # Create equivalent header and tuple specs
     hdr = FunkyHeader(shape)
-    tuple_spec = (hdr.get_data_shape(), hdr.get_data_dtype(),
-                  hdr.get_data_offset(), 1., 0.)
+    tuple_spec = (hdr.get_data_shape(), hdr.get_data_dtype(), hdr.get_data_offset(), 1.0, 0.0)
     ap_header = ArrayProxy(bio, hdr)
     ap_tuple = ArrayProxy(bio, tuple_spec)
     # Header and tuple specs produce identical behavior
     for prop in ('shape', 'dtype', 'offset', 'slope', 'inter', 'is_proxy'):
         assert getattr(ap_header, prop) == getattr(ap_tuple, prop)
-    for method, args in (('get_unscaled', ()), ('__array__', ()),
-                         ('__getitem__', ((0, 2, 1), ))
-                         ):
-        assert_array_equal(getattr(ap_header, method)(*args),
-                           getattr(ap_tuple, method)(*args))
+    for method, args in (('get_unscaled', ()), ('__array__', ()), ('__getitem__', ((0, 2, 1),))):
+        assert_array_equal(getattr(ap_header, method)(*args), getattr(ap_tuple, method)(*args))
     # Partial tuples of length 2-4 are also valid
     for n in range(2, 5):
         ArrayProxy(bio, tuple_spec[:n])
@@ -154,33 +158,87 @@ def test_nifti1_init():
         assert_array_equal(np.asarray(ap), arr * 2.0 + 10)
 
 
-def test_proxy_slicing():
-    shapes = (15, 16, 17)
-    for n_dim in range(1, len(shapes) + 1):
-        shape = shapes[:n_dim]
-        arr = np.arange(np.prod(shape)).reshape(shape)
-        for offset in (0, 20):
-            hdr = Nifti1Header()
-            hdr.set_data_offset(offset)
-            hdr.set_data_dtype(arr.dtype)
-            hdr.set_data_shape(shape)
-            for order, klass in ('F', ArrayProxy), ('C', CArrayProxy):
-                fobj = BytesIO()
-                fobj.write(b'\0' * offset)
-                fobj.write(arr.tobytes(order=order))
-                prox = klass(fobj, hdr)
-                for sliceobj in slicer_samples(shape):
-                    assert_array_equal(arr[sliceobj], prox[sliceobj])
-    # Check slicing works with scaling
+@pytest.mark.parametrize('n_dim', (1, 2, 3))
+@pytest.mark.parametrize('offset', (0, 20))
+def test_proxy_slicing(n_dim, offset):
+    shape = (15, 16, 17)[:n_dim]
+    arr = np.arange(np.prod(shape)).reshape(shape)
+    hdr = Nifti1Header()
+    hdr.set_data_offset(offset)
+    hdr.set_data_dtype(arr.dtype)
+    hdr.set_data_shape(shape)
+    for order, klass in ('F', ArrayProxy), ('C', CArrayProxy):
+        fobj = BytesIO()
+        fobj.write(b'\0' * offset)
+        fobj.write(arr.tobytes(order=order))
+        prox = klass(fobj, hdr)
+        assert prox.order == order
+        for sliceobj in slicer_samples(shape):
+            assert_array_equal(arr[sliceobj], prox[sliceobj])
+
+
+def test_proxy_slicing_with_scaling():
+    shape = (15, 16, 17)
+    offset = 20
+    arr = np.arange(np.prod(shape)).reshape(shape)
+    hdr = Nifti1Header()
+    hdr.set_data_offset(offset)
+    hdr.set_data_dtype(arr.dtype)
+    hdr.set_data_shape(shape)
     hdr.set_slope_inter(2.0, 1.0)
     fobj = BytesIO()
-    fobj.write(b'\0' * offset)
+    fobj.write(bytes(offset))
     fobj.write(arr.tobytes(order='F'))
     prox = ArrayProxy(fobj, hdr)
     sliceobj = (None, slice(None), 1, -1)
     assert_array_equal(arr[sliceobj] * 2.0 + 1.0, prox[sliceobj])
 
 
+@pytest.mark.parametrize('order', ('C', 'F'))
+def test_order_override(order):
+    shape = (15, 16, 17)
+    arr = np.arange(np.prod(shape)).reshape(shape)
+    fobj = BytesIO()
+    fobj.write(arr.tobytes(order=order))
+    for klass in (ArrayProxy, CArrayProxy):
+        prox = klass(fobj, (shape, arr.dtype), order=order)
+        assert prox.order == order
+        sliceobj = (None, slice(None), 1, -1)
+        assert_array_equal(arr[sliceobj], prox[sliceobj])
+
+
+def test_deprecated_order_classvar():
+    shape = (15, 16, 17)
+    arr = np.arange(np.prod(shape)).reshape(shape)
+    fobj = BytesIO()
+    fobj.write(arr.tobytes(order='C'))
+    sliceobj = (None, slice(None), 1, -1)
+
+    # We don't really care about the original order, just that the behavior
+    # of the deprecated mode matches the new behavior
+    fprox = ArrayProxy(fobj, (shape, arr.dtype), order='F')
+    cprox = ArrayProxy(fobj, (shape, arr.dtype), order='C')
+
+    # Start raising errors when we crank the dev version
+    if Version(__version__) >= Version('7.0.0.dev0'):
+        cm = pytest.raises(ExpiredDeprecationError)
+    else:
+        cm = pytest.deprecated_call()
+
+    with cm:
+        prox = DeprecatedCArrayProxy(fobj, (shape, arr.dtype))
+        assert prox.order == 'C'
+        assert_array_equal(prox[sliceobj], cprox[sliceobj])
+    with cm:
+        prox = DeprecatedCArrayProxy(fobj, (shape, arr.dtype), order='C')
+        assert prox.order == 'C'
+        assert_array_equal(prox[sliceobj], cprox[sliceobj])
+    with cm:
+        prox = DeprecatedCArrayProxy(fobj, (shape, arr.dtype), order='F')
+        assert prox.order == 'F'
+        assert_array_equal(prox[sliceobj], fprox[sliceobj])
+
+
 def test_is_proxy():
     # Test is_proxy function
     hdr = FunkyHeader((2, 3, 4))
@@ -191,8 +249,9 @@ def test_is_proxy():
     assert not is_proxy(hdr)
     assert not is_proxy(np.zeros((2, 3, 4)))
 
-    class NP(object):
+    class NP:
         is_proxy = False
+
     assert not is_proxy(NP())
 
 
@@ -205,21 +264,17 @@ def test_reshape_dataobj():
     arr = np.arange(np.prod(shape), dtype=prox.dtype).reshape(shape)
     bio.write(b'\x00' * prox.offset + arr.tobytes(order='F'))
     assert_array_equal(prox, arr)
-    assert_array_equal(reshape_dataobj(prox, (2, 3, 4)),
-                       np.reshape(arr, (2, 3, 4)))
+    assert_array_equal(reshape_dataobj(prox, (2, 3, 4)), np.reshape(arr, (2, 3, 4)))
     assert prox.shape == shape
     assert arr.shape == shape
-    assert_array_equal(reshape_dataobj(arr, (2, 3, 4)),
-                       np.reshape(arr, (2, 3, 4)))
+    assert_array_equal(reshape_dataobj(arr, (2, 3, 4)), np.reshape(arr, (2, 3, 4)))
     assert arr.shape == shape
 
-    class ArrGiver(object):
-
+    class ArrGiver:
         def __array__(self):
             return arr
 
-    assert_array_equal(reshape_dataobj(ArrGiver(), (2, 3, 4)),
-                       np.reshape(arr, (2, 3, 4)))
+    assert_array_equal(reshape_dataobj(ArrGiver(), (2, 3, 4)), np.reshape(arr, (2, 3, 4)))
     assert arr.shape == shape
 
 
@@ -240,12 +295,35 @@ def test_reshaped_is_proxy():
         prox.reshape((2, -1, 5))
 
 
+def test_get_obj_dtype():
+    # Check get_obj_dtype(obj) returns same result as array(obj).dtype
+    bio = BytesIO()
+    shape = (2, 3, 4)
+    hdr = Nifti1Header()
+    arr = np.arange(24, dtype=np.int16).reshape(shape)
+    write_raw_data(arr, hdr, bio)
+    hdr.set_slope_inter(2, 10)
+    prox = ArrayProxy(bio, hdr)
+    assert get_obj_dtype(prox) == np.dtype('float64')
+    assert get_obj_dtype(np.array(prox)) == np.dtype('float64')
+    hdr.set_slope_inter(1, 0)
+    prox = ArrayProxy(bio, hdr)
+    assert get_obj_dtype(prox) == np.dtype('int16')
+    assert get_obj_dtype(np.array(prox)) == np.dtype('int16')
+
+    class ArrGiver:
+        def __array__(self):
+            return arr
+
+    assert get_obj_dtype(ArrGiver()) == np.dtype('int16')
+
+
 def test_get_unscaled():
     # Test fetch of raw array
     class FunkyHeader2(FunkyHeader):
-
         def get_slope_inter(self):
             return 2.1, 3.14
+
     shape = (2, 3, 4)
     hdr = FunkyHeader2(shape)
     bio = BytesIO()
@@ -265,10 +343,8 @@ def test_mmap():
     check_mmap(hdr, hdr.get_data_offset(), ArrayProxy)
 
 
-def check_mmap(hdr, offset, proxy_class,
-               has_scaling=False,
-               unscaled_is_view=True):
-    """ Assert that array proxies return memory maps as expected
+def check_mmap(hdr, offset, proxy_class, has_scaling=False, unscaled_is_view=True):
+    """Assert that array proxies return memory maps as expected
 
     Parameters
     ----------
@@ -303,14 +379,15 @@ def check_mmap(hdr, offset, proxy_class,
             fobj.write(b' ' * offset)
             fobj.write(arr.tobytes(order='F'))
         for mmap, expected_mode in (
-                # mmap value, expected memmap mode
-                # mmap=None -> no mmap value
-                # expected mode=None -> no memmap returned
-                (None, 'c'),
-                (True, 'c'),
-                ('c', 'c'),
-                ('r', 'r'),
-                (False, None)):
+            # mmap value, expected memmap mode
+            # mmap=None -> no mmap value
+            # expected mode=None -> no memmap returned
+            (None, 'c'),
+            (True, 'c'),
+            ('c', 'c'),
+            ('r', 'r'),
+            (False, None),
+        ):
             kwargs = {}
             if mmap is not None:
                 kwargs['mmap'] = mmap
@@ -318,7 +395,7 @@ def check_mmap(hdr, offset, proxy_class,
             unscaled = prox.get_unscaled()
             back_data = np.asanyarray(prox)
             unscaled_is_mmap = isinstance(unscaled, np.memmap)
-            back_is_mmap =  isinstance(back_data, np.memmap)
+            back_is_mmap = isinstance(back_data, np.memmap)
             if expected_mode is None:
                 assert not unscaled_is_mmap
                 assert not back_is_mmap
@@ -342,8 +419,9 @@ def check_mmap(hdr, offset, proxy_class,
 # created
 class CountingImageOpener(ImageOpener):
     num_openers = 0
+
     def __init__(self, *args, **kwargs):
-        super(CountingImageOpener, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         CountingImageOpener.num_openers += 1
 
 
@@ -351,7 +429,7 @@ def _count_ImageOpeners(proxy, data, voxels):
     CountingImageOpener.num_openers = 0
     # expected data is defined in the test_keep_file_open_* tests
     for i in range(voxels.shape[0]):
-        x, y, z = [int(c) for c in voxels[i, :]]
+        x, y, z = (int(c) for c in voxels[i, :])
         assert proxy[x, y, z] == x * 100 + y * 10 + z
     return CountingImageOpener.num_openers
 
@@ -383,32 +461,32 @@ def test_keep_file_open_true_false_invalid():
     #  - expected value for internal ArrayProxy._keep_file_open flag
     tests = [
         # open file handle - kfo and have_igzip are both irrelevant
-        ('open', False,  False, False, False),
-        ('open', False,  True,  False, False),
-        ('open', True,   False, False, False),
-        ('open', True,   True,  False, False),
+        ('open', False, False, False, False),
+        ('open', False, True, False, False),
+        ('open', True, False, False, False),
+        ('open', True, True, False, False),
         # non-gzip file - have_igzip is irrelevant, decision should be made
         # solely from kfo flag
-        ('bin', False,  False, False, False),
-        ('bin', False,  True,  False, False),
-        ('bin', True,   False, True,  True),
-        ('bin', True,   True,  True,  True),
+        ('bin', False, False, False, False),
+        ('bin', False, True, False, False),
+        ('bin', True, False, True, True),
+        ('bin', True, True, True, True),
         # gzip file. If igzip is present, we persist the ImageOpener.
-        ('gz', False,  False, False, False),
-        ('gz', False,  True,  True,  False),
-        ('gz', True,   False, True,  True),
-        ('gz', True,   True,  True,  True),
-        ]
+        ('gz', False, False, False, False),
+        ('gz', False, True, True, False),
+        ('gz', True, False, True, True),
+        ('gz', True, True, True, True),
+    ]
 
     dtype = np.float32
-    data  = np.arange(1000, dtype=dtype).reshape((10, 10, 10))
+    data = np.arange(1000, dtype=dtype).reshape((10, 10, 10))
     voxels = np.random.randint(0, 10, (10, 3))
 
     for test in tests:
         filetype, kfo, have_igzip, exp_persist, exp_kfo = test
-        with InTemporaryDirectory(), \
-             mock.patch('nibabel.openers.ImageOpener', CountingImageOpener), \
-             patch_indexed_gzip(have_igzip):
+        with InTemporaryDirectory(), mock.patch(
+            'nibabel.openers.ImageOpener', CountingImageOpener
+        ), patch_indexed_gzip(have_igzip):
             fname = f'testdata.{filetype}'
             # create the test data file
             if filetype == 'gz':
@@ -427,8 +505,7 @@ def test_keep_file_open_true_false_invalid():
                 fobj1 = fname
                 fobj2 = fname
             try:
-                proxy = ArrayProxy(fobj1, ((10, 10, 10), dtype),
-                                   keep_file_open=kfo)
+                proxy = ArrayProxy(fobj1, ((10, 10, 10), dtype), keep_file_open=kfo)
                 # We also test that we get the same behaviour when the
                 # KEEP_FILE_OPEN_DEFAULT flag is changed
                 with patch_keep_file_open_default(kfo):
@@ -471,8 +548,7 @@ def test_keep_file_open_true_false_invalid():
 
         for invalid_kfo in (55, 'auto', 'cauto'):
             with pytest.raises(ValueError):
-                ArrayProxy(fname, ((10, 10, 10), dtype),
-                           keep_file_open=invalid_kfo)
+                ArrayProxy(fname, ((10, 10, 10), dtype), keep_file_open=invalid_kfo)
             with patch_keep_file_open_default(invalid_kfo):
                 with pytest.raises(ValueError):
                     ArrayProxy(fname, ((10, 10, 10), dtype))
