@@ -1,14 +1,17 @@
-""" Testing `deprecated` module
+"""Testing `deprecated` module
 """
 
 import warnings
+
 import pytest
 
 from nibabel import pkg_info
-from nibabel.deprecated import (ModuleProxy, FutureWarningMixin,
-                                deprecate_with_version)
-
-
+from nibabel.deprecated import (
+    FutureWarningMixin,
+    ModuleProxy,
+    alert_future_error,
+    deprecate_with_version,
+)
 from nibabel.tests.test_deprecator import TestDeprecatorFunc as _TestDF
 
 
@@ -32,8 +35,7 @@ def test_module_proxy():
 
 def test_futurewarning_mixin():
     # Test mixin for FutureWarning
-    class C(object):
-
+    class C:
         def __init__(self, val):
             self.val = val
 
@@ -44,7 +46,8 @@ def test_futurewarning_mixin():
         pass
 
     class E(FutureWarningMixin, C):
-        warn_message = "Oh no, not this one"
+        warn_message = 'Oh no, not this one'
+
     with warnings.catch_warnings(record=True) as warns:
         c = C(42)
         assert c.meth() == 42
@@ -53,8 +56,7 @@ def test_futurewarning_mixin():
         assert d.meth() == 42
         warn = warns.pop(0)
         assert warn.category == FutureWarning
-        assert (str(warn.message) ==
-                     'This class will be removed in future versions')
+        assert str(warn.message) == 'This class will be removed in future versions'
         e = E(42)
         assert e.meth() == 42
         warn = warns.pop(0)
@@ -63,7 +65,7 @@ def test_futurewarning_mixin():
 
 
 class TestNibabelDeprecator(_TestDF):
-    """ Test deprecations against nibabel version """
+    """Test deprecations against nibabel version"""
 
     dep_func = deprecate_with_version
 
@@ -82,3 +84,36 @@ def test_dev_version():
             assert func() == 99
     finally:
         pkg_info.cmp_pkg_version.__defaults__ = ('2.0',)
+
+
+def test_alert_future_error():
+    with pytest.warns(FutureWarning):
+        alert_future_error(
+            'Message',
+            '9999.9.9',
+            warning_rec='Silence this warning by doing XYZ.',
+            error_rec='Fix this issue by doing XYZ.',
+        )
+    with pytest.raises(RuntimeError):
+        alert_future_error(
+            'Message',
+            '1.0.0',
+            warning_rec='Silence this warning by doing XYZ.',
+            error_rec='Fix this issue by doing XYZ.',
+        )
+    with pytest.raises(ValueError):
+        alert_future_error(
+            'Message',
+            '1.0.0',
+            warning_rec='Silence this warning by doing XYZ.',
+            error_rec='Fix this issue by doing XYZ.',
+            error_class=ValueError,
+        )
+    with pytest.raises(ValueError):
+        alert_future_error(
+            'Message',
+            '2.0.0',  # Error if we equal the (patched) version
+            warning_rec='Silence this warning by doing XYZ.',
+            error_rec='Fix this issue by doing XYZ.',
+            error_class=ValueError,
+        )
