@@ -1,4 +1,4 @@
-""" Validate image API
+"""Validate image API
 
 What is the image API?
 
@@ -23,38 +23,60 @@ What is the image API?
   cached, but False otherwise.
 """
 
+import io
+import pathlib
 import warnings
 from functools import partial
 from itertools import product
-import pathlib
 
 import numpy as np
 
 from ..optpkg import optional_package
-_, have_scipy, _ = optional_package('scipy')
-from .._h5py_compat import have_h5py
 
-from .. import (AnalyzeImage, Spm99AnalyzeImage, Spm2AnalyzeImage,
-                Nifti1Pair, Nifti1Image, Nifti2Pair, Nifti2Image,
-                GiftiImage,
-                MGHImage, Minc1Image, Minc2Image, is_proxy)
-from ..spatialimages import SpatialImage
-from .. import minc1, minc2, parrec, brikhead
+_, have_scipy, _ = optional_package('scipy')
+_, have_h5py, _ = optional_package('h5py')
 
 import unittest
+
 import pytest
+from numpy.testing import assert_allclose, assert_almost_equal, assert_array_equal, assert_warns
 
-from numpy.testing import assert_almost_equal, assert_array_equal, assert_warns, assert_allclose
-from nibabel.testing import (bytesio_round_trip, bytesio_filemap, assert_data_similar,
-                             clear_and_catch_warnings, nullcontext)
-from ..tmpdirs import InTemporaryDirectory
+from nibabel.arraywriters import WriterError
+from nibabel.testing import (
+    assert_data_similar,
+    bytesio_filemap,
+    bytesio_round_trip,
+    clear_and_catch_warnings,
+    expires,
+    nullcontext,
+)
+
+from .. import (
+    AnalyzeImage,
+    GiftiImage,
+    MGHImage,
+    Minc1Image,
+    Minc2Image,
+    Nifti1Image,
+    Nifti1Pair,
+    Nifti2Image,
+    Nifti2Pair,
+    Spm2AnalyzeImage,
+    Spm99AnalyzeImage,
+    brikhead,
+    is_proxy,
+    minc1,
+    minc2,
+    parrec,
+)
 from ..deprecator import ExpiredDeprecationError
-
+from ..spatialimages import SpatialImage
+from ..tmpdirs import InTemporaryDirectory
 from .test_api_validators import ValidateAPI
+from .test_brikhead import EXAMPLE_IMAGES as AFNI_EXAMPLE_IMAGES
 from .test_minc1 import EXAMPLE_IMAGES as MINC1_EXAMPLE_IMAGES
 from .test_minc2 import EXAMPLE_IMAGES as MINC2_EXAMPLE_IMAGES
 from .test_parrec import EXAMPLE_IMAGES as PARREC_EXAMPLE_IMAGES
-from .test_brikhead import EXAMPLE_IMAGES as AFNI_EXAMPLE_IMAGES
 
 
 def maybe_deprecated(meth_name):
@@ -62,7 +84,8 @@ def maybe_deprecated(meth_name):
 
 
 class GenericImageAPI(ValidateAPI):
-    """ General image validation API """
+    """General image validation API"""
+
     # Whether this image type can do scaling of data
     has_scaling = False
     # Whether the image can be saved to disk / file objects
@@ -72,7 +95,7 @@ class GenericImageAPI(ValidateAPI):
     standard_extension = '.img'
 
     def obj_params(self):
-        """ Return generator returning (`img_creator`, `img_params`) tuples
+        """Return generator returning (`img_creator`, `img_params`) tuples
 
         ``img_creator`` is a function taking no arguments and returning a fresh
         image.  We need to return this ``img_creator`` function rather than an
@@ -116,13 +139,6 @@ class GenericImageAPI(ValidateAPI):
         with pytest.raises(AttributeError):
             img.header = hdr
 
-    def validate_header_deprecated(self, imaker, params):
-        # Check deprecated header API
-        img = imaker()
-        with pytest.deprecated_call():
-            hdr = img.get_header()
-        assert hdr is img.header
-
     def validate_filenames(self, imaker, params):
         # Validate the filename, file_map interface
 
@@ -154,18 +170,18 @@ class GenericImageAPI(ValidateAPI):
         # to_ / from_ filename
         fname = 'another_image' + self.standard_extension
         for path in (fname, pathlib.Path(fname)):
-          with InTemporaryDirectory():
-              # Validate that saving or loading a file doesn't use deprecated methods internally
-              with clear_and_catch_warnings() as w:
-                  warnings.filterwarnings('error',
-                                          category=DeprecationWarning,
-                                          module=r"nibabel.*")
-                  img.to_filename(path)
-                  rt_img = img.__class__.from_filename(path)
-              assert_array_equal(img.shape, rt_img.shape)
-              assert_almost_equal(img.get_fdata(), rt_img.get_fdata())
-              assert_almost_equal(np.asanyarray(img.dataobj), np.asanyarray(rt_img.dataobj))
-              del rt_img  # to allow windows to delete the directory
+            with InTemporaryDirectory():
+                # Validate that saving or loading a file doesn't use deprecated methods internally
+                with clear_and_catch_warnings() as w:
+                    warnings.filterwarnings(
+                        'error', category=DeprecationWarning, module=r'nibabel.*'
+                    )
+                    img.to_filename(path)
+                    rt_img = img.__class__.from_filename(path)
+                assert_array_equal(img.shape, rt_img.shape)
+                assert_almost_equal(img.get_fdata(), rt_img.get_fdata())
+                assert_almost_equal(np.asanyarray(img.dataobj), np.asanyarray(rt_img.dataobj))
+                del rt_img  # to allow windows to delete the directory
 
     def validate_no_slicing(self, imaker, params):
         img = imaker()
@@ -174,16 +190,16 @@ class GenericImageAPI(ValidateAPI):
         with pytest.raises(TypeError):
             img[:]
 
+    @expires('5.0.0')
     def validate_get_data_deprecated(self, imaker, params):
-        # Check deprecated header API
         img = imaker()
         with pytest.deprecated_call():
             data = img.get_data()
         assert_array_equal(np.asanyarray(img.dataobj), data)
 
 
-class GetSetDtypeMixin(object):
-    """ Adds dtype tests
+class GetSetDtypeMixin:
+    """Adds dtype tests
 
     Add this one if your image has ``get_data_dtype`` and ``set_data_dtype``.
     """
@@ -208,12 +224,13 @@ class GetSetDtypeMixin(object):
 
 
 class DataInterfaceMixin(GetSetDtypeMixin):
-    """ Test dataobj interface for images with array backing
+    """Test dataobj interface for images with array backing
 
     Use this mixin if your image has a ``dataobj`` property that contains an
     array or an array-like thing.
     """
-    meth_names = ('get_fdata', 'get_data')
+
+    meth_names = ('get_fdata',)
 
     def validate_data_interface(self, imaker, params):
         # Check get data returns array, and caches
@@ -238,7 +255,7 @@ class DataInterfaceMixin(GetSetDtypeMixin):
             with maybe_deprecated(meth_name), pytest.raises(ValueError):
                 method(caching='something')
         # dataobj is read only
-        fake_data = np.zeros(img.shape).astype(img.get_data_dtype())
+        fake_data = np.zeros(img.shape, dtype=img.get_data_dtype())
         with pytest.raises(AttributeError):
             img.dataobj = fake_data
         # So is in_memory
@@ -308,27 +325,6 @@ class DataInterfaceMixin(GetSetDtypeMixin):
         with maybe_deprecated(meth_name):
             data_again = method()
         assert data is data_again
-        # Check the interaction of caching with get_data, get_fdata.
-        # Caching for `get_data` should have no effect on caching for
-        # get_fdata, and vice versa.
-        # Modify the cached data
-        data[:] = 43
-        # Load using the other data fetch method
-        other_name = set(self.meth_names).difference({meth_name}).pop()
-        other_method = getattr(img, other_name)
-        with maybe_deprecated(other_name):
-            other_data = other_method()
-        # We get the original data, not the modified cache
-        assert_array_equal(proxy_data, other_data)
-        assert not np.all(data == other_data)
-        # We can modify the other cache, without affecting the first
-        other_data[:] = 44
-        with maybe_deprecated(other_name):
-            assert_array_equal(other_method(), 44)
-        with pytest.deprecated_call():
-            assert not np.all(method() == other_method())
-        if meth_name != 'get_fdata':
-            return
         # Check that caching refreshes for new floating point type.
         img.uncache()
         fdata = img.get_fdata()
@@ -368,8 +364,7 @@ class DataInterfaceMixin(GetSetDtypeMixin):
     def _check_array_caching(self, imaker, meth_name, caching):
         img = imaker()
         method = getattr(img, meth_name)
-        get_data_func = (method if caching is None else
-                         partial(method, caching=caching))
+        get_data_func = method if caching is None else partial(method, caching=caching)
         assert isinstance(img.dataobj, np.ndarray)
         assert img.in_memory
         with maybe_deprecated(meth_name):
@@ -416,16 +411,6 @@ class DataInterfaceMixin(GetSetDtypeMixin):
                 data = get_data_func(dtype=float_type)
             assert (data is img.dataobj) == (arr_dtype == float_type)
 
-    def validate_data_deprecated(self, imaker, params):
-        # Check _data property still exists, but raises warning
-        img = imaker()
-        with pytest.deprecated_call():
-            assert_data_similar(img._data, params)
-        # Check setting _data raises error
-        fake_data = np.zeros(img.shape).astype(img.get_data_dtype())
-        with pytest.raises(AttributeError):
-            img._data = fake_data
-
     def validate_shape(self, imaker, params):
         # Validate shape
         img = imaker()
@@ -450,12 +435,6 @@ class DataInterfaceMixin(GetSetDtypeMixin):
         with pytest.raises(AttributeError):
             img.ndim = 5
 
-    def validate_shape_deprecated(self, imaker, params):
-        # Check deprecated get_shape API
-        img = imaker()
-        with pytest.raises(ExpiredDeprecationError):
-            img.get_shape()
-
     def validate_mmap_parameter(self, imaker, params):
         img = imaker()
         fname = img.get_filename()
@@ -485,8 +464,8 @@ class DataInterfaceMixin(GetSetDtypeMixin):
             del rt_img  # to allow windows to delete the directory
 
 
-class HeaderShapeMixin(object):
-    """ Tests that header shape can be set and got
+class HeaderShapeMixin:
+    """Tests that header shape can be set and got
 
     Add this one of your header supports ``get_data_shape`` and
     ``set_data_shape``.
@@ -503,11 +482,10 @@ class HeaderShapeMixin(object):
         assert img.header.get_data_shape() == new_shape
 
 
-class AffineMixin(object):
-    """ Adds test of affine property, method
+class AffineMixin:
+    """Adds test of affine property, method
 
-    Add this one if your image has an ``affine`` property.  If so, it should
-    (for now) also have a ``get_affine`` method returning the same result.
+    Add this one if your image has an ``affine`` property.
     """
 
     def validate_affine(self, imaker, params):
@@ -521,45 +499,42 @@ class AffineMixin(object):
         with pytest.raises(AttributeError):
             img.affine = np.eye(4)
 
-    def validate_affine_deprecated(self, imaker, params):
-        # Check deprecated affine API
+
+class SerializeMixin:
+    def validate_to_from_stream(self, imaker, params):
         img = imaker()
-        with pytest.deprecated_call():
-            assert_almost_equal(img.get_affine(), params['affine'], 6)
-            assert img.get_affine().dtype == np.float64
-            aff = img.get_affine()
-            aff[0, 0] = 1.5
-            assert aff is img.get_affine()
+        klass = getattr(self, 'klass', img.__class__)
+        stream = io.BytesIO()
+        img.to_stream(stream)
 
+        rt_img = klass.from_stream(stream)
+        assert self._header_eq(img.header, rt_img.header)
+        assert np.array_equal(img.get_fdata(), rt_img.get_fdata())
 
-class SerializeMixin(object):
-    def validate_to_bytes(self, imaker, params):
-        img = imaker()
-        serialized = img.to_bytes()
-        with InTemporaryDirectory():
-            fname = 'img' + self.standard_extension
-            img.to_filename(fname)
-            with open(fname, 'rb') as fobj:
-                file_contents = fobj.read()
-        assert serialized == file_contents
-
-    def validate_from_bytes(self, imaker, params):
+    def validate_file_stream_equivalence(self, imaker, params):
         img = imaker()
         klass = getattr(self, 'klass', img.__class__)
         with InTemporaryDirectory():
             fname = 'img' + self.standard_extension
             img.to_filename(fname)
 
-            all_images = list(getattr(self, 'example_images', [])) + [{'fname': fname}]
-            for img_params in all_images:
-                img_a = klass.from_filename(img_params['fname'])
-                with open(img_params['fname'], 'rb') as fobj:
-                    img_b = klass.from_bytes(fobj.read())
+            with open('stream', 'wb') as fobj:
+                img.to_stream(fobj)
 
-                assert self._header_eq(img_a.header, img_b.header)
+            # Check that writing gets us the same thing
+            contents1 = pathlib.Path(fname).read_bytes()
+            contents2 = pathlib.Path('stream').read_bytes()
+            assert contents1 == contents2
+
+            # Check that reading gets us the same thing
+            img_a = klass.from_filename(fname)
+            with open(fname, 'rb') as fobj:
+                img_b = klass.from_stream(fobj)
+                # This needs to happen while the filehandle is open
                 assert np.array_equal(img_a.get_fdata(), img_b.get_fdata())
-                del img_a
-                del img_b
+            assert self._header_eq(img_a.header, img_b.header)
+            del img_a
+            del img_b
 
     def validate_to_from_bytes(self, imaker, params):
         img = imaker()
@@ -581,9 +556,48 @@ class SerializeMixin(object):
                 del img_a
                 del img_b
 
+    @pytest.fixture(autouse=True)
+    def setup_method(self, httpserver, tmp_path):
+        """Make pytest fixtures available to validate functions"""
+        self.httpserver = httpserver
+        self.tmp_path = tmp_path
+
+    def validate_from_url(self, imaker, params):
+        server = self.httpserver
+
+        img = imaker()
+        img_bytes = img.to_bytes()
+
+        server.expect_oneshot_request('/img').respond_with_data(img_bytes)
+        url = server.url_for('/img')
+        assert url.startswith('http://')  # Check we'll trigger an HTTP handler
+        rt_img = img.__class__.from_url(url)
+
+        assert rt_img.to_bytes() == img_bytes
+        assert self._header_eq(img.header, rt_img.header)
+        assert np.array_equal(img.get_fdata(), rt_img.get_fdata())
+        del img
+        del rt_img
+
+    def validate_from_file_url(self, imaker, params):
+        tmp_path = self.tmp_path
+
+        img = imaker()
+        import uuid
+
+        fname = tmp_path / f'img-{uuid.uuid4()}{self.standard_extension}'
+        img.to_filename(fname)
+
+        rt_img = img.__class__.from_url(f'file:///{fname}')
+
+        assert self._header_eq(img.header, rt_img.header)
+        assert np.array_equal(img.get_fdata(), rt_img.get_fdata())
+        del img
+        del rt_img
+
     @staticmethod
     def _header_eq(header_a, header_b):
-        """ Header equality check that can be overridden by a subclass of this test
+        """Header equality check that can be overridden by a subclass of this test
 
         This allows us to retain the same tests above when testing an image that uses an
         abstract class as a header, namely when testing the FileBasedImage API, which
@@ -592,12 +606,9 @@ class SerializeMixin(object):
         return header_a == header_b
 
 
-
-class LoadImageAPI(GenericImageAPI,
-                   DataInterfaceMixin,
-                   AffineMixin,
-                   GetSetDtypeMixin,
-                   HeaderShapeMixin):
+class LoadImageAPI(
+    GenericImageAPI, DataInterfaceMixin, AffineMixin, GetSetDtypeMixin, HeaderShapeMixin
+):
     # Callable returning an image from a filename
     loader = None
     # Sequence of dictionaries, where dictionaries have keys
@@ -620,8 +631,8 @@ class LoadImageAPI(GenericImageAPI,
 
 
 class MakeImageAPI(LoadImageAPI):
-    """ Validation for images we can make with ``func(data, affine, header)``
-    """
+    """Validation for images we can make with ``func(data, affine, header)``"""
+
     # A callable returning an image from ``image_maker(data, affine, header)``
     image_maker = None
     # A callable returning a header from ``header_maker()``
@@ -633,7 +644,7 @@ class MakeImageAPI(LoadImageAPI):
 
     def obj_params(self):
         # Return any obj_params from superclass
-        for func, params in super(MakeImageAPI, self).obj_params():
+        for func, params in super().obj_params():
             yield func, params
         # Create new images
         aff = np.diag([1, 2, 3, 1])
@@ -642,7 +653,6 @@ class MakeImageAPI(LoadImageAPI):
             return lambda: self.image_maker(arr, aff, header)
 
         def make_prox_imaker(arr, aff, hdr):
-
             def prox_imaker():
                 img = self.image_maker(arr, aff, hdr)
                 rt_img = bytesio_round_trip(img)
@@ -650,20 +660,14 @@ class MakeImageAPI(LoadImageAPI):
 
             return prox_imaker
 
-        for shape, stored_dtype in product(self.example_shapes,
-                                           self.storable_dtypes):
+        for shape, stored_dtype in product(self.example_shapes, self.storable_dtypes):
             # To make sure we do not trigger scaling, always use the
             # stored_dtype for the input array.
             arr = np.arange(np.prod(shape), dtype=stored_dtype).reshape(shape)
             hdr = self.header_maker()
             hdr.set_data_dtype(stored_dtype)
             func = make_imaker(arr.copy(), aff, hdr)
-            params = dict(
-                dtype=stored_dtype,
-                affine=aff,
-                data=arr,
-                shape=shape,
-                is_proxy=False)
+            params = dict(dtype=stored_dtype, affine=aff, data=arr, shape=shape, is_proxy=False)
             yield make_imaker(arr.copy(), aff, hdr), params
             if not self.can_save:
                 continue
@@ -673,17 +677,61 @@ class MakeImageAPI(LoadImageAPI):
             yield make_prox_imaker(arr.copy(), aff, hdr), params
 
 
-class ImageHeaderAPI(MakeImageAPI):
-    """ When ``self.image_maker`` is an image class, make header from class
+class DtypeOverrideMixin(GetSetDtypeMixin):
+    """Test images that can accept ``dtype`` arguments to ``__init__`` and
+    ``to_file_map``
     """
 
+    def validate_init_dtype_override(self, imaker, params):
+        img = imaker()
+        klass = img.__class__
+        for dtype in self.storable_dtypes:
+            if hasattr(img, 'affine'):
+                new_img = klass(img.dataobj, img.affine, header=img.header, dtype=dtype)
+            else:  # XXX This is for CIFTI-2, these validators might need refactoring
+                new_img = klass(img.dataobj, header=img.header, dtype=dtype)
+            assert new_img.get_data_dtype() == dtype
+
+            if self.has_scaling and self.can_save:
+                with np.errstate(invalid='ignore'):
+                    rt_img = bytesio_round_trip(new_img)
+                assert rt_img.get_data_dtype() == dtype
+
+    def validate_to_file_dtype_override(self, imaker, params):
+        if not self.can_save:
+            raise unittest.SkipTest
+        img = imaker()
+        orig_dtype = img.get_data_dtype()
+        fname = 'image' + self.standard_extension
+        with InTemporaryDirectory():
+            for dtype in self.storable_dtypes:
+                try:
+                    img.to_filename(fname, dtype=dtype)
+                except WriterError:
+                    # It's possible to try to save to a dtype that requires
+                    # scaling, and images without scale factors will fail.
+                    # We're not testing that here.
+                    continue
+                rt_img = img.__class__.from_filename(fname)
+                assert rt_img.get_data_dtype() == dtype
+                assert img.get_data_dtype() == orig_dtype
+
+
+class ImageHeaderAPI(MakeImageAPI):
+    """When ``self.image_maker`` is an image class, make header from class"""
+
     def header_maker(self):
         return self.image_maker.header_class()
 
 
-class TestAnalyzeAPI(ImageHeaderAPI):
-    """ General image validation API instantiated for Analyze images
-    """
+class TestSpatialImageAPI(ImageHeaderAPI):
+    klass = image_maker = SpatialImage
+    can_save = False
+
+
+class TestAnalyzeAPI(TestSpatialImageAPI, DtypeOverrideMixin):
+    """General image validation API instantiated for Analyze images"""
+
     klass = image_maker = AnalyzeImage
     has_scaling = False
     can_save = True
@@ -692,11 +740,6 @@ class TestAnalyzeAPI(ImageHeaderAPI):
     storable_dtypes = (np.uint8, np.int16, np.int32, np.float32, np.float64)
 
 
-class TestSpatialImageAPI(TestAnalyzeAPI):
-    klass = image_maker = SpatialImage
-    can_save = False
-
-
 class TestSpm99AnalyzeAPI(TestAnalyzeAPI):
     # SPM-type analyze need scipy for mat file IO
     klass = image_maker = Spm99AnalyzeImage
@@ -733,8 +776,7 @@ class TestMinc1API(ImageHeaderAPI):
 
 
 class TestMinc2API(TestMinc1API):
-
-    def setup(self):
+    def setup_method(self):
         if not have_h5py:
             raise unittest.SkipTest('Need h5py for these tests')
 
@@ -744,7 +786,6 @@ class TestMinc2API(TestMinc1API):
 
 
 class TestPARRECAPI(LoadImageAPI):
-
     def loader(self, fname):
         return parrec.load(fname)
 
