@@ -6,32 +6,43 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Tests for loader function """
-from io import BytesIO
-
-import shutil
-from os.path import dirname, join as pjoin
-from tempfile import mkdtemp
-import pathlib
+"""Tests for loader function"""
 import logging
+import pathlib
+import shutil
+from io import BytesIO
+from os.path import dirname
+from os.path import join as pjoin
+from tempfile import mkdtemp
 
 import numpy as np
+import pytest
+from numpy.testing import assert_array_almost_equal, assert_array_equal
 
+from .. import (
+    AnalyzeImage,
+    MGHImage,
+    Minc1Image,
+    Minc2Image,
+    Nifti1Header,
+    Nifti1Image,
+    Nifti1Pair,
+    Nifti2Image,
+    Nifti2Pair,
+    Spm2AnalyzeImage,
+    Spm99AnalyzeImage,
+    all_image_classes,
+)
 from .. import analyze as ana
-from .. import spm99analyze as spm99
-from .. import spm2analyze as spm2
-from .. import nifti1 as ni1
 from .. import loadsave as nils
-from .. import (Nifti1Image, Nifti1Header, Nifti1Pair, Nifti2Image, Nifti2Pair,
-                Minc1Image, Minc2Image, Spm2AnalyzeImage, Spm99AnalyzeImage,
-                AnalyzeImage, MGHImage, all_image_classes)
-from ..tmpdirs import InTemporaryDirectory
-from ..volumeutils import native_code, swapped_code
+from .. import nifti1 as ni1
+from .. import spm2analyze as spm2
+from .. import spm99analyze as spm99
 from ..optpkg import optional_package
 from ..spatialimages import SpatialImage
-
-from numpy.testing import assert_array_equal, assert_array_almost_equal
-import pytest
+from ..testing import expires
+from ..tmpdirs import InTemporaryDirectory
+from ..volumeutils import native_code, swapped_code
 
 _, have_scipy, _ = optional_package('scipy')  # No scipy=>no SPM-format writing
 DATA_PATH = pjoin(dirname(__file__), 'data')
@@ -46,8 +57,9 @@ def round_trip(img):
 def test_conversion_spatialimages(caplog):
     shape = (2, 4, 6)
     affine = np.diag([1, 2, 3, 1])
-    klasses = [klass for klass in all_image_classes
-               if klass.rw and issubclass(klass, SpatialImage)]
+    klasses = [
+        klass for klass in all_image_classes if klass.rw and issubclass(klass, SpatialImage)
+    ]
     for npt in np.float32, np.int16:
         data = np.arange(np.prod(shape), dtype=npt).reshape(shape)
         for r_class in klasses:
@@ -270,38 +282,7 @@ def test_filename_save():
             shutil.rmtree(pth)
 
 
-def test_analyze_detection():
-    # Test detection of Analyze, Nifti1 and Nifti2
-    # Algorithm is as described in loadsave:which_analyze_type
-    def wat(hdr):
-        with pytest.deprecated_call():
-            return nils.which_analyze_type(hdr.binaryblock)
-    n1_hdr = Nifti1Header(b'\0' * 348, check=False)
-    assert wat(n1_hdr) is None
-    n1_hdr['sizeof_hdr'] = 540
-    assert wat(n1_hdr) == 'nifti2'
-    assert wat(n1_hdr.as_byteswapped()) == 'nifti2'
-    n1_hdr['sizeof_hdr'] = 348
-    assert wat(n1_hdr) == 'analyze'
-    assert wat(n1_hdr.as_byteswapped()) == 'analyze'
-    n1_hdr['magic'] = b'n+1'
-    assert wat(n1_hdr) == 'nifti1'
-    assert wat(n1_hdr.as_byteswapped()) == 'nifti1'
-    n1_hdr['magic'] = b'ni1'
-    assert wat(n1_hdr) == 'nifti1'
-    assert wat(n1_hdr.as_byteswapped()) == 'nifti1'
-    # Doesn't matter what magic is if it's not a nifti1 magic
-    n1_hdr['magic'] = b'ni2'
-    assert wat(n1_hdr) == 'analyze'
-    n1_hdr['sizeof_hdr'] = 0
-    n1_hdr['magic'] = b''
-    assert wat(n1_hdr) is None
-    n1_hdr['magic'] = 'n+1'
-    assert wat(n1_hdr) == 'nifti1'
-    n1_hdr['magic'] = 'ni1'
-    assert wat(n1_hdr) == 'nifti1'
-
-
+@expires('5.0.0')
 def test_guessed_image_type():
     # Test whether we can guess the image type from example files
     with pytest.deprecated_call():
