@@ -1,23 +1,22 @@
-""" Testing imageclasses module
+"""Testing imageclasses module
 """
 
-from os.path import dirname, join as pjoin
 import warnings
+from os.path import dirname
+from os.path import join as pjoin
 
 import numpy as np
+import pytest
 
 import nibabel as nib
+from nibabel import imageclasses
 from nibabel.analyze import AnalyzeImage
+from nibabel.imageclasses import spatial_axes_first
 from nibabel.nifti1 import Nifti1Image
 from nibabel.nifti2 import Nifti2Image
-from .._h5py_compat import have_h5py
-
-from nibabel import imageclasses
-from nibabel.imageclasses import spatial_axes_first, class_map, ext_map
-
-
-from nibabel.testing import clear_and_catch_warnings
+from nibabel.optpkg import optional_package
 
+have_h5py = optional_package('h5py')[1]
 
 DATA_DIR = pjoin(dirname(__file__), 'data')
 
@@ -47,15 +46,3 @@ def test_spatial_axes_first():
         img = nib.load(pjoin(DATA_DIR, fname))
         assert len(img.shape) == 4
         assert not spatial_axes_first(img)
-
-
-def test_deprecations():
-    with clear_and_catch_warnings(modules=[imageclasses]) as w:
-        warnings.filterwarnings('always', category=DeprecationWarning)
-        nifti_single = class_map['nifti_single']
-        assert nifti_single['class'] == Nifti1Image
-        assert len(w) == 1
-        nifti_ext = ext_map['.nii']
-        assert nifti_ext == 'nifti_single'
-        assert len(w) == 2
-
