@@ -1,14 +1,13 @@
-""" Testing optpkg module
+"""Testing optpkg module
 """
 
-from unittest import mock
-import types
-import sys
 import builtins
-from distutils.version import LooseVersion
+import sys
+import types
+from unittest import SkipTest, mock
 
-from unittest import SkipTest
 import pytest
+from packaging.version import Version
 
 from nibabel.optpkg import optional_package
 from nibabel.tripwire import TripWire, TripWireError
@@ -41,12 +40,15 @@ def test_basic():
 
     # Only disrupt imports for "nottriedbefore" package
     orig_import = builtins.__import__
+
     def raise_Exception(*args, **kwargs):
         if args[0] == 'nottriedbefore':
             raise Exception(
-                "non ImportError could be thrown by some malfunctioning module "
-                "upon import, and optional_package should catch it too")
+                'non ImportError could be thrown by some malfunctioning module '
+                'upon import, and optional_package should catch it too'
+            )
         return orig_import(*args, **kwargs)
+
     with mock.patch.object(builtins, '__import__', side_effect=raise_Exception):
         assert_bad('nottriedbefore')
 
@@ -67,10 +69,10 @@ def test_versions():
         # Now add a version
         fake_pkg.__version__ = '2.0'
         # We have fake_pkg > 1.0
-        for min_ver in (None, '1.0', LooseVersion('1.0'), lambda pkg: True):
+        for min_ver in (None, '1.0', Version('1.0'), lambda pkg: True):
             assert_good(fake_name, min_ver)
         # We never have fake_pkg > 100.0
-        for min_ver in ('100.0', LooseVersion('100.0'), lambda pkg: False):
+        for min_ver in ('100.0', Version('100.0'), lambda pkg: False):
             assert_bad(fake_name, min_ver)
         # Check error string for bad version
         pkg, _, _ = optional_package(fake_name, min_version='3.0')
