@@ -1,21 +1,21 @@
-""" Test we can correctly import example PARREC files
+"""Test we can correctly import example PARREC files
 """
 
+import unittest
 from glob import glob
-from os.path import join as pjoin, basename, splitext, exists
+from os.path import basename, exists
+from os.path import join as pjoin
+from os.path import splitext
 
 import numpy as np
-
-from .. import load as top_load
-from ..parrec import load
-from ..affines import voxel_sizes
-
-from .nibabel_data import get_nibabel_data, needs_nibabel_data
-
-import unittest
 import pytest
 from numpy.testing import assert_almost_equal
 
+from .. import load as top_load
+from ..affines import voxel_sizes
+from ..parrec import load
+from .nibabel_data import get_nibabel_data, needs_nibabel_data
+
 BALLS = pjoin(get_nibabel_data(), 'nitest-balls1')
 OBLIQUE = pjoin(get_nibabel_data(), 'parrec_oblique')
 
@@ -77,7 +77,7 @@ def test_oblique_loading():
         nimg = top_load(nifti_fname)
         assert_almost_equal(nimg.affine[:3, :3], pimg.affine[:3, :3], 3)
         # The translation part is always off
-        # The ammount differs by rotation
+        # The amount differs by rotation
         aff_off = pimg.affine[:3, 3] - nimg.affine[:3, 3]
         # The difference is max in the order of 0.5 voxel
         vox_sizes = voxel_sizes(nimg.affine)
