@@ -6,35 +6,42 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Testing processing module
+"""Testing processing module
 """
 
-from os.path import dirname, join as pjoin
 import logging
+from os.path import dirname
+from os.path import join as pjoin
 
 import numpy as np
 import numpy.linalg as npl
 
 from nibabel.optpkg import optional_package
+
 spnd, have_scipy, _ = optional_package('scipy.ndimage')
 
+import unittest
+
+import pytest
+from numpy.testing import assert_almost_equal, assert_array_equal
+
 import nibabel as nib
-from nibabel.processing import (sigma2fwhm, fwhm2sigma, adapt_affine,
-                                resample_from_to, resample_to_output, smooth_image,
-                                conform)
+from nibabel.affines import AffineError, apply_affine, from_matvec, to_matvec, voxel_sizes
+from nibabel.eulerangles import euler2mat
 from nibabel.nifti1 import Nifti1Image
 from nibabel.nifti2 import Nifti2Image
 from nibabel.orientations import aff2axcodes, inv_ornt_aff
-from nibabel.affines import (AffineError, from_matvec, to_matvec, apply_affine,
-                             voxel_sizes)
-from nibabel.eulerangles import euler2mat
-
-from numpy.testing import assert_almost_equal, assert_array_equal
-import unittest
-import pytest
-
-from nibabel.tests.test_spaces import assert_all_in, get_outspace_params
+from nibabel.processing import (
+    adapt_affine,
+    conform,
+    fwhm2sigma,
+    resample_from_to,
+    resample_to_output,
+    sigma2fwhm,
+    smooth_image,
+)
 from nibabel.testing import assert_allclose_safely
+from nibabel.tests.test_spaces import assert_all_in, get_outspace_params
 
 needs_scipy = unittest.skipUnless(have_scipy, 'These tests need scipy')
 
@@ -44,9 +51,13 @@ DATA_DIR = pjoin(dirname(__file__), 'data')
 from .test_imageclasses import MINC_3DS, MINC_4DS
 
 # Filenames of other images that should work correctly with processing
-OTHER_IMGS = ('anatomical.nii', 'functional.nii',
-              'example4d.nii.gz', 'example_nifti2.nii.gz',
-              'phantom_EPI_asc_CLEAR_2_1.PAR')
+OTHER_IMGS = (
+    'anatomical.nii',
+    'functional.nii',
+    'example4d.nii.gz',
+    'example_nifti2.nii.gz',
+    'phantom_EPI_asc_CLEAR_2_1.PAR',
+)
 
 
 def test_sigma2fwhm():
@@ -68,27 +79,39 @@ def test_adapt_affine():
     # For 4x4 affine, 3D image, no-op
     assert_array_equal(adapt_affine(aff_3d, 3), aff_3d)
     # For 4x4 affine, 4D image, add extra identity dimension
-    assert_array_equal(adapt_affine(aff_3d, 4),
-                       [[ 0,  1,  2,  0,  11],
-                        [ 3,  4,  5,  0,  12],
-                        [ 6,  7,  8,  0,  13],
-                        [ 0,  0,  0,  1,   0],
-                        [ 0,  0,  0,  0,   1]])
+    assert_array_equal(
+        adapt_affine(aff_3d, 4),
+        [
+            [0, 1, 2, 0, 11],
+            [3, 4, 5, 0, 12],
+            [6, 7, 8, 0, 13],
+            [0, 0, 0, 1, 0],
+            [0, 0, 0, 0, 1],
+        ],
+    )
     # For 5x5 affine, 4D image, identity
     aff_4d = from_matvec(np.arange(16).reshape((4, 4)), [11, 12, 13, 14])
     assert_array_equal(adapt_affine(aff_4d, 4), aff_4d)
     # For 4x4 affine, 2D image, dropped column
-    assert_array_equal(adapt_affine(aff_3d, 2),
-                       [[ 0,  1,  11],
-                        [ 3,  4,  12],
-                        [ 6,  7,  13],
-                        [ 0,  0,   1]])
-    # For 4x4 affine, 1D image, 2 dropped columnn
-    assert_array_equal(adapt_affine(aff_3d, 1),
-                       [[ 0,  11],
-                        [ 3,  12],
-                        [ 6,  13],
-                        [ 0,   1]])
+    assert_array_equal(
+        adapt_affine(aff_3d, 2),
+        [
+            [0, 1, 11],
+            [3, 4, 12],
+            [6, 7, 13],
+            [0, 0, 1],
+        ],
+    )
+    # For 4x4 affine, 1D image, 2 dropped columns
+    assert_array_equal(
+        adapt_affine(aff_3d, 1),
+        [
+            [0, 11],
+            [3, 12],
+            [6, 13],
+            [0, 1],
+        ],
+    )
     # For 3x3 affine, 2D image, identity
     aff_2d = from_matvec(np.arange(4).reshape((2, 2)), [11, 12])
     assert_array_equal(adapt_affine(aff_2d, 2), aff_2d)
@@ -97,7 +120,7 @@ def test_adapt_affine():
 @needs_scipy
 def test_resample_from_to(caplog):
     # Test resampling from image to image / image space
-    data = np.arange(24).reshape((2, 3, 4))
+    data = np.arange(24, dtype='int32').reshape((2, 3, 4))
     affine = np.diag([-4, 5, 6, 1])
     img = Nifti1Image(data, affine)
     img.header['descrip'] = 'red shirt image'
@@ -111,8 +134,7 @@ def test_resample_from_to(caplog):
         ax_flip_ornt = flip_ornt.copy()
         ax_flip_ornt[axis, 1] = -1
         aff_flip_i = inv_ornt_aff(ax_flip_ornt, (2, 3, 4))
-        flipped_img = Nifti1Image(np.flip(data, axis),
-                                  np.dot(affine, aff_flip_i))
+        flipped_img = Nifti1Image(np.flip(data, axis), np.dot(affine, aff_flip_i))
         out = resample_from_to(flipped_img, ((2, 3, 4), affine))
         assert_almost_equal(img.dataobj, out.dataobj)
         assert_array_equal(img.affine, out.affine)
@@ -142,7 +164,7 @@ def test_resample_from_to(caplog):
     # Test order
     trans_p_25_aff = from_matvec(np.diag([-4, 5, 6]), [1, 0, 0])
     trans_p_25_img = Nifti1Image(data, trans_p_25_aff)
-    # Suprising to me, but all points outside are set to 0, even with NN
+    # Surprising to me, but all points outside are set to 0, even with NN
     out = resample_from_to(img, trans_p_25_img, order=0)
     exp_out = np.zeros_like(data)
     exp_out[1:, :, :] = data[1, :, :]
@@ -182,11 +204,11 @@ def test_resample_from_to(caplog):
     # 3D to 2D, we don't need to invert the fixed matrix
     out = resample_from_to(img, img_2d)
     assert_array_equal(out.dataobj, data[:, :, 0])
-    # Same for tuple as to_img imput
+    # Same for tuple as to_img input
     out = resample_from_to(img, (img_2d.shape, img_2d.affine))
     assert_array_equal(out.dataobj, data[:, :, 0])
     # 4D input and output also OK
-    data_4d = np.arange(24 * 5).reshape((2, 3, 4, 5))
+    data_4d = np.arange(24 * 5, dtype='int32').reshape((2, 3, 4, 5))
     img_4d = Nifti1Image(data_4d, affine)
     out = resample_from_to(img_4d, img_4d)
     assert_almost_equal(data_4d, out.dataobj)
@@ -202,7 +224,7 @@ def test_resample_from_to(caplog):
 def test_resample_to_output(caplog):
     # Test routine to sample iamges to output space
     # Image aligned to output axes - no-op
-    data = np.arange(24).reshape((2, 3, 4))
+    data = np.arange(24, dtype='int32').reshape((2, 3, 4))
     img = Nifti1Image(data, np.eye(4))
     # Check default resampling
     img2 = resample_to_output(img)
@@ -255,13 +277,10 @@ def test_resample_to_output(caplog):
     # Subsample voxels
     out_img = resample_to_output(Nifti1Image(data, np.diag([4, 5, 6, 1])))
     with pytest.warns(UserWarning):  # Suppress scipy warning
-        exp_out = spnd.affine_transform(data,
-                                        [1/4, 1/5, 1/6],
-                                        output_shape = (5, 11, 19))
+        exp_out = spnd.affine_transform(data, [1 / 4, 1 / 5, 1 / 6], output_shape=(5, 11, 19))
     assert_array_equal(out_img.dataobj, exp_out)
     # Unsubsample with voxel sizes
-    out_img = resample_to_output(Nifti1Image(data, np.diag([4, 5, 6, 1])),
-                                 [4, 5, 6])
+    out_img = resample_to_output(Nifti1Image(data, np.diag([4, 5, 6, 1])), [4, 5, 6])
     assert_array_equal(out_img.dataobj, data)
     # A rotation to test nearest, order, cval
     rot_3 = from_matvec(euler2mat(np.pi / 4), [0, 0, 0])
@@ -269,10 +288,14 @@ def test_resample_to_output(caplog):
     out_img = resample_to_output(rot_3_img)
     exp_shape = (4, 4, 4)
     assert out_img.shape == exp_shape
-    exp_aff = np.array([[1, 0, 0, -2 * np.cos(np.pi / 4)],
-                        [0, 1, 0, 0],
-                        [0, 0, 1, 0],
-                        [0, 0, 0, 1]])
+    exp_aff = np.array(
+        [
+            [1, 0, 0, -2 * np.cos(np.pi / 4)],
+            [0, 1, 0, 0],
+            [0, 0, 1, 0],
+            [0, 0, 0, 1],
+        ]
+    )
     assert_almost_equal(out_img.affine, exp_aff)
     rzs, trans = to_matvec(np.dot(npl.inv(rot_3), exp_aff))
     exp_out = spnd.affine_transform(data, rzs, trans, exp_shape)
@@ -280,22 +303,25 @@ def test_resample_to_output(caplog):
     # Order
     assert_almost_equal(
         resample_to_output(rot_3_img, order=0).dataobj,
-        spnd.affine_transform(data, rzs, trans, exp_shape, order=0))
+        spnd.affine_transform(data, rzs, trans, exp_shape, order=0),
+    )
     # Cval
     assert_almost_equal(
         resample_to_output(rot_3_img, cval=99).dataobj,
-        spnd.affine_transform(data, rzs, trans, exp_shape, cval=99))
+        spnd.affine_transform(data, rzs, trans, exp_shape, cval=99),
+    )
     # Mode
     assert_almost_equal(
         resample_to_output(rot_3_img, mode='nearest').dataobj,
-        spnd.affine_transform(data, rzs, trans, exp_shape, mode='nearest'))
+        spnd.affine_transform(data, rzs, trans, exp_shape, mode='nearest'),
+    )
     # out_class
     img_ni1 = Nifti2Image(data, np.eye(4))
     img_ni2 = Nifti2Image(data, np.eye(4))
     # Default is Nifti1Image
     with caplog.at_level(logging.CRITICAL):  # Here and below, suppress logs when changing classes
         assert resample_to_output(img_ni2).__class__ == Nifti1Image
-    # Can be overriden
+    # Can be overridden
     with caplog.at_level(logging.CRITICAL):
         assert resample_to_output(img_ni1, out_class=Nifti2Image).__class__ == Nifti2Image
     # None specifies out_class from input
@@ -305,7 +331,7 @@ def test_resample_to_output(caplog):
 @needs_scipy
 def test_smooth_image(caplog):
     # Test image smoothing
-    data = np.arange(24).reshape((2, 3, 4))
+    data = np.arange(24, dtype='int32').reshape((2, 3, 4))
     aff = np.diag([-4, 5, 6, 1])
     img = Nifti1Image(data, aff)
     # Zero smoothing is no-op
@@ -332,7 +358,7 @@ def test_smooth_image(caplog):
     with pytest.raises(ValueError):
         smooth_image(img_2d, [8, 8, 8])
     # Isotropic in 4D has zero for last dimension in scalar case
-    data_4d = np.arange(24 * 5).reshape((2, 3, 4, 5))
+    data_4d = np.arange(24 * 5, dtype='int32').reshape((2, 3, 4, 5))
     img_4d = Nifti1Image(data_4d, aff)
     exp_out = spnd.gaussian_filter(data_4d, list(sd) + [0], mode='nearest')
     assert_array_equal(smooth_image(img_4d, 8).dataobj, exp_out)
@@ -343,15 +369,14 @@ def test_smooth_image(caplog):
     exp_out = spnd.gaussian_filter(data, sd, mode='constant')
     assert_array_equal(smooth_image(img, 8, mode='constant').dataobj, exp_out)
     exp_out = spnd.gaussian_filter(data, sd, mode='constant', cval=99)
-    assert_array_equal(smooth_image(img, 8, mode='constant', cval=99).dataobj,
-                       exp_out)
+    assert_array_equal(smooth_image(img, 8, mode='constant', cval=99).dataobj, exp_out)
     # out_class
     img_ni1 = Nifti1Image(data, np.eye(4))
     img_ni2 = Nifti2Image(data, np.eye(4))
     # Default is Nifti1Image
     with caplog.at_level(logging.CRITICAL):  # Here and below, suppress logs when changing classes
         assert smooth_image(img_ni2, 0).__class__ == Nifti1Image
-    # Can be overriden
+    # Can be overridden
     with caplog.at_level(logging.CRITICAL):
         assert smooth_image(img_ni1, 0, out_class=Nifti2Image).__class__ == Nifti2Image
     # None specifies out_class from input
@@ -383,8 +408,7 @@ def test_spatial_axes_check(caplog):
 
 
 def assert_spm_resampling_close(from_img, our_resampled, spm_resampled):
-    """ Assert our resampling is close to SPM's, allowing for edge effects
-    """
+    """Assert our resampling is close to SPM's, allowing for edge effects"""
     # To allow for differences in the way SPM and scipy.ndimage handle off-edge
     # interpolation, mask out voxels off edge
     to_img_shape = spm_resampled.shape
@@ -396,9 +420,9 @@ def assert_spm_resampling_close(from_img, our_resampled, spm_resampled):
     # Places where SPM may not return default value but scipy.ndimage will (SPM
     # does not return zeros <0.05 from image edges).
     # See: https://github.com/nipy/nibabel/pull/255#issuecomment-186774173
-    outside_vol = np.any((resamp_coords < 0) |
-                         (np.subtract(resamp_coords, from_img.shape) > -1),
-                         axis=-1)
+    outside_vol = np.any(
+        (resamp_coords < 0) | (np.subtract(resamp_coords, from_img.shape) > -1), axis=-1
+    )
     spm_res = np.where(outside_vol, np.nan, np.array(spm_resampled.dataobj))
     assert_allclose_safely(our_resampled.dataobj, spm_res)
     assert_almost_equal(our_resampled.affine, spm_resampled.affine, 5)
@@ -417,12 +441,8 @@ def test_against_spm_resample():
     func = nib.load(pjoin(DATA_DIR, 'functional.nii'))
     some_rotations = euler2mat(0.1, 0.2, 0.3)
     extra_affine = from_matvec(some_rotations, [3, 4, 5])
-    moved_anat = nib.Nifti1Image(anat.get_fdata(),
-                                 extra_affine.dot(anat.affine),
-                                 anat.header)
-    one_func = nib.Nifti1Image(func.dataobj[..., 0],
-                               func.affine,
-                               func.header)
+    moved_anat = nib.Nifti1Image(anat.get_fdata(), extra_affine.dot(anat.affine), anat.header)
+    one_func = nib.Nifti1Image(func.dataobj[..., 0], func.affine, func.header)
     moved2func = resample_from_to(moved_anat, one_func, order=1, cval=np.nan)
     spm_moved = nib.load(pjoin(DATA_DIR, 'resampled_anat_moved.nii'))
     assert_spm_resampling_close(moved_anat, moved2func, spm_moved)
@@ -431,7 +451,7 @@ def test_against_spm_resample():
     # John Ashburner).
     moved2output = resample_to_output(moved_anat, 4, order=1, cval=np.nan)
     spm2output = nib.load(pjoin(DATA_DIR, 'reoriented_anat_moved.nii'))
-    assert_spm_resampling_close(moved_anat, moved2output, spm2output);
+    assert_spm_resampling_close(moved_anat, moved2output, spm2output)
 
 
 @needs_scipy
@@ -448,8 +468,13 @@ def test_conform(caplog):
 
     # Test with non-default arguments.
     with caplog.at_level(logging.CRITICAL):  # Suppress logs when changing classes
-        c = conform(anat, out_shape=(100, 100, 200), voxel_size=(2, 2, 1.5),
-                    orientation="LPI", out_class=Nifti2Image)
+        c = conform(
+            anat,
+            out_shape=(100, 100, 200),
+            voxel_size=(2, 2, 1.5),
+            orientation='LPI',
+            out_class=Nifti2Image,
+        )
     assert c.shape == (100, 100, 200)
     assert c.header.get_zooms() == (2, 2, 1.5)
     assert c.dataobj.dtype.type == anat.dataobj.dtype.type
