@@ -6,7 +6,7 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Validate image proxy API
+"""Validate image proxy API
 
 Minimum array proxy API is:
 
@@ -28,45 +28,40 @@ And:
 These last are to allow the proxy to be re-used with different images.
 """
 
-from os.path import join as pjoin
+import unittest
 import warnings
-from itertools import product
 from io import BytesIO
+from itertools import product
+from os.path import join as pjoin
 
 import numpy as np
-
-from ..volumeutils import apply_read_scaling
-from ..analyze import AnalyzeHeader
-from ..spm99analyze import Spm99AnalyzeHeader
-from ..spm2analyze import Spm2AnalyzeHeader
-from ..nifti1 import Nifti1Header
-from ..freesurfer.mghformat import MGHHeader
-from .. import minc1
-from ..externals.netcdf import netcdf_file
-from .. import minc2
-from .._h5py_compat import h5py, have_h5py
-from .. import ecat
-from .. import parrec
-from ..casting import have_binary128
-
-from ..arrayproxy import ArrayProxy, is_proxy
-
-import unittest
 import pytest
-from numpy.testing import assert_almost_equal, assert_array_equal, assert_allclose
+from numpy.testing import assert_allclose, assert_almost_equal, assert_array_equal
 
-from ..testing import data_path as DATA_PATH, assert_dt_equal, clear_and_catch_warnings
+from .. import ecat, minc1, minc2, parrec
+from ..analyze import AnalyzeHeader
+from ..arrayproxy import ArrayProxy, is_proxy
+from ..casting import have_binary128
 from ..deprecator import ExpiredDeprecationError
-
+from ..externals.netcdf import netcdf_file
+from ..freesurfer.mghformat import MGHHeader
+from ..nifti1 import Nifti1Header
+from ..optpkg import optional_package
+from ..spm2analyze import Spm2AnalyzeHeader
+from ..spm99analyze import Spm99AnalyzeHeader
+from ..testing import assert_dt_equal, clear_and_catch_warnings
+from ..testing import data_path as DATA_PATH
 from ..tmpdirs import InTemporaryDirectory
-
+from ..volumeutils import apply_read_scaling
 from .test_api_validators import ValidateAPI
 from .test_parrec import EG_REC, VARY_REC
 
+h5py, have_h5py, _ = optional_package('h5py')
+
 
 def _some_slicers(shape):
     ndim = len(shape)
-    slicers = np.eye(ndim).astype(int).astype(object)
+    slicers = np.eye(ndim, dtype=int).astype(object)
     slicers[slicers == 0] = slice(None)
     for i in range(ndim):
         if i % 2:
@@ -75,15 +70,19 @@ def _some_slicers(shape):
             slicers[i, i] = 0
     # Add a newaxis to keep us on our toes
     no_pos = ndim // 2
-    slicers = np.hstack((slicers[:, :no_pos],
-                         np.empty((ndim, 1)),
-                         slicers[:, no_pos:]))
+    slicers = np.hstack(
+        (
+            slicers[:, :no_pos],
+            np.empty((ndim, 1)),
+            slicers[:, no_pos:],
+        )
+    )
     slicers[:, no_pos] = None
     return [tuple(s) for s in slicers]
 
 
 class _TestProxyAPI(ValidateAPI):
-    """ Base class for testing proxy APIs
+    """Base class for testing proxy APIs
 
     Assumes that real classes will provide an `obj_params` method which is a
     generator returning 2 tuples of (<proxy_maker>, <param_dict>).
@@ -95,6 +94,7 @@ class _TestProxyAPI(ValidateAPI):
     The <header> above should support at least "get_data_dtype",
     "set_data_dtype", "get_data_shape", "set_data_shape"
     """
+
     # Flag True if offset can be set into header of image
     settable_offset = False
 
@@ -201,11 +201,12 @@ class _TestProxyAPI(ValidateAPI):
 
 
 class TestAnalyzeProxyAPI(_TestProxyAPI):
-    """ Specific Analyze-type array proxy API test
+    """Specific Analyze-type array proxy API test
 
     The analyze proxy extends the general API by adding read-only attributes
     ``slope, inter, offset``
     """
+
     proxy_class = ArrayProxy
     header_class = AnalyzeHeader
     shapes = ((2,), (2, 3), (2, 3, 4), (2, 3, 4, 5))
@@ -219,7 +220,7 @@ class TestAnalyzeProxyAPI(_TestProxyAPI):
     data_endian = '='
 
     def obj_params(self):
-        """ Iterator returning (``proxy_creator``, ``proxy_params``) pairs
+        """Iterator returning (``proxy_creator``, ``proxy_params``) pairs
 
         Each pair will be tested separately.
 
@@ -238,13 +239,15 @@ class TestAnalyzeProxyAPI(_TestProxyAPI):
             offsets = (0, 16)
         # For non-integral parameters, cast to float32 value can be losslessly cast
         # later, enabling exact checks, then back to float for consistency
-        slopes = (1., 2., float(np.float32(3.1416))) if self.has_slope else (1.,)
-        inters = (0., 10., float(np.float32(2.7183))) if self.has_inter else (0.,)
-        for shape, dtype, offset, slope, inter in product(self.shapes,
-                                                          self.data_dtypes,
-                                                          offsets,
-                                                          slopes,
-                                                          inters):
+        slopes = (1.0, 2.0, float(np.float32(3.1416))) if self.has_slope else (1.0,)
+        inters = (0.0, 10.0, float(np.float32(2.7183))) if self.has_inter else (0.0,)
+        for shape, dtype, offset, slope, inter in product(
+            self.shapes,
+            self.data_dtypes,
+            offsets,
+            slopes,
+            inters,
+        ):
             n_els = np.prod(shape)
             dtype = np.dtype(dtype).newbyteorder(self.data_endian)
             arr = np.arange(n_els, dtype=dtype).reshape(shape)
@@ -262,9 +265,7 @@ class TestAnalyzeProxyAPI(_TestProxyAPI):
                 # and datatypes of slope, inter
                 hdr.set_slope_inter(slope, inter)
                 s, i = hdr.get_slope_inter()
-                tmp = apply_read_scaling(arr,
-                                         1. if s is None else s,
-                                         0. if i is None else i)
+                tmp = apply_read_scaling(arr, 1.0 if s is None else s, 0.0 if i is None else i)
                 dtype_out = tmp.dtype.type
 
             def sio_func():
@@ -275,9 +276,7 @@ class TestAnalyzeProxyAPI(_TestProxyAPI):
                 # Use a copy of the header to avoid changing
                 # global header in test functions.
                 new_hdr = hdr.copy()
-                return (self.proxy_class(fio, new_hdr),
-                        fio,
-                        new_hdr)
+                return (self.proxy_class(fio, new_hdr), fio, new_hdr)
 
             params = dict(
                 dtype=dtype,
@@ -287,7 +286,8 @@ class TestAnalyzeProxyAPI(_TestProxyAPI):
                 shape=shape,
                 offset=offset,
                 slope=slope,
-                inter=inter)
+                inter=inter,
+            )
             yield sio_func, params
             # Same with filenames
             with InTemporaryDirectory():
@@ -300,9 +300,8 @@ class TestAnalyzeProxyAPI(_TestProxyAPI):
                     # Use a copy of the header to avoid changing
                     # global header in test functions.
                     new_hdr = hdr.copy()
-                    return (self.proxy_class(fname, new_hdr),
-                            fname,
-                            new_hdr)
+                    return (self.proxy_class(fname, new_hdr), fname, new_hdr)
+
                 params = params.copy()
                 yield fname_func, params
 
@@ -323,11 +322,6 @@ class TestAnalyzeProxyAPI(_TestProxyAPI):
             with pytest.raises(AttributeError):
                 setattr(prox, attr_name, expected)
 
-    def validate_deprecated_header(self, pmaker, params):
-        prox, fio, hdr = pmaker()
-        with pytest.raises(ExpiredDeprecationError):
-            prox.header
-
 
 class TestSpm99AnalyzeProxyAPI(TestAnalyzeProxyAPI):
     # SPM-type analyze has slope scaling but not intercept
@@ -342,8 +336,20 @@ class TestSpm2AnalyzeProxyAPI(TestSpm99AnalyzeProxyAPI):
 class TestNifti1ProxyAPI(TestSpm99AnalyzeProxyAPI):
     header_class = Nifti1Header
     has_inter = True
-    data_dtypes = (np.uint8, np.int16, np.int32, np.float32, np.complex64, np.float64,
-                   np.int8, np.uint16, np.uint32, np.int64, np.uint64, np.complex128)
+    data_dtypes = (
+        np.uint8,
+        np.int16,
+        np.int32,
+        np.float32,
+        np.complex64,
+        np.float64,
+        np.int8,
+        np.uint16,
+        np.uint32,
+        np.int64,
+        np.uint64,
+        np.complex128,
+    )
     if have_binary128():
         data_dtypes += (np.float128, np.complex256)
 
@@ -369,7 +375,7 @@ class TestMinc1API(_TestProxyAPI):
         return netcdf_file(f, mode='r')
 
     def obj_params(self):
-        """ Iterator returning (``proxy_creator``, ``proxy_params``) pairs
+        """Iterator returning (``proxy_creator``, ``proxy_params``) pairs
 
         Each pair will be tested separately.
 
@@ -381,8 +387,7 @@ class TestMinc1API(_TestProxyAPI):
         having an effect on the later tests in the same function.
         """
         eg_path = pjoin(DATA_PATH, self.eg_fname)
-        arr_out = self.file_class(
-            self.opener(eg_path)).get_scaled_data()
+        arr_out = self.file_class(self.opener(eg_path)).get_scaled_data()
 
         def eg_func():
             mf = self.file_class(self.opener(eg_path))
@@ -390,13 +395,12 @@ class TestMinc1API(_TestProxyAPI):
             img = self.module.load(eg_path)
             fobj = open(eg_path, 'rb')
             return prox, fobj, img.header
-        yield (eg_func,
-               dict(shape=self.eg_shape,
-                    dtype_out=np.float64,
-                    arr_out=arr_out))
+
+        yield (eg_func, dict(shape=self.eg_shape, dtype_out=np.float64, arr_out=arr_out))
 
 
 if have_h5py:
+
     class TestMinc2API(TestMinc1API):
         module = minc2
         file_class = minc2.Minc2File
@@ -423,32 +427,25 @@ class TestEcatAPI(_TestProxyAPI):
             prox = ecat.EcatImageArrayProxy(sh)
             fobj = open(eg_path, 'rb')
             return prox, fobj, sh
-        yield (eg_func,
-               dict(shape=self.eg_shape,
-                    dtype_out=np.float64,
-                    arr_out=arr_out))
+
+        yield (eg_func, dict(shape=self.eg_shape, dtype_out=np.float64, arr_out=arr_out))
 
     def validate_header_isolated(self, pmaker, params):
         raise unittest.SkipTest('ECAT header does not support dtype get')
 
 
 class TestPARRECAPI(_TestProxyAPI):
-
     def _func_dict(self, rec_name):
         img = parrec.load(rec_name)
         arr_out = img.get_fdata()
 
         def eg_func():
             img = parrec.load(rec_name)
-            prox = parrec.PARRECArrayProxy(rec_name,
-                                           img.header,
-                                           scaling='dv')
+            prox = parrec.PARRECArrayProxy(rec_name, img.header, scaling='dv')
             fobj = open(rec_name, 'rb')
             return prox, fobj, img.header
-        return (eg_func,
-                dict(shape=img.shape,
-                     dtype_out=np.float64,
-                     arr_out=arr_out))
+
+        return (eg_func, dict(shape=img.shape, dtype_out=np.float64, arr_out=arr_out))
 
     def obj_params(self):
         yield self._func_dict(EG_REC)
