@@ -6,50 +6,51 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Test for scaling / rounding in volumeutils module """
+"""Test for scaling / rounding in volumeutils module"""
+
+import warnings
+from io import BytesIO
 
 import numpy as np
-import warnings
+import pytest
+from numpy.testing import assert_array_almost_equal, assert_array_equal
 
-from io import BytesIO
-from ..volumeutils import finite_range, apply_read_scaling, array_to_file, array_from_file
 from ..casting import type_info
 from ..testing import suppress_warnings
-
+from ..volumeutils import apply_read_scaling, array_from_file, array_to_file, finite_range
 from .test_volumeutils import _calculate_scale
 
-from numpy.testing import (assert_array_almost_equal, assert_array_equal)
-import pytest
-
-
 # Debug print statements
 DEBUG = True
 
 
-@pytest.mark.parametrize("in_arr, res", [
-    ([[-1, 0, 1], [np.inf, np.nan, -np.inf]], (-1, 1)),
-    (np.array([[-1, 0, 1], [np.inf, np.nan, -np.inf]]), (-1, 1)),
-    ([[np.nan], [np.nan]], (np.inf, -np.inf)),  # all nans slices
-    (np.zeros((3, 4, 5)) + np.nan, (np.inf, -np.inf)),
-    ([[-np.inf], [np.inf]], (np.inf, -np.inf)),  # all infs slices
-    (np.zeros((3, 4, 5)) + np.inf, (np.inf, -np.inf)),
-    ([[np.nan, -1, 2], [-2, np.nan, 1]], (-2, 2)),
-    ([[np.nan, -np.inf, 2], [-2, np.nan, np.inf]], (-2, 2)),
-    ([[-np.inf, 2], [np.nan, 1]], (1, 2)),  # good max case
-    ([[np.nan, -np.inf, 2], [-2, np.nan, np.inf]], (-2, 2)),
-    ([np.nan], (np.inf, -np.inf)),
-    ([np.inf], (np.inf, -np.inf)),
-    ([-np.inf], (np.inf, -np.inf)),
-    ([np.inf, 1], (1, 1)),  # only look at finite values
-    ([-np.inf, 1], (1, 1)),
-    ([[], []], (np.inf, -np.inf)),  # empty array
-    (np.array([[-3, 0, 1], [2, -1, 4]], dtype=int), (-3, 4)),
-    (np.array([[1, 0, 1], [2, 3, 4]], dtype=np.uint), (0, 4)),
-    ([0., 1, 2, 3], (0, 3)),
-    # Complex comparison works as if they are floats
-    ([[np.nan, -1 - 100j, 2], [-2, np.nan, 1 + 100j]], (-2, 2)),
-    ([[np.nan, -1, 2 - 100j], [-2 + 100j, np.nan, 1]], (-2 + 100j, 2 - 100j)),
-])
+@pytest.mark.parametrize(
+    'in_arr, res',
+    [
+        ([[-1, 0, 1], [np.inf, np.nan, -np.inf]], (-1, 1)),
+        (np.array([[-1, 0, 1], [np.inf, np.nan, -np.inf]]), (-1, 1)),
+        ([[np.nan], [np.nan]], (np.inf, -np.inf)),  # all nans slices
+        (np.zeros((3, 4, 5)) + np.nan, (np.inf, -np.inf)),
+        ([[-np.inf], [np.inf]], (np.inf, -np.inf)),  # all infs slices
+        (np.zeros((3, 4, 5)) + np.inf, (np.inf, -np.inf)),
+        ([[np.nan, -1, 2], [-2, np.nan, 1]], (-2, 2)),
+        ([[np.nan, -np.inf, 2], [-2, np.nan, np.inf]], (-2, 2)),
+        ([[-np.inf, 2], [np.nan, 1]], (1, 2)),  # good max case
+        ([[np.nan, -np.inf, 2], [-2, np.nan, np.inf]], (-2, 2)),
+        ([np.nan], (np.inf, -np.inf)),
+        ([np.inf], (np.inf, -np.inf)),
+        ([-np.inf], (np.inf, -np.inf)),
+        ([np.inf, 1], (1, 1)),  # only look at finite values
+        ([-np.inf, 1], (1, 1)),
+        ([[], []], (np.inf, -np.inf)),  # empty array
+        (np.array([[-3, 0, 1], [2, -1, 4]], dtype=int), (-3, 4)),
+        (np.array([[1, 0, 1], [2, 3, 4]], dtype=np.uint), (0, 4)),
+        ([0.0, 1, 2, 3], (0, 3)),
+        # Complex comparison works as if they are floats
+        ([[np.nan, -1 - 100j, 2], [-2, np.nan, 1 + 100j]], (-2, 2)),
+        ([[np.nan, -1, 2 - 100j], [-2 + 100j, np.nan, 1]], (-2 + 100j, 2 - 100j)),
+    ],
+)
 def test_finite_range(in_arr, res):
     # Finite range utility function
     assert finite_range(in_arr) == res
@@ -71,12 +72,12 @@ def test_finite_range(in_arr, res):
 
 def test_finite_range_err():
     # Test error cases
-    a = np.array([[1., 0, 1], [2, 3, 4]]).view([('f1', 'f')])
+    a = np.array([[1.0, 0, 1], [2, 3, 4]]).view([('f1', 'f')])
     with pytest.raises(TypeError):
         finite_range(a)
 
 
-@pytest.mark.parametrize("out_type", [np.int16, np.float32])
+@pytest.mark.parametrize('out_type', [np.int16, np.float32])
 def test_a2f_mn_mx(out_type):
     # Test array to file mn, mx handling
     str_io = BytesIO()
@@ -111,7 +112,7 @@ def test_a2f_mn_mx(out_type):
 
 def test_a2f_nan2zero():
     # Test conditions under which nans written to zero
-    arr = np.array([np.nan, 99.], dtype=np.float32)
+    arr = np.array([np.nan, 99.0], dtype=np.float32)
     str_io = BytesIO()
     array_to_file(arr, str_io)
     data_back = array_from_file(arr.shape, np.float32, str_io)
@@ -132,14 +133,17 @@ def test_a2f_nan2zero():
     assert_array_equal(data_back, [np.array(np.nan).astype(np.int32), 99])
 
 
-@pytest.mark.parametrize("in_type, out_type", [
-    (np.int16, np.int16),
-    (np.int16, np.int8),
-    (np.uint16, np.uint8),
-    (np.int32, np.int8),
-    (np.float32, np.uint8),
-    (np.float32, np.int16)
-])
+@pytest.mark.parametrize(
+    'in_type, out_type',
+    [
+        (np.int16, np.int16),
+        (np.int16, np.int8),
+        (np.uint16, np.uint8),
+        (np.int32, np.int8),
+        (np.float32, np.uint8),
+        (np.float32, np.int16),
+    ],
+)
 def test_array_file_scales(in_type, out_type):
     # Test scaling works for max, min when going from larger to smaller type,
     # and from float to integer.
@@ -154,21 +158,24 @@ def test_array_file_scales(in_type, out_type):
     arr2 = array_from_file(arr.shape, out_dtype, bio)
     arr3 = apply_read_scaling(arr2, slope, inter)
     # Max rounding error for integer type
-    max_miss = slope / 2.
+    max_miss = slope / 2.0
     assert np.all(np.abs(arr - arr3) <= max_miss)
 
 
-@pytest.mark.parametrize("category0, category1, overflow",[
-    # Confirm that, for all ints and uints as input, and all possible outputs,
-    # for any simple way of doing the calculation, the result is near enough
-    ('int', 'int', False),
-    ('uint', 'int', False),
-    # Converting floats to integer
-    ('float', 'int', True),
-    ('float', 'uint', True),
-    ('complex', 'int', True),
-    ('complex', 'uint', True),
-])
+@pytest.mark.parametrize(
+    'category0, category1, overflow',
+    [
+        # Confirm that, for all ints and uints as input, and all possible outputs,
+        # for any simple way of doing the calculation, the result is near enough
+        ('int', 'int', False),
+        ('uint', 'int', False),
+        # Converting floats to integer
+        ('float', 'int', True),
+        ('float', 'uint', True),
+        ('complex', 'int', True),
+        ('complex', 'uint', True),
+    ],
+)
 def test_scaling_in_abstract(category0, category1, overflow):
     for in_type in np.sctypes[category0]:
         for out_type in np.sctypes[category1]:
