@@ -1,36 +1,35 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-""" Test scripts
+"""Test scripts
 
 Test running scripts
 """
 
-import sys
+import csv
 import os
 import shutil
-from os.path import (dirname, join as pjoin, abspath, splitext, basename,
-                     exists)
-import csv
+import sys
+import unittest
 from glob import glob
+from os.path import abspath, basename, dirname, exists
+from os.path import join as pjoin
+from os.path import splitext
 
 import numpy as np
-
-import nibabel as nib
-from ..tmpdirs import InTemporaryDirectory
-from ..loadsave import load
-from ..orientations import aff2axcodes, inv_ornt_aff
-
-import unittest
 import pytest
 from numpy.testing import assert_almost_equal
 
-from .scriptrunner import ScriptRunner
+import nibabel as nib
+
+from ..loadsave import load
+from ..orientations import aff2axcodes, inv_ornt_aff
+from ..testing import assert_data_similar, assert_dt_equal, assert_re_in
+from ..tmpdirs import InTemporaryDirectory
 from .nibabel_data import needs_nibabel_data
-from ..testing import assert_dt_equal, assert_re_in
-from .test_parrec import (DTI_PAR_BVECS, DTI_PAR_BVALS,
-                          EXAMPLE_IMAGES as PARREC_EXAMPLES)
-from .test_parrec_data import BALLS, AFF_OFF
-from ..testing import assert_data_similar
+from .scriptrunner import ScriptRunner
+from .test_parrec import DTI_PAR_BVALS, DTI_PAR_BVECS
+from .test_parrec import EXAMPLE_IMAGES as PARREC_EXAMPLES
+from .test_parrec_data import AFF_OFF, BALLS
 
 
 def _proc_stdout(stdout):
@@ -39,9 +38,8 @@ def _proc_stdout(stdout):
 
 
 runner = ScriptRunner(
-    script_sdir='bin',
-    debug_print_var='NIPY_DEBUG_PRINT',
-    output_processor=_proc_stdout)
+    script_sdir='bin', debug_print_var='NIPY_DEBUG_PRINT', output_processor=_proc_stdout
+)
 run_command = runner.run_command
 
 
@@ -49,6 +47,8 @@ def script_test(func):
     # Decorator to label test as a script_test
     func.script_test = True
     return func
+
+
 script_test.__test__ = False  # It's not a test
 
 DATA_PATH = abspath(pjoin(dirname(__file__), 'data'))
@@ -62,59 +62,91 @@ def load_small_file():
         return False
 
 
-def check_nib_ls_example4d(opts=[], hdrs_str="", other_str=""):
+def check_nib_ls_example4d(opts=[], hdrs_str='', other_str=''):
     # test nib-ls script
     fname = pjoin(DATA_PATH, 'example4d.nii.gz')
-    expected_re = (" (int16|[<>]i2) \\[128,  96,  24,   2\\] 2.00x2.00x2.20x2000.00  "
-                   f"#exts: 2{hdrs_str} sform{other_str}$")
+    expected_re = (
+        ' (int16|[<>]i2) \\[128,  96,  24,   2\\] 2.00x2.00x2.20x2000.00  '
+        f'#exts: 2{hdrs_str} sform{other_str}$'
+    )
     cmd = ['nib-ls'] + opts + [fname]
     code, stdout, stderr = run_command(cmd)
-    assert fname == stdout[:len(fname)]
-    assert_re_in(expected_re, stdout[len(fname):])
+    assert fname == stdout[: len(fname)]
+    assert_re_in(expected_re, stdout[len(fname) :])
 
 
 def check_nib_diff_examples():
-    fnames = [pjoin(DATA_PATH, f)
-               for f in ('standard.nii.gz', 'example4d.nii.gz')]
+    fnames = [pjoin(DATA_PATH, f) for f in ('standard.nii.gz', 'example4d.nii.gz')]
     code, stdout, stderr = run_command(['nib-diff'] + fnames, check_code=False)
-    checked_fields = ["Field/File", "regular", "dim_info", "dim", "datatype", "bitpix", "pixdim", "slice_end",
-                      "xyzt_units", "cal_max", "descrip", "qform_code", "sform_code", "quatern_b",
-                      "quatern_c", "quatern_d", "qoffset_x", "qoffset_y", "qoffset_z", "srow_x",
-                      "srow_y", "srow_z", "DATA(md5)", "DATA(diff 1:)"]
+    checked_fields = [
+        'Field/File',
+        'regular',
+        'dim_info',
+        'dim',
+        'datatype',
+        'bitpix',
+        'pixdim',
+        'slice_end',
+        'xyzt_units',
+        'cal_max',
+        'descrip',
+        'qform_code',
+        'sform_code',
+        'quatern_b',
+        'quatern_c',
+        'quatern_d',
+        'qoffset_x',
+        'qoffset_y',
+        'qoffset_z',
+        'srow_x',
+        'srow_y',
+        'srow_z',
+        'DATA(md5)',
+        'DATA(diff 1:)',
+    ]
     for item in checked_fields:
         assert item in stdout
 
-    fnames2 = [pjoin(DATA_PATH, f)
-              for f in ('example4d.nii.gz', 'example4d.nii.gz')]
+    fnames2 = [pjoin(DATA_PATH, f) for f in ('example4d.nii.gz', 'example4d.nii.gz')]
     code, stdout, stderr = run_command(['nib-diff'] + fnames2, check_code=False)
-    assert stdout == "These files are identical."
+    assert stdout == 'These files are identical.'
 
-    fnames3 = [pjoin(DATA_PATH, f)
-               for f in ('standard.nii.gz', 'example4d.nii.gz', 'example_nifti2.nii.gz')]
+    fnames3 = [
+        pjoin(DATA_PATH, f)
+        for f in ('standard.nii.gz', 'example4d.nii.gz', 'example_nifti2.nii.gz')
+    ]
     code, stdout, stderr = run_command(['nib-diff'] + fnames3, check_code=False)
     for item in checked_fields:
         assert item in stdout
 
-    fnames4 = [pjoin(DATA_PATH, f)
-               for f in ('standard.nii.gz', 'standard.nii.gz', 'standard.nii.gz')]
+    fnames4 = [
+        pjoin(DATA_PATH, f) for f in ('standard.nii.gz', 'standard.nii.gz', 'standard.nii.gz')
+    ]
     code, stdout, stderr = run_command(['nib-diff'] + fnames4, check_code=False)
-    assert stdout == "These files are identical."
+    assert stdout == 'These files are identical.'
 
     code, stdout, stderr = run_command(['nib-diff', '--dt', 'float64'] + fnames, check_code=False)
     for item in checked_fields:
         assert item in stdout
 
 
-@pytest.mark.parametrize("args", [
-    [],
-    [['-H', 'dim,bitpix'], r" \[  4 128  96  24   2   1   1   1\] 16"],
-    [['-c'], "", " !1030 uniques. Use --all-counts"],
-    [['-c', '--all-counts'], "", " 2:3 3:2 4:1 5:1.*"],
-    # both stats and counts
-    [['-c', '-s', '--all-counts'], "", r" \[229725\] \[2, 1.2e\+03\] 2:3 3:2 4:1 5:1.*"],
-    # and must not error out if we allow for zeros
-    [['-c', '-s', '-z', '--all-counts'], "", r" \[589824\] \[0, 1.2e\+03\] 0:360099 2:3 3:2 4:1 5:1.*"],
-])
+@pytest.mark.parametrize(
+    'args',
+    [
+        [],
+        [['-H', 'dim,bitpix'], r' \[  4 128  96  24   2   1   1   1\] 16'],
+        [['-c'], '', ' !1030 uniques. Use --all-counts'],
+        [['-c', '--all-counts'], '', ' 2:3 3:2 4:1 5:1.*'],
+        # both stats and counts
+        [['-c', '-s', '--all-counts'], '', r' \[229725\] \[2, 1.2e\+03\] 2:3 3:2 4:1 5:1.*'],
+        # and must not error out if we allow for zeros
+        [
+            ['-c', '-s', '-z', '--all-counts'],
+            '',
+            r' \[589824\] \[0, 1.2e\+03\] 0:360099 2:3 3:2 4:1 5:1.*',
+        ],
+    ],
+)
 @script_test
 def test_nib_ls(args):
     check_nib_ls_example4d(*args)
@@ -126,8 +158,7 @@ def test_nib_ls_multiple():
     # verify that correctly lists/formats for multiple files
     fnames = [
         pjoin(DATA_PATH, f)
-        for f in ('example4d.nii.gz', 'example_nifti2.nii.gz',
-                  'small.mnc', 'nifti2.hdr')
+        for f in ('example4d.nii.gz', 'example_nifti2.nii.gz', 'small.mnc', 'nifti2.hdr')
     ]
     code, stdout, stderr = run_command(['nib-ls'] + fnames)
     stdout_lines = stdout.split('\n')
@@ -136,30 +167,27 @@ def test_nib_ls_multiple():
     # they should be indented correctly.  Since all files are int type -
     ln = max(len(f) for f in fnames)
     i_str = ' i' if sys.byteorder == 'little' else ' <i'
-    assert [l[ln:ln + len(i_str)] for l in stdout_lines] == [i_str] * 4, \
-            f"Type sub-string didn't start with '{i_str}'. Full output was: {stdout_lines}"
+    assert [l[ln : ln + len(i_str)] for l in stdout_lines] == [
+        i_str
+    ] * 4, f"Type sub-string didn't start with '{i_str}'. Full output was: {stdout_lines}"
     # and if disregard type indicator which might vary
-    assert (
-        [l[l.index('['):] for l in stdout_lines] ==
-        [
-            '[128,  96,  24,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform',
-            '[ 32,  20,  12,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform',
-            '[ 18,  28,  29]      9.00x8.00x7.00',
-            '[ 91, 109,  91]      2.00x2.00x2.00'
-        ])
+    assert [l[l.index('[') :] for l in stdout_lines] == [
+        '[128,  96,  24,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform',
+        '[ 32,  20,  12,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform',
+        '[ 18,  28,  29]      9.00x8.00x7.00',
+        '[ 91, 109,  91]      2.00x2.00x2.00',
+    ]
 
     # Now run with -s for stats
     code, stdout, stderr = run_command(['nib-ls', '-s'] + fnames)
     stdout_lines = stdout.split('\n')
     assert len(stdout_lines) == 4
-    assert (
-        [l[l.index('['):] for l in stdout_lines] ==
-        [
-            '[128,  96,  24,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform [229725] [2, 1.2e+03]',
-            '[ 32,  20,  12,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform [15360]  [46, 7.6e+02]',
-            '[ 18,  28,  29]      9.00x8.00x7.00                         [14616]  [0.12, 93]',
-            '[ 91, 109,  91]      2.00x2.00x2.00                          !error'
-        ])
+    assert [l[l.index('[') :] for l in stdout_lines] == [
+        '[128,  96,  24,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform [229725] [2, 1.2e+03]',
+        '[ 32,  20,  12,   2] 2.00x2.00x2.20x2000.00  #exts: 2 sform [15360]  [46, 7.6e+02]',
+        '[ 18,  28,  29]      9.00x8.00x7.00                         [14616]  [0.12, 93]',
+        '[ 91, 109,  91]      2.00x2.00x2.00                          !error',
+    ]
 
 
 @script_test
@@ -174,8 +202,8 @@ def test_help():
                 continue  # do not test this one
         code, stdout, stderr = run_command([cmd, '--help'])
         assert code == 0
-        assert_re_in(f".*{cmd}", stdout)
-        assert_re_in(".*Usage", stdout)
+        assert_re_in(f'.*{cmd}', stdout)
+        assert_re_in('.*Usage', stdout)
         # Some third party modules might like to announce some Deprecation
         # etc warnings, see e.g. https://travis-ci.org/nipy/nibabel/jobs/370353602
         if 'warning' not in stderr.lower():
@@ -267,28 +295,21 @@ def test_parrec2nii():
             # Delete previous img, data to make Windows happier
             del img, data
             # Does not overwrite unless option given
-            code, stdout, stderr = run_command(
-                ['parrec2nii', fname], check_code=False)
+            code, stdout, stderr = run_command(['parrec2nii', fname], check_code=False)
             assert code == 1
             # Default scaling is dv
             pr_img = load(fname)
             flipped_data = np.flip(pr_img.get_fdata(), 1)
             base_cmd = ['parrec2nii', '--overwrite', fname]
             check_conversion(base_cmd, flipped_data, out_froot)
-            check_conversion(base_cmd + ['--scaling=dv'],
-                             flipped_data,
-                             out_froot)
+            check_conversion(base_cmd + ['--scaling=dv'], flipped_data, out_froot)
             # fp
             pr_img = load(fname, scaling='fp')
             flipped_data = np.flip(pr_img.get_fdata(), 1)
-            check_conversion(base_cmd + ['--scaling=fp'],
-                             flipped_data,
-                             out_froot)
+            check_conversion(base_cmd + ['--scaling=fp'], flipped_data, out_froot)
             # no scaling
             unscaled_flipped = np.flip(pr_img.dataobj.get_unscaled(), 1)
-            check_conversion(base_cmd + ['--scaling=off'],
-                             unscaled_flipped,
-                             out_froot)
+            check_conversion(base_cmd + ['--scaling=off'], unscaled_flipped, out_froot)
             # Save extensions
             run_command(base_cmd + ['--store-header'])
             img = load(out_froot)
@@ -324,8 +345,7 @@ def test_parrec2nii_with_data():
                 assert aff2axcodes(philips_img.affine) == tuple('LPS')
                 # Equivalent to Philips LPS affine
                 equiv_affine = conved_img.affine.dot(LAS2LPS)
-                assert_almost_equal(philips_img.affine[:3, :3],
-                                    equiv_affine[:3, :3], 3)
+                assert_almost_equal(philips_img.affine[:3, :3], equiv_affine[:3, :3], 3)
                 # The translation part is always off by the same ammout
                 aff_off = equiv_affine[:3, 3] - philips_img.affine[:3, 3]
                 assert_almost_equal(aff_off, AFF_OFF, 3)
@@ -344,12 +364,10 @@ def test_parrec2nii_with_data():
         assert not exists('DTI.bvals')
         assert not exists('DTI.bvecs')
         # Does not overwrite unless option given
-        code, stdout, stderr = run_command(['parrec2nii', dti_par],
-                                           check_code=False)
+        code, stdout, stderr = run_command(['parrec2nii', dti_par], check_code=False)
         assert code == 1
         # Writes bvals, bvecs files if asked
-        run_command(['parrec2nii', '--overwrite', '--keep-trace',
-                     '--bvs', dti_par])
+        run_command(['parrec2nii', '--overwrite', '--keep-trace', '--bvs', dti_par])
         bvecs_trace = np.loadtxt('DTI.bvecs').T
         bvals_trace = np.loadtxt('DTI.bvals')
         assert_almost_equal(bvals_trace, DTI_PAR_BVALS)
@@ -364,15 +382,17 @@ def test_parrec2nii_with_data():
         # Dwell time
         assert not exists('DTI.dwell_time')
         # Need field strength if requesting dwell time
-        code, _, _, = run_command(
-            ['parrec2nii', '--overwrite', '--dwell-time', dti_par],
-            check_code=False)
+        (
+            code,
+            _,
+            _,
+        ) = run_command(['parrec2nii', '--overwrite', '--dwell-time', dti_par], check_code=False)
         assert code == 1
         run_command(
-            ['parrec2nii', '--overwrite', '--dwell-time',
-             '--field-strength', '3', dti_par])
+            ['parrec2nii', '--overwrite', '--dwell-time', '--field-strength', '3', dti_par]
+        )
         exp_dwell = (26 * 9.087) / (42.576 * 3.4 * 3 * 28)
-        with open('DTI.dwell_time', 'rt') as fobj:
+        with open('DTI.dwell_time') as fobj:
             contents = fobj.read().strip()
         assert_almost_equal(float(contents), exp_dwell)
         # ensure trace is removed by default
@@ -386,14 +406,14 @@ def test_parrec2nii_with_data():
         assert data_notrace.shape[-1] == len(bvecs_notrace)
         del img
         # ensure correct volume was removed
-        good_mask = np.logical_or((bvecs_trace != 0).any(axis=1),
-                                  bvals_trace == 0)
+        good_mask = np.logical_or((bvecs_trace != 0).any(axis=1), bvals_trace == 0)
         assert_almost_equal(data_notrace, data[..., good_mask])
         assert_almost_equal(bvals_notrace, np.array(DTI_PAR_BVALS)[good_mask])
         assert_almost_equal(bvecs_notrace, bvecs_LAS[good_mask])
         # test --strict-sort
-        run_command(['parrec2nii', '--overwrite', '--keep-trace',
-                     '--bvs', '--strict-sort', dti_par])
+        run_command(
+            ['parrec2nii', '--overwrite', '--keep-trace', '--bvs', '--strict-sort', dti_par]
+        )
         # strict-sort: bvals should be in ascending order
         assert_almost_equal(np.loadtxt('DTI.bvals'), np.sort(DTI_PAR_BVALS))
         img = load('DTI.nii')
@@ -404,7 +424,7 @@ def test_parrec2nii_with_data():
         # Writes .ordering.csv if requested
         run_command(['parrec2nii', '--overwrite', '--volume-info', dti_par])
         assert exists('DTI.ordering.csv')
-        with open('DTI.ordering.csv', 'r') as csvfile:
+        with open('DTI.ordering.csv') as csvfile:
             csvreader = csv.reader(csvfile, delimiter=',')
             csv_keys = next(csvreader)  # header row
             nlines = 0  # count number of non-header rows
@@ -417,20 +437,20 @@ def test_parrec2nii_with_data():
 
 @script_test
 def test_nib_trk2tck():
-    simple_trk = pjoin(DATA_PATH, "simple.trk")
-    standard_trk = pjoin(DATA_PATH, "standard.trk")
+    simple_trk = pjoin(DATA_PATH, 'simple.trk')
+    standard_trk = pjoin(DATA_PATH, 'standard.trk')
 
     with InTemporaryDirectory() as tmpdir:
         # Copy input files to convert.
         shutil.copy(simple_trk, tmpdir)
         shutil.copy(standard_trk, tmpdir)
-        simple_trk = pjoin(tmpdir, "simple.trk")
-        standard_trk = pjoin(tmpdir, "standard.trk")
-        simple_tck = pjoin(tmpdir, "simple.tck")
-        standard_tck = pjoin(tmpdir, "standard.tck")
+        simple_trk = pjoin(tmpdir, 'simple.trk')
+        standard_trk = pjoin(tmpdir, 'standard.trk')
+        simple_tck = pjoin(tmpdir, 'simple.tck')
+        standard_tck = pjoin(tmpdir, 'standard.tck')
 
         # Convert one file.
-        cmd = ["nib-trk2tck", simple_trk]
+        cmd = ['nib-trk2tck', simple_trk]
         code, stdout, stderr = run_command(cmd)
         assert len(stdout) == 0
         assert os.path.isfile(simple_tck)
@@ -440,17 +460,17 @@ def test_nib_trk2tck():
         assert isinstance(tck, nib.streamlines.TckFile)
 
         # Skip non TRK files.
-        cmd = ["nib-trk2tck", simple_tck]
+        cmd = ['nib-trk2tck', simple_tck]
         code, stdout, stderr = run_command(cmd)
-        assert "Skipping non TRK file" in stdout
+        assert 'Skipping non TRK file' in stdout
 
         # By default, refuse to overwrite existing output files.
-        cmd = ["nib-trk2tck", simple_trk]
+        cmd = ['nib-trk2tck', simple_trk]
         code, stdout, stderr = run_command(cmd)
-        assert "Skipping existing file" in stdout
+        assert 'Skipping existing file' in stdout
 
         # Convert multiple files and with --force.
-        cmd = ["nib-trk2tck", "--force", simple_trk, standard_trk]
+        cmd = ['nib-trk2tck', '--force', simple_trk, standard_trk]
         code, stdout, stderr = run_command(cmd)
         assert len(stdout) == 0
         trk = nib.streamlines.load(standard_trk)
@@ -460,23 +480,23 @@ def test_nib_trk2tck():
 
 @script_test
 def test_nib_tck2trk():
-    anat = pjoin(DATA_PATH, "standard.nii.gz")
-    standard_tck = pjoin(DATA_PATH, "standard.tck")
+    anat = pjoin(DATA_PATH, 'standard.nii.gz')
+    standard_tck = pjoin(DATA_PATH, 'standard.tck')
 
     with InTemporaryDirectory() as tmpdir:
         # Copy input file to convert.
         shutil.copy(standard_tck, tmpdir)
-        standard_trk = pjoin(tmpdir, "standard.trk")
-        standard_tck = pjoin(tmpdir, "standard.tck")
+        standard_trk = pjoin(tmpdir, 'standard.trk')
+        standard_tck = pjoin(tmpdir, 'standard.tck')
 
         # Anatomical image not found as first argument.
-        cmd = ["nib-tck2trk", standard_tck, anat]
+        cmd = ['nib-tck2trk', standard_tck, anat]
         code, stdout, stderr = run_command(cmd, check_code=False)
         assert code == 2  # Parser error.
-        assert "Expecting anatomical image as first agument" in stderr
+        assert 'Expecting anatomical image as first argument' in stderr
 
         # Convert one file.
-        cmd = ["nib-tck2trk", anat, standard_tck]
+        cmd = ['nib-tck2trk', anat, standard_tck]
         code, stdout, stderr = run_command(cmd)
         assert len(stdout) == 0
         assert os.path.isfile(standard_trk)
@@ -486,17 +506,17 @@ def test_nib_tck2trk():
         assert isinstance(trk, nib.streamlines.TrkFile)
 
         # Skip non TCK files.
-        cmd = ["nib-tck2trk", anat, standard_trk]
+        cmd = ['nib-tck2trk', anat, standard_trk]
         code, stdout, stderr = run_command(cmd)
-        assert "Skipping non TCK file" in stdout
+        assert 'Skipping non TCK file' in stdout
 
         # By default, refuse to overwrite existing output files.
-        cmd = ["nib-tck2trk", anat, standard_tck]
+        cmd = ['nib-tck2trk', anat, standard_tck]
         code, stdout, stderr = run_command(cmd)
-        assert "Skipping existing file" in stdout
+        assert 'Skipping existing file' in stdout
 
         # Convert multiple files and with --force.
-        cmd = ["nib-tck2trk", "--force", anat, standard_tck, standard_tck]
+        cmd = ['nib-tck2trk', '--force', anat, standard_tck, standard_tck]
         code, stdout, stderr = run_command(cmd)
         assert len(stdout) == 0
         tck = nib.streamlines.load(standard_tck)
