@@ -6,43 +6,51 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Utility functions for analyze-like formats """
+"""Utility functions for analyze-like formats"""
+from __future__ import annotations
 
+import gzip
 import sys
 import warnings
-import gzip
 from collections import OrderedDict
-from os.path import exists, splitext
-from operator import mul
 from functools import reduce
+from operator import mul
+from os.path import exists, splitext
 
 import numpy as np
 
-from .casting import (shared_range, type_info, OK_FLOATS)
-from .openers import Opener, BZ2File, IndexedGzipFile
-from .deprecated import deprecate_with_version
+from .casting import OK_FLOATS, shared_range
 from .externals.oset import OrderedSet
+from .openers import BZ2File, IndexedGzipFile
+from .optpkg import optional_package
+
+pyzstd, HAVE_ZSTD, _ = optional_package('pyzstd')
 
 sys_is_le = sys.byteorder == 'little'
 native_code = sys_is_le and '<' or '>'
 swapped_code = sys_is_le and '>' or '<'
 
-endian_codes = (  # numpy code, aliases
+_endian_codes = (  # numpy code, aliases
     ('<', 'little', 'l', 'le', 'L', 'LE'),
     ('>', 'big', 'BIG', 'b', 'be', 'B', 'BE'),
     (native_code, 'native', 'n', 'N', '=', '|', 'i', 'I'),
-    (swapped_code, 'swapped', 's', 'S', '!'))
+    (swapped_code, 'swapped', 's', 'S', '!'),
+)
 # We'll put these into the Recoder class after we define it
 
 #: default compression level when writing gz and bz2 files
 default_compresslevel = 1
 
 #: file-like classes known to hold compressed data
-COMPRESSED_FILE_LIKES = (gzip.GzipFile, BZ2File, IndexedGzipFile)
+COMPRESSED_FILE_LIKES: tuple[type, ...] = (gzip.GzipFile, BZ2File, IndexedGzipFile)
+
+# Enable .zst support if pyzstd installed.
+if HAVE_ZSTD:
+    COMPRESSED_FILE_LIKES = (*COMPRESSED_FILE_LIKES, pyzstd.ZstdFile)
 
 
-class Recoder(object):
-    """ class to return canonical code(s) from code or aliases
+class Recoder:
+    """class to return canonical code(s) from code or aliases
 
     The concept is a lot easier to read in the implementation and
     tests than it is to explain, so...
@@ -76,7 +84,7 @@ class Recoder(object):
     """
 
     def __init__(self, codes, fields=('code',), map_maker=OrderedDict):
-        """ Create recoder object
+        """Create recoder object
 
         ``codes`` give a sequence of code, alias sequences
         ``fields`` are names by which the entries in these sequences can be
@@ -114,7 +122,7 @@ class Recoder(object):
         self.add_codes(codes)
 
     def add_codes(self, code_syn_seqs):
-        """ Add codes to object
+        """Add codes to object
 
         Parameters
         ----------
@@ -148,7 +156,7 @@ class Recoder(object):
                     self.__dict__[field_name][alias] = code_syns[field_ind]
 
     def __getitem__(self, key):
-        """ Return value from field1 dictionary (first column of values)
+        """Return value from field1 dictionary (first column of values)
 
         Returns same value as ``obj.field1[key]`` and, with the
         default initializing ``fields`` argument of fields=('code',),
@@ -161,8 +169,7 @@ class Recoder(object):
         return self.field1[key]
 
     def __contains__(self, key):
-        """ True if field1 in recoder contains `key`
-        """
+        """True if field1 in recoder contains `key`"""
         try:
             self.field1[key]
         except KeyError:
@@ -170,7 +177,7 @@ class Recoder(object):
         return True
 
     def keys(self):
-        """ Return all available code and alias values
+        """Return all available code and alias values
 
         Returns same value as ``obj.field1.keys()`` and, with the
         default initializing ``fields`` argument of fields=('code',),
@@ -184,7 +191,7 @@ class Recoder(object):
         return self.field1.keys()
 
     def value_set(self, name=None):
-        """ Return OrderedSet of possible returned values for column
+        """Return OrderedSet of possible returned values for column
 
         By default, the column is the first column.
 
@@ -214,11 +221,11 @@ class Recoder(object):
 
 
 # Endian code aliases
-endian_codes = Recoder(endian_codes)
+endian_codes = Recoder(_endian_codes)
 
 
-class DtypeMapper(object):
-    """ Specialized mapper for numpy dtypes
+class DtypeMapper:
+    """Specialized mapper for numpy dtypes
 
     We pass this mapper into the Recoder class to deal with numpy dtype
     hashing.
@@ -246,7 +253,7 @@ class DtypeMapper(object):
         return self._dict.values()
 
     def __setitem__(self, key, value):
-        """ Set item into mapping, checking for dtype keys
+        """Set item into mapping, checking for dtype keys
 
         Cache dtype keys for comparison test in __getitem__
         """
@@ -255,7 +262,7 @@ class DtypeMapper(object):
             self._dtype_keys.append(key)
 
     def __getitem__(self, key):
-        """ Get item from mapping, checking for dtype keys
+        """Get item from mapping, checking for dtype keys
 
         First do simple hash lookup, then check for a dtype key that has failed
         the hash lookup.  Look then for any known dtype keys that compare equal
@@ -273,7 +280,7 @@ class DtypeMapper(object):
 
 
 def pretty_mapping(mapping, getterfunc=None):
-    """ Make pretty string from mapping
+    """Make pretty string from mapping
 
     Adjusts text column to print values on basis of longest key.
     Probably only sensible if keys are mainly strings.
@@ -300,7 +307,7 @@ def pretty_mapping(mapping, getterfunc=None):
     >>> d = {'a key': 'a value'}
     >>> print(pretty_mapping(d))
     a key  : a value
-    >>> class C(object): # to control ordering, show get_ method
+    >>> class C: # to control ordering, show get_ method
     ...     def __iter__(self):
     ...         return iter(('short_field','longer_field'))
     ...     def __getitem__(self, key):
@@ -333,7 +340,7 @@ def pretty_mapping(mapping, getterfunc=None):
 
 
 def make_dt_codes(codes_seqs):
-    """ Create full dt codes Recoder instance from datatype codes
+    """Create full dt codes Recoder instance from datatype codes
 
     Include created numpy dtype (from numpy type) and opposite endian
     numpy dtype
@@ -372,82 +379,13 @@ def make_dt_codes(codes_seqs):
     return Recoder(dt_codes, fields + ['dtype', 'sw_dtype'], DtypeMapper)
 
 
-@deprecate_with_version('can_cast deprecated. '
-                        'Please use arraywriter classes instead',
-                        '1.2',
-                        '3.0')
-def can_cast(in_type, out_type, has_intercept=False, has_slope=False):
-    """ Return True if we can safely cast ``in_type`` to ``out_type``
-
-    Parameters
-    ----------
-    in_type : numpy type
-       type of data we will case from
-    out_dtype : numpy type
-       type that we want to cast to
-    has_intercept : bool, optional
-       Whether we can subtract a constant from the data (before scaling)
-       before casting to ``out_dtype``.  Default is False
-    has_slope : bool, optional
-       Whether we can use a scaling factor to adjust slope of
-       relationship of data to data in cast array.  Default is False
-
-    Returns
-    -------
-    tf : bool
-       True if we can safely cast, False otherwise
-
-    Examples
-    --------
-    >>> can_cast(np.float64, np.float32)  # doctest: +SKIP
-    True
-    >>> can_cast(np.complex128, np.float32)  # doctest: +SKIP
-    False
-    >>> can_cast(np.int64, np.float32)  # doctest: +SKIP
-    True
-    >>> can_cast(np.float32, np.int16)  # doctest: +SKIP
-    False
-    >>> can_cast(np.float32, np.int16, False, True)  # doctest: +SKIP
-    True
-    >>> can_cast(np.int16, np.uint8)  # doctest: +SKIP
-    False
-
-    Whether we can actually cast int to uint when we don't have an intercept
-    depends on the data.  That's why this function isn't very useful. But we
-    assume that an integer is using its full range, and check whether scaling
-    works in that situation.
-
-    Here we need an intercept to scale the full range of an int to a uint
-
-    >>> can_cast(np.int16, np.uint8, False, True)  # doctest: +SKIP
-    False
-    >>> can_cast(np.int16, np.uint8, True, True)  # doctest: +SKIP
-    True
-    """
-    in_dtype = np.dtype(in_type)
-    # Whether we can cast depends on the data, and we've only got the type.
-    # Let's assume integers use all of their range but floats etc not
-    if in_dtype.kind in 'iu':
-        info = np.iinfo(in_dtype)
-        data = np.array([info.min, info.max], dtype=in_dtype)
-    else:  # Float or complex or something. Any old thing will do
-        data = np.ones((1,), in_type)
-    from .arraywriters import make_array_writer, WriterError
-    try:
-        make_array_writer(data, out_type, has_slope, has_intercept)
-    except WriterError:
-        return False
-    return True
-
-
 def _is_compressed_fobj(fobj):
-    """ Return True if fobj represents a compressed data file-like object
-    """
+    """Return True if fobj represents a compressed data file-like object"""
     return isinstance(fobj, COMPRESSED_FILE_LIKES)
 
 
 def array_from_file(shape, in_dtype, infile, offset=0, order='F', mmap=True):
-    """ Get array from file with specified shape, dtype and file offset
+    """Get array from file with specified shape, dtype and file offset
 
     Parameters
     ----------
@@ -490,8 +428,7 @@ def array_from_file(shape, in_dtype, infile, offset=0, order='F', mmap=True):
     True
     """
     if mmap not in (True, False, 'c', 'r', 'r+'):
-        raise ValueError("mmap value should be one of True, False, 'c', "
-                         "'r', 'r+'")
+        raise ValueError("mmap value should be one of True, False, 'c', " "'r', 'r+'")
     if mmap is True:
         mmap = 'c'
     in_dtype = np.dtype(in_dtype)
@@ -499,12 +436,7 @@ def array_from_file(shape, in_dtype, infile, offset=0, order='F', mmap=True):
     infile = getattr(infile, 'fobj', infile)
     if mmap and not _is_compressed_fobj(infile):
         try:  # Try memmapping file on disk
-            return np.memmap(infile,
-                             in_dtype,
-                             mode=mmap,
-                             shape=shape,
-                             order=order,
-                             offset=offset)
+            return np.memmap(infile, in_dtype, mode=mmap, shape=shape, order=order, offset=offset)
             # The error raised by memmap, for different file types, has
             # changed in different incarnations of the numpy routine
         except (AttributeError, TypeError, ValueError):
@@ -526,8 +458,10 @@ def array_from_file(shape, in_dtype, infile, offset=0, order='F', mmap=True):
         n_read = len(data_bytes)
         needs_copy = True
     if n_bytes != n_read:
-        raise IOError(f"Expected {n_bytes} bytes, got {n_read} bytes from "
-                      f"{getattr(infile, 'name', 'object')}\n - could the file be damaged?")
+        raise OSError(
+            f'Expected {n_bytes} bytes, got {n_read} bytes from '
+            f"{getattr(infile, 'name', 'object')}\n - could the file be damaged?"
+        )
     arr = np.ndarray(shape, in_dtype, buffer=data_bytes, order=order)
     if needs_copy:
         return arr.copy()
@@ -535,10 +469,19 @@ def array_from_file(shape, in_dtype, infile, offset=0, order='F', mmap=True):
     return arr
 
 
-def array_to_file(data, fileobj, out_dtype=None, offset=0,
-                  intercept=0.0, divslope=1.0,
-                  mn=None, mx=None, order='F', nan2zero=True):
-    """ Helper function for writing arrays to file objects
+def array_to_file(
+    data,
+    fileobj,
+    out_dtype=None,
+    offset=0,
+    intercept=0.0,
+    divslope=1.0,
+    mn=None,
+    mx=None,
+    order='F',
+    nan2zero=True,
+):
+    """Helper function for writing arrays to file objects
 
     Writes arrays as scaled by `intercept` and `divslope`, and clipped
     at (prescaling) `mn` minimum, and `mx` maximum.
@@ -590,7 +533,7 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
         casting; this depends on the underlying C library and is undefined. In
         practice `nan2zero` == False might be a good choice when you completely
         sure there will be no NaNs in the data. This value ignored for float
-        outut types.  NaNs are treated as zero *before* applying `intercept`
+        output types.  NaNs are treated as zero *before* applying `intercept`
         and `divslope` - so an array ``[np.nan]`` with an `intercept` of 10
         becomes ``[-10]`` after conversion to integer `out_dtype` with
         `nan2zero` set.  That is because you will likely apply `divslope` and
@@ -620,8 +563,7 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
     """
     # Shield special case
     div_none = divslope is None
-    if not np.all(
-            np.isfinite((intercept, 1.0 if div_none else divslope))):
+    if not np.all(np.isfinite((intercept, 1.0 if div_none else divslope))):
         raise ValueError('divslope and intercept must be finite')
     if divslope == 0:
         raise ValueError('divslope cannot be zero')
@@ -633,15 +575,14 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
         out_dtype = np.dtype(out_dtype)
     if offset is not None:
         seek_tell(fileobj, offset)
-    if (div_none or (mn, mx) == (0, 0) or
-            ((mn is not None and mx is not None) and mx < mn)):
+    if div_none or (mn, mx) == (0, 0) or ((mn is not None and mx is not None) and mx < mn):
         write_zeros(fileobj, data.size * out_dtype.itemsize)
         return
     if order not in 'FC':
         raise ValueError('Order should be one of F or C')
     # Simple cases
     pre_clips = None if (mn is None and mx is None) else (mn, mx)
-    null_scaling = (intercept == 0 and divslope == 1)
+    null_scaling = intercept == 0 and divslope == 1
     if in_dtype.type == np.void:
         if not null_scaling:
             raise ValueError('Cannot scale non-numeric types')
@@ -651,10 +592,9 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
     if pre_clips is not None:
         pre_clips = _dt_min_max(in_dtype, *pre_clips)
     if null_scaling and np.can_cast(in_dtype, out_dtype):
-        return _write_data(data, fileobj, out_dtype, order,
-                           pre_clips=pre_clips)
+        return _write_data(data, fileobj, out_dtype, order, pre_clips=pre_clips)
     # Force upcasting for floats by making atleast_1d.
-    slope, inter = [np.atleast_1d(v) for v in (divslope, intercept)]
+    slope, inter = (np.atleast_1d(v) for v in (divslope, intercept))
     # Default working point type for applying slope / inter
     if slope.dtype.kind in 'iu':
         slope = slope.astype(float)
@@ -663,10 +603,9 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
     in_kind = in_dtype.kind
     out_kind = out_dtype.kind
     if out_kind in 'fc':
-        return _write_data(data, fileobj, out_dtype, order,
-                           slope=slope,
-                           inter=inter,
-                           pre_clips=pre_clips)
+        return _write_data(
+            data, fileobj, out_dtype, order, slope=slope, inter=inter, pre_clips=pre_clips
+        )
     assert out_kind in 'iu'
     if in_kind in 'iu':
         if null_scaling:
@@ -675,16 +614,15 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
             mn, mx = _dt_min_max(in_dtype, mn, mx)
             mn_out, mx_out = _dt_min_max(out_dtype)
             pre_clips = max(mn, mn_out), min(mx, mx_out)
-            return _write_data(data, fileobj, out_dtype, order,
-                               pre_clips=pre_clips)
-        # In any case, we do not want to check for nans beause we've already
+            return _write_data(data, fileobj, out_dtype, order, pre_clips=pre_clips)
+        # In any case, we do not want to check for nans because we've already
         # disallowed scaling that generates nans
         nan2zero = False
     # We are either scaling into c/floats or starting with c/floats, then we're
     # going to integers
     # Because we're going to integers, complex inter and slope will only slow
     # us down, cast to float
-    slope, inter = [v.astype(_matching_float(v.dtype)) for v in (slope, inter)]
+    slope, inter = (v.astype(_matching_float(v.dtype)) for v in (slope, inter))
     # We'll do the thresholding on the scaled data, so turn off the
     # thresholding on the unscaled data
     pre_clips = None
@@ -705,7 +643,7 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
     extremes = np.array(dt_mnmx, dtype=cast_in_dtype)
     w_type = best_write_scale_ftype(extremes, slope, inter, w_type)
     # Push up precision by casting the slope, inter
-    slope, inter = [v.astype(w_type) for v in (slope, inter)]
+    slope, inter = (v.astype(w_type) for v in (slope, inter))
     # We need to know the result of applying slope and inter to the min and
     # max of the array, in order to clip the output array, after applying
     # the slope and inter.  Otherwise we'd need to clip twice, once before
@@ -739,38 +677,48 @@ def array_to_file(data, fileobj, out_dtype=None, offset=0,
         # slope).  Assume errors are for working float type. Round for integer
         # rounding
         est_err = np.round(2 * np.finfo(w_type).eps * abs(inter / slope))
-        if ((nan_fill < both_mn and abs(nan_fill - both_mn) < est_err) or
-                (nan_fill > both_mx and abs(nan_fill - both_mx) < est_err)):
+        if (nan_fill < both_mn and abs(nan_fill - both_mn) < est_err) or (
+            nan_fill > both_mx and abs(nan_fill - both_mx) < est_err
+        ):
             # nan_fill can be (just) outside clip range
             nan_fill = np.clip(nan_fill, both_mn, both_mx)
         else:
-            raise ValueError(f"nan_fill == {nan_fill}, outside safe int range "
-                             f"({int(both_mn)}-{int(both_mx)}); "
-                             "change scaling or set nan2zero=False?")
+            raise ValueError(
+                f'nan_fill == {nan_fill}, outside safe int range '
+                f'({int(both_mn)}-{int(both_mx)}); '
+                'change scaling or set nan2zero=False?'
+            )
     # Make sure non-nan output clipped to shared range
     post_mn = np.max([post_mn, both_mn])
     post_mx = np.min([post_mx, both_mx])
     in_cast = None if cast_in_dtype == in_dtype else cast_in_dtype
-    return _write_data(data, fileobj, out_dtype, order,
-                       in_cast=in_cast,
-                       pre_clips=pre_clips,
-                       inter=inter,
-                       slope=slope,
-                       post_clips=(post_mn, post_mx),
-                       nan_fill=nan_fill if nan2zero else None)
+    return _write_data(
+        data,
+        fileobj,
+        out_dtype,
+        order,
+        in_cast=in_cast,
+        pre_clips=pre_clips,
+        inter=inter,
+        slope=slope,
+        post_clips=(post_mn, post_mx),
+        nan_fill=nan_fill if nan2zero else None,
+    )
 
 
-def _write_data(data,
-                fileobj,
-                out_dtype,
-                order,
-                in_cast=None,
-                pre_clips=None,
-                inter=0.,
-                slope=1.,
-                post_clips=None,
-                nan_fill=None):
-    """ Write array `data` to `fileobj` as `out_dtype` type, layout `order`
+def _write_data(
+    data,
+    fileobj,
+    out_dtype,
+    order,
+    in_cast=None,
+    pre_clips=None,
+    inter=0.0,
+    slope=1.0,
+    post_clips=None,
+    nan_fill=None,
+):
+    """Write array `data` to `fileobj` as `out_dtype` type, layout `order`
 
     Does not modify `data` in-place.
 
@@ -784,7 +732,7 @@ def _write_data(data,
     order : {'F', 'C'}
         memory layout of array in fileobj after writing
     in_cast : None or numpy type, optional
-        If not None, inital cast to do on `data` slices before further
+        If not None, initial cast to do on `data` slices before further
         processing
     pre_clips : None or 2-sequence, optional
         If not None, minimum and maximum of input values at which to clip.
@@ -803,8 +751,7 @@ def _write_data(data,
         data = np.atleast_2d(data)
     elif order == 'F':
         data = data.T
-    nan_need_copy = ((pre_clips, in_cast, inter, slope, post_clips) ==
-                     (None, None, 0, 1, None))
+    nan_need_copy = (pre_clips, in_cast, inter, slope, post_clips) == (None, None, 0, 1, None)
     for dslice in data:  # cycle over first dimension to save memory
         if pre_clips is not None:
             dslice = np.clip(dslice, *pre_clips)
@@ -835,20 +782,15 @@ def _dt_min_max(dtype_like, mn=None, mx=None):
         info = np.iinfo(dt)
         dt_mn, dt_mx = (info.min, info.max)
     else:
-        raise ValueError("unknown dtype")
+        raise ValueError('unknown dtype')
     return dt_mn if mn is None else mn, dt_mx if mx is None else mx
 
 
-_CSIZE2FLOAT = {
-    8: np.float32,
-    16: np.float64,
-    24: np.longdouble,
-    32: np.longdouble}
+_CSIZE2FLOAT = {8: np.float32, 16: np.float64, 24: np.longdouble, 32: np.longdouble}
 
 
 def _matching_float(np_type):
-    """ Return floating point type matching `np_type`
-    """
+    """Return floating point type matching `np_type`"""
     dtype = np.dtype(np_type)
     if dtype.kind not in 'cf':
         raise ValueError('Expecting float or complex type as input')
@@ -858,7 +800,7 @@ def _matching_float(np_type):
 
 
 def write_zeros(fileobj, count, block_size=8194):
-    """ Write `count` zero bytes to `fileobj`
+    """Write `count` zero bytes to `fileobj`
 
     Parameters
     ----------
@@ -878,12 +820,12 @@ def write_zeros(fileobj, count, block_size=8194):
 
 
 def seek_tell(fileobj, offset, write0=False):
-    """ Seek in `fileobj` or check we're in the right place already
+    """Seek in `fileobj` or check we're in the right place already
 
     Parameters
     ----------
     fileobj : file-like
-        object implementing ``seek`` and (if seek raises an IOError) ``tell``
+        object implementing ``seek`` and (if seek raises an OSError) ``tell``
     offset : int
         position in file to which to seek
     write0 : {False, True}, optional
@@ -893,22 +835,22 @@ def seek_tell(fileobj, offset, write0=False):
     """
     try:
         fileobj.seek(offset)
-    except IOError as e:
+    except OSError as e:
         # This can be a negative seek in write mode for gz file object or any
         # seek in write mode for a bz2 file object
         pos = fileobj.tell()
         if pos == offset:
             return
         if not write0:
-            raise IOError(str(e))
+            raise OSError(str(e))
         if pos > offset:
-            raise IOError("Can't write to seek backwards")
+            raise OSError("Can't write to seek backwards")
         fileobj.write(b'\x00' * (offset - pos))
         assert fileobj.tell() == offset
 
 
 def apply_read_scaling(arr, slope=None, inter=None):
-    """ Apply scaling in `slope` and `inter` to array `arr`
+    """Apply scaling in `slope` and `inter` to array `arr`
 
     This is for loading the array from a file (as opposed to the reverse
     scaling when saving an array to file)
@@ -946,12 +888,12 @@ def apply_read_scaling(arr, slope=None, inter=None):
         return arr
     shape = arr.shape
     # Force float / float upcasting by promoting to arrays
-    arr, slope, inter = [np.atleast_1d(v) for v in (arr, slope, inter)]
+    arr, slope, inter = (np.atleast_1d(v) for v in (arr, slope, inter))
     if arr.dtype.kind in 'iu':
         # int to float; get enough precision to avoid infs
         # Find floating point type for which scaling does not overflow,
         # starting at given type
-        default = (slope.dtype.type if slope.dtype.kind == 'f' else np.float64)
+        default = slope.dtype.type if slope.dtype.kind == 'f' else np.float64
         ftype = int_scinter_ftype(arr.dtype, slope, inter, default)
         slope = slope.astype(ftype)
         inter = inter.astype(ftype)
@@ -963,7 +905,7 @@ def apply_read_scaling(arr, slope=None, inter=None):
 
 
 def working_type(in_type, slope=1.0, inter=0.0):
-    """ Return array type from applying `slope`, `inter` to array of `in_type`
+    """Return array type from applying `slope`, `inter` to array of `in_type`
 
     Numpy type that results from an array of type `in_type` being combined with
     `slope` and `inter`. It returns something like the dtype type of
@@ -1005,156 +947,8 @@ def working_type(in_type, slope=1.0, inter=0.0):
     return val.dtype.type
 
 
-@deprecate_with_version('calculate_scale deprecated. '
-                        'Please use arraywriter classes instead',
-                        '1.2',
-                        '3.0')
-def calculate_scale(data, out_dtype, allow_intercept):
-    """ Calculate scaling and optional intercept for data
-
-    Parameters
-    ----------
-    data : array
-    out_dtype : dtype
-       output data type in some form understood by ``np.dtype``
-    allow_intercept : bool
-       If True allow non-zero intercept
-
-    Returns
-    -------
-    scaling : None or float
-       scalefactor to divide into data.  None if no valid data
-    intercept : None or float
-       intercept to subtract from data.  None if no valid data
-    mn : None or float
-       minimum of finite value in data or None if this will not
-       be used to threshold data
-    mx : None or float
-       minimum of finite value in data, or None if this will not
-       be used to threshold data
-    """
-    # Code here is a compatibility shell around arraywriters refactor
-    in_dtype = data.dtype
-    out_dtype = np.dtype(out_dtype)
-    if np.can_cast(in_dtype, out_dtype):
-        return 1.0, 0.0, None, None
-    from .arraywriters import make_array_writer, WriterError, get_slope_inter
-    try:
-        writer = make_array_writer(data, out_dtype, True, allow_intercept)
-    except WriterError as e:
-        raise ValueError(str(e))
-    if out_dtype.kind in 'fc':
-        return (1.0, 0.0, None, None)
-    mn, mx = writer.finite_range()
-    if (mn, mx) == (np.inf, -np.inf):  # No valid data
-        return (None, None, None, None)
-    if in_dtype.kind not in 'fc':
-        mn, mx = (None, None)
-    return get_slope_inter(writer) + (mn, mx)
-
-
-@deprecate_with_version('scale_min_max deprecated. Please use arraywriter '
-                        'classes instead.',
-                        '1.2',
-                        '3.0')
-def scale_min_max(mn, mx, out_type, allow_intercept):
-    """ Return scaling and intercept min, max of data, given output type
-
-    Returns ``scalefactor`` and ``intercept`` to best fit data with
-    given ``mn`` and ``mx`` min and max values into range of data type
-    with ``type_min`` and ``type_max`` min and max values for type.
-
-    The calculated scaling is therefore::
-
-        scaled_data = (data-intercept) / scalefactor
-
-    Parameters
-    ----------
-    mn : scalar
-       data minimum value
-    mx : scalar
-       data maximum value
-    out_type : numpy type
-       numpy type of output
-    allow_intercept : bool
-       If true, allow calculation of non-zero intercept.  Otherwise,
-       returned intercept is always 0.0
-
-    Returns
-    -------
-    scalefactor : numpy scalar, dtype=np.maximum_sctype(np.float64)
-       scalefactor by which to divide data after subtracting intercept
-    intercept : numpy scalar, dtype=np.maximum_sctype(np.float64)
-       value to subtract from data before dividing by scalefactor
-
-    Examples
-    --------
-    >>> scale_min_max(0, 255, np.uint8, False)  # doctest: +SKIP
-    (1.0, 0.0)
-    >>> scale_min_max(-128, 127, np.int8, False)  # doctest: +SKIP
-    (1.0, 0.0)
-    >>> scale_min_max(0, 127, np.int8, False)  # doctest: +SKIP
-    (1.0, 0.0)
-    >>> scaling, intercept = scale_min_max(0, 127, np.int8,  True)  # doctest: +SKIP
-    >>> np.allclose((0 - intercept) / scaling, -128)  # doctest: +SKIP
-    True
-    >>> np.allclose((127 - intercept) / scaling, 127)  # doctest: +SKIP
-    True
-    >>> scaling, intercept = scale_min_max(-10, -1, np.int8, True)  # doctest: +SKIP
-    >>> np.allclose((-10 - intercept) / scaling, -128)  # doctest: +SKIP
-    True
-    >>> np.allclose((-1 - intercept) / scaling, 127)  # doctest: +SKIP
-    True
-    >>> scaling, intercept = scale_min_max(1, 10, np.int8, True)  # doctest: +SKIP
-    >>> np.allclose((1 - intercept) / scaling, -128)  # doctest: +SKIP
-    True
-    >>> np.allclose((10 - intercept) / scaling, 127)  # doctest: +SKIP
-    True
-
-    Notes
-    -----
-    We don't use this function anywhere in nibabel now, it's here for API
-    compatibility only.
-
-    The large integers lead to python long types as max / min for type.
-    To contain the rounding error, we need to use the maximum numpy
-    float types when casting to float.
-    """
-    if mn > mx:
-        raise ValueError('min value > max value')
-    info = type_info(out_type)
-    mn, mx, type_min, type_max = np.array(
-        [mn, mx, info['min'], info['max']], np.maximum_sctype(np.float))
-    # with intercept
-    if allow_intercept:
-        data_range = mx - mn
-        if data_range == 0:
-            return 1.0, mn
-        type_range = type_max - type_min
-        scaling = data_range / type_range
-        intercept = mn - type_min * scaling
-        return scaling, intercept
-    # without intercept
-    if mx == 0 and mn == 0:
-        return 1.0, 0.0
-    if type_min == 0:  # uint
-        if mn < 0 and mx > 0:
-            raise ValueError('Cannot scale negative and positive '
-                             'numbers to uint without intercept')
-        if mx < 0:
-            scaling = mn / type_max
-        else:
-            scaling = mx / type_max
-    else:  # int
-        if abs(mx) >= abs(mn):
-            scaling = mx / type_max
-        else:
-            scaling = mn / type_min
-    return scaling, 0.0
-
-
 def int_scinter_ftype(ifmt, slope=1.0, inter=0.0, default=np.float32):
-    """ float type containing int type `ifmt` * `slope` + `inter`
+    """float type containing int type `ifmt` * `slope` + `inter`
 
     Return float type that can represent the max and the min of the `ifmt` type
     after multiplication with `slope` and addition of `inter` with something
@@ -1206,7 +1000,7 @@ def int_scinter_ftype(ifmt, slope=1.0, inter=0.0, default=np.float32):
 
 
 def best_write_scale_ftype(arr, slope=1.0, inter=0.0, default=np.float32):
-    """ Smallest float type to contain range of ``arr`` after scaling
+    """Smallest float type to contain range of ``arr`` after scaling
 
     Scaling that will be applied to ``arr`` is ``(arr - inter) / slope``.
 
@@ -1270,7 +1064,7 @@ def best_write_scale_ftype(arr, slope=1.0, inter=0.0, default=np.float32):
 
 
 def better_float_of(first, second, default=np.float32):
-    """ Return more capable float type of `first` and `second`
+    """Return more capable float type of `first` and `second`
 
     Return `default` if neither of `first` or `second` is a float
 
@@ -1315,10 +1109,8 @@ def better_float_of(first, second, default=np.float32):
     return second.type
 
 
-def _ftype4scaled_finite(tst_arr, slope, inter, direction='read',
-                         default=np.float32):
-    """ Smallest float type for scaling of `tst_arr` that does not overflow
-    """
+def _ftype4scaled_finite(tst_arr, slope, inter, direction='read', default=np.float32):
+    """Smallest float type for scaling of `tst_arr` that does not overflow"""
     assert direction in ('read', 'write')
     if default not in OK_FLOATS and default is np.longdouble:
         # Omitted longdouble
@@ -1356,7 +1148,7 @@ def _ftype4scaled_finite(tst_arr, slope, inter, direction='read',
 
 
 def finite_range(arr, check_nan=False):
-    """ Get range (min, max) or range and flag (min, max, has_nan) from `arr`
+    """Get range (min, max) or range and flag (min, max, has_nan) from `arr`
 
     Parameters
     ----------
@@ -1452,7 +1244,7 @@ def finite_range(arr, check_nan=False):
 
 
 def shape_zoom_affine(shape, zooms, x_flip=True):
-    """ Get affine implied by given shape and zooms
+    """Get affine implied by given shape and zooms
 
     We get the translations from the center of the image (implied by
     `shape`).
@@ -1470,7 +1262,7 @@ def shape_zoom_affine(shape, zooms, x_flip=True):
     Returns
     -------
     aff : (4,4) array
-       affine giving correspondance of voxel coordinates to mm
+       affine giving correspondence of voxel coordinates to mm
        coordinates, taking the center of the image as origin
 
     Examples
@@ -1514,7 +1306,7 @@ def shape_zoom_affine(shape, zooms, x_flip=True):
 
 
 def rec2dict(rec):
-    """ Convert recarray to dictionary
+    """Convert recarray to dictionary
 
     Also converts scalar values to scalars
 
@@ -1546,19 +1338,8 @@ def rec2dict(rec):
     return dct
 
 
-class BinOpener(Opener):
-    """ Deprecated class that used to handle .mgz through specialized logic."""
-    __doc__ = Opener.__doc__
-
-    @deprecate_with_version('BinOpener class deprecated. '
-                            "Please use Opener class instead.",
-                            '2.1', '4.0')
-    def __init__(self, *args, **kwargs):
-        return super(BinOpener, self).__init__(*args, **kwargs)
-
-
 def fname_ext_ul_case(fname):
-    """ `fname` with ext changed to upper / lower case if file exists
+    """`fname` with ext changed to upper / lower case if file exists
 
     Check for existence of `fname`.  If it does exist, return unmodified.  If
     it doesn't, check for existence of `fname` with case changed from lower to
@@ -1587,21 +1368,3 @@ def fname_ext_ul_case(fname):
         if exists(mod_fname):
             return mod_fname
     return fname
-
-
-@deprecate_with_version('allopen is deprecated. '
-                        'Please use "Opener" class instead.',
-                        '2.0', '4.0')
-def allopen(fileish, *args, **kwargs):
-    """ Compatibility wrapper for old ``allopen`` function
-
-    Wraps creation of ``Opener`` instance, while picking up module global
-    ``default_compresslevel``.
-
-    Please see docstring of ``Opener`` for details.
-    """
-
-    class MyOpener(Opener):
-        default_compresslevel = default_compresslevel
-
-    return MyOpener(fileish, *args, **kwargs)
