@@ -17,26 +17,26 @@ from xml.parsers.expat import ParserCreate
 from .filebasedimages import FileBasedHeader
 
 
-class XmlSerializable(object):
-    """ Basic interface for serializing an object to xml"""
+class XmlSerializable:
+    """Basic interface for serializing an object to xml"""
 
     def _to_xml_element(self):
-        """ Output should be a xml.etree.ElementTree.Element"""
+        """Output should be a xml.etree.ElementTree.Element"""
         raise NotImplementedError()
 
     def to_xml(self, enc='utf-8'):
-        """ Output should be an xml string with the given encoding.
+        """Output should be an xml string with the given encoding.
         (default: utf-8)"""
         ele = self._to_xml_element()
         return '' if ele is None else tostring(ele, enc)
 
 
 class XmlBasedHeader(FileBasedHeader, XmlSerializable):
-    """ Basic wrapper around FileBasedHeader and XmlSerializable."""
+    """Basic wrapper around FileBasedHeader and XmlSerializable."""
 
 
-class XmlParser(object):
-    """ Base class for defining how to parse xml-based image snippets.
+class XmlParser:
+    """Base class for defining how to parse xml-based image snippets.
 
     Image-specific parsers should define:
         StartElementHandler
@@ -44,9 +44,7 @@ class XmlParser(object):
         CharacterDataHandler
     """
 
-    HANDLER_NAMES = ['StartElementHandler',
-                     'EndElementHandler',
-                     'CharacterDataHandler']
+    HANDLER_NAMES = ['StartElementHandler', 'EndElementHandler', 'CharacterDataHandler']
 
     def __init__(self, encoding='utf-8', buffer_size=35000000, verbose=0):
         """
@@ -65,6 +63,7 @@ class XmlParser(object):
         self.encoding = encoding
         self.buffer_size = buffer_size
         self.verbose = verbose
+        self.fname = None  # set on calls to parse
 
     def _create_parser(self):
         """Internal function that allows subclasses to mess
@@ -80,8 +79,8 @@ class XmlParser(object):
         """
         Parameters
         ----------
-        string : str
-            string containing xml document
+        string : bytes
+            string (as a bytes object) containing xml document
 
         fname : str
             file name of an xml document.
@@ -95,8 +94,10 @@ class XmlParser(object):
         if string is not None:
             fptr = BytesIO(string)
         elif fname is not None:
-            fptr = open(fname, 'r')
+            fptr = open(fname)
 
+        # store the name of the xml file in case it is needed during parsing
+        self.fname = getattr(fptr, 'name', None)
         parser = self._create_parser()
         for name in self.HANDLER_NAMES:
             setattr(parser, name, getattr(self, name))
