@@ -1,19 +1,19 @@
-""" Tests for testers
+"""Tests for testers
 """
 
 import os
 from os.path import dirname, pathsep
 
-from ..testers import back_tick, run_mod_cmd, PYTHON
-
 import pytest
 
+from ..testers import PYTHON, back_tick, run_mod_cmd
+
 
 def test_back_tick():
     cmd = f'{PYTHON} -c "print(\'Hello\')"'
-    assert back_tick(cmd) == "Hello"
-    assert back_tick(cmd, ret_err=True) == ("Hello", "")
-    assert back_tick(cmd, True, False) == (b"Hello", b"")
+    assert back_tick(cmd) == 'Hello'
+    assert back_tick(cmd, ret_err=True) == ('Hello', '')
+    assert back_tick(cmd, True, False) == (b'Hello', b'')
     cmd = f'{PYTHON} -c "raise ValueError()"'
     with pytest.raises(RuntimeError):
         back_tick(cmd)
@@ -22,7 +22,7 @@ def test_back_tick():
 def test_run_mod_cmd():
     mod = 'os'
     mod_dir = dirname(os.__file__)
-    assert run_mod_cmd(mod, mod_dir, "print('Hello')", None, False) == ("Hello", "")
+    assert run_mod_cmd(mod, mod_dir, "print('Hello')", None, False) == ('Hello', '')
     sout, serr = run_mod_cmd(mod, mod_dir, "print('Hello again')")
     assert serr == ''
     mod_file, out_str = [s.strip() for s in sout.split('\n')]
