@@ -18,14 +18,15 @@ if [ -n "$EXTRA_PIP_FLAGS" ]; then
     EXTRA_PIP_FLAGS=${!EXTRA_PIP_FLAGS}
 fi
 
-if [ "$INSTALL_TYPE" == "setup" ]; then
-    python setup.py install
-else
-    pip install $EXTRA_PIP_FLAGS $ARCHIVE
-fi
+(
+  # Ensure installation does not depend on being in source tree
+  mkdir ../unversioned_install_dir
+  cd ../unversioned_install_dir
+  pip install $EXTRA_PIP_FLAGS $ARCHIVE
 
-# Basic import check
-python -c 'import nibabel; print(nibabel.__version__)'
+  # Basic import check
+  python -c 'import nibabel; print(nibabel.__version__)'
+)
 
 if [ "$CHECK_TYPE" == "skiptests" ]; then
     exit 0
