@@ -10,13 +10,14 @@
 distutils setup.py.
 
 This script is a minimal version of a wrapper script shipped with the
-bdist_mpkg packge.
+bdist_mpkg package.
 """
 
 __docformat__ = 'restructuredtext'
 
 import sys
 
+
 def main():
     del sys.argv[0]
     sys.argv.insert(1, 'bdist_mpkg')
@@ -25,5 +26,6 @@ def main():
     g['__name__'] = '__main__'
     execfile(sys.argv[0], g, g)
 
+
 if __name__ == '__main__':
     main()
